Class: Straddle::Internal::Transport::BaseClient Abstract Private

Inherits:
Object
  • Object
show all
Extended by:
Util::SorbetRuntimeSupport
Defined in:
lib/straddle/internal/transport/base_client.rb,
sig/straddle/internal/transport/base_client.rbs

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

This class is abstract.

Direct Known Subclasses

Client

Constant Summary collapse

MAX_REDIRECTS =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

from whatwg fetch spec

Returns:

  • (20)
20
PLATFORM_HEADERS =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

rubocop:disable Style/MutableConstant

Returns:

  • (::Hash[String, String])
{
  "x-scalar-arch" => Straddle::Internal::Util.arch,
  "x-scalar-lang" => "ruby",
  "x-scalar-os" => Straddle::Internal::Util.os,
  "x-scalar-package-version" => Straddle::VERSION,
  "x-scalar-runtime" => ::RUBY_ENGINE,
  "x-scalar-runtime-version" => ::RUBY_ENGINE_VERSION
}
Straddle =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Returns:

  • (:request_options opts)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Util::SorbetRuntimeSupport

const_missing, define_sorbet_constant!, sorbet_constant_defined?, to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(base_url:, timeout: 0.0, max_retries: 0, initial_retry_delay: 0.0, max_retry_delay: 0.0, headers: {}, idempotency_header: nil) ⇒ BaseClient

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of BaseClient.

Parameters:

  • base_url (String)
  • timeout (Float) (defaults to: 0.0)
  • max_retries (Integer) (defaults to: 0)
  • initial_retry_delay (Float) (defaults to: 0.0)
  • max_retry_delay (Float) (defaults to: 0.0)
  • headers (Hash{String=>String, Integer, Array<String, Integer, nil>, nil}) (defaults to: {})
  • idempotency_header (String, nil) (defaults to: nil)


189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/straddle/internal/transport/base_client.rb', line 189

def initialize(
  base_url:,
  timeout: 0.0,
  max_retries: 0,
  initial_retry_delay: 0.0,
  max_retry_delay: 0.0,
  headers: {},
  idempotency_header: nil
)
  @requester = Straddle::Internal::Transport::PooledNetRequester.new
  @headers =
    Straddle::Internal::Util.normalized_headers(
      self.class::PLATFORM_HEADERS,
      {
        "accept" => "application/json",
        "content-type" => "application/json",
        "user-agent" => user_agent
      },
      headers
    )
  @base_url_components = Straddle::Internal::Util.parse_uri(base_url)
  @base_url = Straddle::Internal::Util.unparse_uri(@base_url_components)
  @idempotency_header = idempotency_header&.to_s&.downcase
  @timeout = timeout
  @max_retries = max_retries
  @initial_retry_delay = initial_retry_delay
  @max_retry_delay = max_retry_delay
end

Instance Attribute Details

#base_url ⇒ URI::Generic (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (URI::Generic)


156
157
158
# File 'lib/straddle/internal/transport/base_client.rb', line 156

def base_url
  @base_url
end

#headers ⇒ Hash{String=>String} (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (Hash{String=>String})


171
172
173
# File 'lib/straddle/internal/transport/base_client.rb', line 171

def headers
  @headers
end

#idempotency_header ⇒ String? (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (String, nil)


174
175
176
# File 'lib/straddle/internal/transport/base_client.rb', line 174

def idempotency_header
  @idempotency_header
end

#initial_retry_delay ⇒ Float (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (Float)


165
166
167
# File 'lib/straddle/internal/transport/base_client.rb', line 165

def initial_retry_delay
  @initial_retry_delay
end

#max_retries ⇒ Integer (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (Integer)


162
163
164
# File 'lib/straddle/internal/transport/base_client.rb', line 162

def max_retries
  @max_retries
end

#max_retry_delay ⇒ Float (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (Float)


168
169
170
# File 'lib/straddle/internal/transport/base_client.rb', line 168

def max_retry_delay
  @max_retry_delay
end

#requester ⇒ Straddle::Internal::Transport::PooledNetRequester (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



178
179
180
# File 'lib/straddle/internal/transport/base_client.rb', line 178

def requester
  @requester
end

#timeout ⇒ Float (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (Float)


159
160
161
# File 'lib/straddle/internal/transport/base_client.rb', line 159

def timeout
  @timeout
end

Class Method Details

.follow_redirect(request, status:, response_headers:) ⇒ Hash{Symbol=>Object}

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • request (Hash{Symbol=>Object}) —

    .

    @option request [Symbol] :method

    @option request [URI::Generic] :url

    @option request [HashString=>String] :headers

    @option request [Object] :body

    @option request [Integer] :max_retries

    @option request [Float] :timeout

  • status (Integer)
  • response_headers (Hash{String=>String})

Returns:

  • (Hash{Symbol=>Object})


90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/straddle/internal/transport/base_client.rb', line 90

def follow_redirect(request, status:, response_headers:)
  method, url, headers = request.fetch_values(:method, :url, :headers)
  location =
    Kernel.then do
      URI.join(url, response_headers["location"])
    rescue ArgumentError
      message = "Server responded with status #{status} but no valid location header."
      raise Straddle::Errors::APIConnectionError.new(
        url: url,
        response: response_headers,
        message: message
      )
    end

  request = {**request, url: location}

  case [url.scheme, location.scheme]
  in ["https", "http"]
    message = "Tried to redirect to a insecure URL"
    raise Straddle::Errors::APIConnectionError.new(
      url: url,
      response: response_headers,
      message: message
    )
  else
    nil
  end

  # from whatwg fetch spec
  case [status, method]
  in [301 | 302, :post] | [303, _]
    drop = %w[content-encoding content-language content-length content-location content-type]
    request = {
      **request,
      method: method == :head ? :head : :get,
      headers: headers.except(*drop),
      body: nil
    }
  else
  end

  # from undici
  if Straddle::Internal::Util.uri_origin(url) != Straddle::Internal::Util.uri_origin(location)
    drop = %w[authorization cookie host proxy-authorization]
    request = {**request, headers: request.fetch(:headers).except(*drop)}
  end

  request
end

.reap_connection!(status, stream:) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:



144
145
146
147
148
149
150
151
152
# File 'lib/straddle/internal/transport/base_client.rb', line 144

def reap_connection!(status, stream:)
  case status
  in ..199 | 300..499
    stream&.each { next }
  in Straddle::Errors::APIConnectionError | 500.. then
    Straddle::Internal::Util.close_fused!(stream)
  else
  end
end

.should_retry?(status, headers:) ⇒ Boolean

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • status (Integer)
  • headers (Hash{String=>String})

Returns:

  • (Boolean)


52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/straddle/internal/transport/base_client.rb', line 52

def should_retry?(status, headers:)
  coerced = Straddle::Internal::Util.coerce_boolean(headers["x-should-retry"])
  case [coerced, status]
  in [true | false, _]
    coerced
  in [_, 408 | 409 | 429 | 500..]
    # retry on:
    # 408: timeouts
    # 409: locks
    # 429: rate limits
    # 500+: unknown errors
    true
  else
    false
  end
end

.validate!(req) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • req (Hash{Symbol=>Object})

Raises:

  • (ArgumentError)


32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/straddle/internal/transport/base_client.rb', line 32

def validate!(req)
  keys = %i[method path query headers body unwrap page stream model options]
  case req
  in Hash
    req.each_key do |k|
      unless keys.include?(k)
        raise ArgumentError.new("Request `req` keys must be one of #{keys}, got #{k.inspect}")
      end
    end
  else
    raise ArgumentError.new("Request `req` must be a Hash or RequestOptions, got #{req.inspect}")
  end
end

Instance Method Details

#inspect ⇒ String

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (String)


518
519
520
521
522
# File 'lib/straddle/internal/transport/base_client.rb', line 518

def inspect
  # rubocop:disable Layout/LineLength
  "#<#{self.class.name}:0x#{object_id.to_s(16)} base_url=#{@base_url} max_retries=#{@max_retries} timeout=#{@timeout}>"
  # rubocop:enable Layout/LineLength
end

#request(method, path, query: {}, headers: {}, body: nil, unwrap: nil, page: nil, stream: nil, model: Straddle::Internal::Type::Unknown, options: {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Execute the request specified by req. This is the method that all resource methods call into.

Parameters:

  • method (Symbol)
  • path (String, Array<String>)
  • query (Hash{String=>Array<String>, String, nil}, nil)
  • headers (Hash{String=>String, Integer, Array<String, Integer, nil>, nil}, nil)
  • body (Object, nil)
  • unwrap (Symbol, Integer, Array<Symbol, Integer>, Proc, nil)
  • page (Class<Straddle::Internal::Type::BasePage>, nil)
  • stream (Class<Straddle::Internal::Type::BaseStream>, nil)
  • model (Straddle::Internal::Type::Converter, Class, nil)
  • options (Straddle::RequestOptions, Hash{Symbol=>Object}, nil) —

    .

    @option options [String, nil] :idempotency_key

    @option options [HashString, nil, nil] :extra_query

    @option options [Hashnil, nil] :extra_headers

    @option options [Object, nil] :extra_body

    @option options [Integer, nil] :max_retries

    @option options [Float, nil] :timeout

Returns:

  • (Object)

Raises:



480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
# File 'lib/straddle/internal/transport/base_client.rb', line 480

def request(req)
  self.class.validate!(req)
  model = req.fetch(:model) { Straddle::Internal::Type::Unknown }
  opts = req[:options].to_h
  unwrap = req[:unwrap]
  Straddle::RequestOptions.validate!(opts)
  request = build_request(req.except(:options), opts)
  url = request.fetch(:url)

  # Don't send the current retry count in the headers if the caller modified the header defaults.
  send_retry_header = request.fetch(:headers)["x-scalar-retry-count"] == "0"
  status, response, stream =
    send_request(request, redirect_count: 0, retry_count: 0, send_retry_header: send_retry_header)

  headers = Straddle::Internal::Util.normalized_headers(response.each_header.to_h)
  decoded = Straddle::Internal::Util.decode_content(headers, stream: stream)
  case req
  in stream: Class => st
    st.new(
      model: model,
      url: url,
      status: status,
      headers: headers,
      response: response,
      unwrap: unwrap,
      stream: decoded
    )
  in page: Class => page
    page.new(client: self, req: req, headers: headers, page_data: decoded)
  else
    unwrapped = Straddle::Internal::Util.dig(decoded, unwrap)
    Straddle::Internal::Type::Converter.coerce(model, unwrapped)
  end
end

#send_request(request, redirect_count:, retry_count:, send_retry_header:) ⇒ Array(Integer, Net::HTTPResponse, Enumerable<String>)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • request (Hash{Symbol=>Object}) —

    .

    @option request [Symbol] :method

    @option request [URI::Generic] :url

    @option request [HashString=>String] :headers

    @option request [Object] :body

    @option request [Integer] :max_retries

    @option request [Float] :timeout

  • redirect_count (Integer)
  • retry_count (Integer)
  • send_retry_header (Boolean)

Returns:

  • (Array(Integer, Net::HTTPResponse, Enumerable<String>))

Raises:



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/straddle/internal/transport/base_client.rb', line 377

def send_request(request, redirect_count:, retry_count:, send_retry_header:)
  url, headers, max_retries, timeout = request.fetch_values(:url, :headers, :max_retries, :timeout)
  input = {**request.except(:timeout), deadline: Straddle::Internal::Util.monotonic_secs + timeout}

  headers["x-scalar-retry-count"] = retry_count.to_s if send_retry_header

  begin
    status, response, stream = @requester.execute(input)
  rescue Straddle::Errors::APIConnectionError => e
    status = e
  end
  headers = Straddle::Internal::Util.normalized_headers(response&.each_header&.to_h)

  case status
  in ..299
    [status, response, stream]
  in 300..399 if redirect_count >= self.class::MAX_REDIRECTS
    self.class.reap_connection!(status, stream: stream)

    message = "Failed to complete the request within #{self.class::MAX_REDIRECTS} redirects."
    raise Straddle::Errors::APIConnectionError.new(url: url, response: response, message: message)
  in 300..399
    self.class.reap_connection!(status, stream: stream)

    request = self.class.follow_redirect(request, status: status, response_headers: headers)
    send_request(
      request,
      redirect_count: redirect_count + 1,
      retry_count: retry_count,
      send_retry_header: send_retry_header
    )
  in Straddle::Errors::APIConnectionError if retry_count >= max_retries
    raise status
  in (400..) if retry_count >= max_retries || !self.class.should_retry?(status, headers: headers)
    decoded =
      Kernel.then do
        Straddle::Internal::Util.decode_content(headers, stream: stream, suppress_error: true)
      ensure
        self.class.reap_connection!(status, stream: stream)
      end

    raise Straddle::Errors::APIStatusError.for(
      url: url,
      status: status,
      headers: headers,
      body: decoded,
      request: nil,
      response: response
    )
  in 400.. | Straddle::Errors::APIConnectionError
    self.class.reap_connection!(status, stream: stream)

    delay = retry_delay(response || {}, retry_count: retry_count)
    sleep(delay)

    send_request(
      request,
      redirect_count: redirect_count,
      retry_count: retry_count + 1,
      send_retry_header: send_retry_header
    )
  end
end