Module: Straddle::Internal::Type::Union Private

Includes:
Converter, Util::SorbetRuntimeSupport
Included in:
Models::ComplianceProfile, Models::UnmaskedComplianceProfile, Models::UnwrapWebhookEvent
Defined in:
lib/straddle/internal/type/union.rb,
sig/straddle/internal/type/union.rbs

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, to_sorbet_type

Methods included from Converter

coerce, dump, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.derefed_variants ⇒ ::Array[[Symbol?, top, ::Hash[Symbol, top]]]

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (::Array[[Symbol?, top, ::Hash[Symbol, top]]])


10
# File 'sig/straddle/internal/type/union.rbs', line 10

def self.derefed_variants: -> ::Array[[Symbol?, top, ::Hash[Symbol, top]]]

.variants ⇒ ::Array[top]

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (::Array[top])


12
# File 'sig/straddle/internal/type/union.rbs', line 12

def self.variants: -> ::Array[top]

Instance Method Details

#==(other) ⇒ Boolean

Parameters:

  • other (Object)

Returns:



106
107
108
# File 'lib/straddle/internal/type/union.rb', line 106

def ==(other)
  Straddle::Internal::Type::Union === other && other.derefed_variants == derefed_variants
end

#===(other) ⇒ Boolean

Parameters:

  • other (Object)

Returns:



97
98
99
# File 'lib/straddle/internal/type/union.rb', line 97

def ===(other)
  known_variants.any? { |_, variant_fn| variant_fn.call === other }
end

#coerce(value, state:) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Tries to efficiently coerce the given value to one of the known variants.

If the value cannot match any of the known variants, the coercion is considered non-viable and returns the original value.

Parameters:

  • value (Object)
  • state (Hash{Symbol=>Object}) —

    .

    @option state [Boolean] :translate_names

    @option state [Boolean] :strictness

    @option state [HashSymbol=>Object] :exactness

    @option state [Class] :error

    @option state [Integer] :branched

Returns:

  • (Object)


137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/straddle/internal/type/union.rb', line 137

def coerce(value, state:)
  if (target = resolve_variant(value))
    return Straddle::Internal::Type::Converter.coerce(target, value, state: state)
  end

  strictness = state.fetch(:strictness)
  exactness = state.fetch(:exactness)

  alternatives = []
  known_variants.each do |_, variant_fn|
    target = variant_fn.call
    exact = state[:exactness] = {yes: 0, no: 0, maybe: 0}
    state[:branched] += 1

    coerced = Straddle::Internal::Type::Converter.coerce(target, value, state: state)
    yes, no, maybe = exact.values
    if (no + maybe).zero? || (!strictness && yes.positive?)
      exact.each { exactness[_1] += _2 }
      state[:exactness] = exactness
      return coerced
    elsif maybe.positive?
      alternatives << [[-yes, -maybe, no], exact, coerced]
    end
  end

  case alternatives.sort_by!(&:first)
  in []
    exactness[:no] += 1
    state[:error] = ArgumentError.new("no matching variant for #{value.inspect}")
    value
  in [[_, exact, coerced], *]
    exact.each { exactness[_1] += _2 }
    coerced
  end.tap { state[:exactness] = exactness }
ensure
  state[:strictness] = strictness
end

#dump(value, state:) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • value (Object)
  • state (Hash{Symbol=>Object}) —

    .

    @option state [Boolean] :can_retry

Returns:

  • (Object)


184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/straddle/internal/type/union.rb', line 184

def dump(value, state:)
  if (target = resolve_variant(value))
    return Straddle::Internal::Type::Converter.dump(target, value, state: state)
  end

  known_variants.each do
    target = _2.call
    return Straddle::Internal::Type::Converter.dump(target, value, state: state) if target === value
  end

  super
end

#hash ⇒ Integer

Returns:

  • (Integer)


113
# File 'lib/straddle/internal/type/union.rb', line 113

def hash = variants.hash

#inspect(depth: 0) ⇒ String

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • depth (Integer) (defaults to: 0)
  • depth: (Integer) (defaults to: 0)

Returns:

  • (String)


220
221
222
223
224
225
226
227
# File 'lib/straddle/internal/type/union.rb', line 220

def inspect(depth: 0)
  return is_a?(Module) ? super() : self.class.name if depth.positive?

  members = variants.map { Straddle::Internal::Type::Converter.inspect(_1, depth: depth.succ) }
  prefix = is_a?(Module) ? name : self.class.name

  "#{prefix}[#{members.join(" | ")}]"
end

#to_sorbet_type ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (Object)


200
201
202
203
204
205
206
207
208
209
210
# File 'lib/straddle/internal/type/union.rb', line 200

def to_sorbet_type
  types = variants.map { Straddle::Internal::Util::SorbetRuntimeSupport.to_sorbet_type(_1) }.uniq
  case types
  in []
    T.noreturn
  in [type]
    type
  else
    T.any(*types)
  end
end

#variants ⇒ Array<Object>

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

All of the specified variants for this union.

Returns:

  • (Array<Object>)


29
# File 'lib/straddle/internal/type/union.rb', line 29

def variants = derefed_variants.map { _2 }