Class: Straddle::Models::Account
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::Account
- Defined in:
- lib/straddle/models/account.rb,
sig/straddle/models/account.rbs
Defined Under Namespace
Modules: AccessLevel, Status, Type
Constant Summary collapse
- Straddle =
Instance Attribute Summary collapse
-
#access_level ⇒ Symbol, Straddle::Models::Account::AccessLevel
The account access level.
- #business_profile ⇒ Straddle::Models::AccountBusinessProfile?
- #capabilities ⇒ Straddle::Models::AccountCapabilities?
-
#created_at ⇒ Time?
Date and time when Straddle created the account.
-
#external_id ⇒ String?
Your unique ID for the account.
-
#id ⇒ String
Straddle's unique ID for the account.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
Up to 20 user-defined key-value pairs.
-
#organization_id ⇒ String
ID of the organization that owns the account.
- #settings ⇒ Straddle::Models::AccountPaymentSettings?
-
#status ⇒ Symbol, Straddle::Models::Account::Status
The current lifecycle status of the account.
- #status_detail ⇒ Straddle::Models::AccountStatusDetail
- #terms_of_service ⇒ Straddle::Models::TermsOfService?
-
#type ⇒ Symbol, Straddle::Models::Account::Type
The account type.
-
#updated_at ⇒ Time?
Date and time of the most recent account update.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, access_level:, organization_id:, status:, status_detail:, type:, business_profile: nil, capabilities: nil, created_at: nil, external_id: nil, metadata: nil, settings: nil, terms_of_service: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Account for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, access_level:, organization_id:, status:, status_detail:, type:, business_profile: nil, capabilities: nil, created_at: nil, external_id: nil, metadata: nil, settings: nil, terms_of_service: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::Account for more details.
|
|
# File 'lib/straddle/models/account.rb', line 87
|
Instance Attribute Details
#access_level ⇒ Symbol, Straddle::Models::Account::AccessLevel
The account access level. standard provides normal account access, including
access to the Straddle dashboard. managed means the platform manages the
account and account users cannot access the Straddle dashboard.
18 |
# File 'lib/straddle/models/account.rb', line 18 required :access_level, enum: -> { Straddle::Account::AccessLevel } |
#business_profile ⇒ Straddle::Models::AccountBusinessProfile?
46 |
# File 'lib/straddle/models/account.rb', line 46 optional :business_profile, -> { Straddle::AccountBusinessProfile } |
#capabilities ⇒ Straddle::Models::AccountCapabilities?
51 |
# File 'lib/straddle/models/account.rb', line 51 optional :capabilities, -> { Straddle::AccountCapabilities } |
#created_at ⇒ Time?
Date and time when Straddle created the account.
57 |
# File 'lib/straddle/models/account.rb', line 57 optional :created_at, Time, nil?: true |
#external_id ⇒ String?
Your unique ID for the account.
63 |
# File 'lib/straddle/models/account.rb', line 63 optional :external_id, String, nil?: true |
#id ⇒ String
Straddle's unique ID for the account.
10 |
# File 'lib/straddle/models/account.rb', line 10 required :id, String |
#metadata ⇒ Hash{Symbol=>String, nil}?
Up to 20 user-defined key-value pairs.
69 |
# File 'lib/straddle/models/account.rb', line 69 optional :metadata, Straddle::Internal::Type::HashOf[String, nil?: true], nil?: true |
#organization_id ⇒ String
ID of the organization that owns the account.
24 |
# File 'lib/straddle/models/account.rb', line 24 required :organization_id, String |
#settings ⇒ Straddle::Models::AccountPaymentSettings?
74 |
# File 'lib/straddle/models/account.rb', line 74 optional :settings, -> { Straddle::AccountPaymentSettings } |
#status ⇒ Symbol, Straddle::Models::Account::Status
The current lifecycle status of the account.
30 |
# File 'lib/straddle/models/account.rb', line 30 required :status, enum: -> { Straddle::Account::Status } |
#status_detail ⇒ Straddle::Models::AccountStatusDetail
35 |
# File 'lib/straddle/models/account.rb', line 35 required :status_detail, -> { Straddle::AccountStatusDetail } |
#terms_of_service ⇒ Straddle::Models::TermsOfService?
79 |
# File 'lib/straddle/models/account.rb', line 79 optional :terms_of_service, -> { Straddle::TermsOfService } |
#type ⇒ Symbol, Straddle::Models::Account::Type
The account type. Only business is supported.
41 |
# File 'lib/straddle/models/account.rb', line 41 required :type, enum: -> { Straddle::Account::Type } |
#updated_at ⇒ Time?
Date and time of the most recent account update.
85 |
# File 'lib/straddle/models/account.rb', line 85 optional :updated_at, Time, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/straddle/models/account.rb', line 130
|
Instance Method Details
#to_hash ⇒ {
83 |
# File 'sig/straddle/models/account.rbs', line 83
def to_hash: -> {
|