Module: Straddle::Models::Account::AccessLevel

Extended by:
Internal::Type::Enum
Defined in:
lib/straddle/models/account.rb,
sig/straddle/models/account.rbs

Overview

The account access level. standard provides normal account access, including access to the Straddle dashboard. managed means the platform manages the account and account users cannot access the Straddle dashboard.

See Also:

  • Straddle::Models::Account#access_level

Constant Summary collapse

STANDARD =

Returns:

  • (:standard)
:standard
MANAGED =

Returns:

  • (:managed)
:managed

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values ⇒ ::Array[Straddle::Models::Account::access_level]

Returns:

  • (::Array[Straddle::Models::Account::access_level])


108
# File 'sig/straddle/models/account.rbs', line 108

def self?.values: -> ::Array[Straddle::Models::Account::access_level]