Class: Straddle::Models::AccountBusinessProfile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/account_business_profile.rb,
sig/straddle/models/account_business_profile.rbs

Constant Summary collapse

Straddle =

Returns:

  • (:AccountSupportChannels)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, website:, address: nil, description: nil, industry: nil, legal_name: nil, phone: nil, support_channels: nil, tax_id: nil, use_case: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::AccountBusinessProfile for more details.

Parameters:

  • name (String) —

    The operating or trade name of the business.

  • website (String) —

    URL of the business's primary website.

  • address (Straddle::Models::AccountAddress, nil) (defaults to: nil) —

    Optional business address. If provided, line1, city, state, and `postal_co

  • description (String, nil) (defaults to: nil) —

    Description of the business and its products or services.

  • industry (Straddle::Models::AccountIndustry) (defaults to: nil)
  • legal_name (String, nil) (defaults to: nil) —

    The official registered name of the business.

  • phone (String, nil) (defaults to: nil) —

    Primary business phone number in E.164 format.

  • support_channels (Straddle::Models::AccountSupportChannels) (defaults to: nil)
  • tax_id (String, nil) (defaults to: nil) —

    Business tax identification number, such as a US Employer Identification Number

  • use_case (String, nil) (defaults to: nil) —

    How the business plans to use Straddle.



# File 'lib/straddle/models/account_business_profile.rb', line 66

Instance Attribute Details

#address ⇒ Straddle::Models::AccountAddress?

Optional business address. If provided, line1, city, state, and postal_code are required.

Parameters:

Returns:



23
# File 'lib/straddle/models/account_business_profile.rb', line 23

optional :address, -> { Straddle::AccountAddress }, nil?: true

#description ⇒ String?

Description of the business and its products or services.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


29
# File 'lib/straddle/models/account_business_profile.rb', line 29

optional :description, String, nil?: true

#industry ⇒ Straddle::Models::AccountIndustry?



34
# File 'lib/straddle/models/account_business_profile.rb', line 34

optional :industry, -> { Straddle::AccountIndustry }

The official registered name of the business.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


40
# File 'lib/straddle/models/account_business_profile.rb', line 40

optional :legal_name, String, nil?: true

#name ⇒ String

The operating or trade name of the business.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/account_business_profile.rb', line 10

required :name, String

#phone ⇒ String?

Primary business phone number in E.164 format.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


46
# File 'lib/straddle/models/account_business_profile.rb', line 46

optional :phone, String, nil?: true

#support_channels ⇒ Straddle::Models::AccountSupportChannels?



51
# File 'lib/straddle/models/account_business_profile.rb', line 51

optional :support_channels, -> { Straddle::AccountSupportChannels }

#tax_id ⇒ String?

Business tax identification number, such as a US Employer Identification Number (EIN).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


58
# File 'lib/straddle/models/account_business_profile.rb', line 58

optional :tax_id, String, nil?: true

#use_case ⇒ String?

How the business plans to use Straddle.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


64
# File 'lib/straddle/models/account_business_profile.rb', line 64

optional :use_case, String, nil?: true

#website ⇒ String

URL of the business's primary website.

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/straddle/models/account_business_profile.rb', line 16

required :website, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


57
# File 'sig/straddle/models/account_business_profile.rbs', line 57

def to_hash: -> {