Class: Straddle::Models::AccountCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/straddle/models/account_create_params.rb,
sig/straddle/models/account_create_params.rbs

Overview

See Also:

  • Straddle::Resources::Accounts#create

Defined Under Namespace

Modules: AccessLevel, AccountType

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_level:, account_type:, business_profile:, organization_id:, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::AccountCreateParams for more details.

Parameters:

  • access_level (Symbol, Straddle::Models::AccountCreateParams::AccessLevel) —

    The account access level. standard provides normal account access, including a

  • account_type (Symbol, Straddle::Models::AccountCreateParams::AccountType) —

    Account type. The only accepted value is business.

  • business_profile (Straddle::Models::AccountBusinessProfile)
  • organization_id (String) —

    ID of the organization that will own the account.

  • external_id (String, nil) (defaults to: nil) —

    Your unique ID for the account.

  • metadata (Hash{Symbol=>String, nil}, nil) (defaults to: nil) —

    Up to 20 user-defined key-value pairs.

  • correlation_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing a series of related requests.

  • idempotency_key (String) (defaults to: nil) —

    Optional client-generated key for an idempotent request.

  • request_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing one request.

  • request_options (Straddle::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/straddle/models/account_create_params.rb', line 65

Instance Attribute Details

#access_level ⇒ Symbol, Straddle::Models::AccountCreateParams::AccessLevel

The account access level. standard provides normal account access, including access to the Straddle dashboard. managed means the platform manages the account and account users cannot access the Straddle dashboard.

Parameters:

  • value (Straddle::Models::AccountCreateParams::access_level)

Returns:



16
# File 'lib/straddle/models/account_create_params.rb', line 16

required :access_level, enum: -> { Straddle::AccountCreateParams::AccessLevel }

#account_type ⇒ Symbol, Straddle::Models::AccountCreateParams::AccountType

Account type. The only accepted value is business.

Parameters:

  • value (Straddle::Models::AccountCreateParams::account_type)

Returns:



22
# File 'lib/straddle/models/account_create_params.rb', line 22

required :account_type, enum: -> { Straddle::AccountCreateParams::AccountType }

#business_profile ⇒ Straddle::Models::AccountBusinessProfile



27
# File 'lib/straddle/models/account_create_params.rb', line 27

required :business_profile, -> { Straddle::AccountBusinessProfile }

#correlation_id ⇒ String?

Optional client-generated identifier for tracing a series of related requests.

Parameters:

  • (String)

Returns:

  • (String, nil)


51
# File 'lib/straddle/models/account_create_params.rb', line 51

optional :correlation_id, String

#external_id ⇒ String?

Your unique ID for the account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


39
# File 'lib/straddle/models/account_create_params.rb', line 39

optional :external_id, String, nil?: true

#idempotency_key ⇒ String?

Optional client-generated key for an idempotent request.

Parameters:

  • (String)

Returns:

  • (String, nil)


57
# File 'lib/straddle/models/account_create_params.rb', line 57

optional :idempotency_key, String

#metadata ⇒ Hash{Symbol=>String, nil}?

Up to 20 user-defined key-value pairs.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


45
# File 'lib/straddle/models/account_create_params.rb', line 45

optional :metadata, Straddle::Internal::Type::HashOf[String, nil?: true], nil?: true

#organization_id ⇒ String

ID of the organization that will own the account.

Parameters:

  • value (String)

Returns:

  • (String)


33
# File 'lib/straddle/models/account_create_params.rb', line 33

required :organization_id, String

#request_id ⇒ String?

Optional client-generated identifier for tracing one request.

Parameters:

  • (String)

Returns:

  • (String, nil)


63
# File 'lib/straddle/models/account_create_params.rb', line 63

optional :request_id, String

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/straddle/models/account_create_params.rb', line 98

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


58
# File 'sig/straddle/models/account_create_params.rbs', line 58

def to_hash: -> {