Class: Straddle::Models::AccountListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::AccountListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/account_list_params.rb,
sig/straddle/models/account_list_params.rbs
Overview
Defined Under Namespace
Modules: SortOrder, Status, Type
Instance Attribute Summary collapse
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#external_id ⇒ String?
Your external ID for the account.
-
#page_number ⇒ Integer?
Page number.
-
#page_size ⇒ Integer?
Number of results per page.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#search_text ⇒ String?
Text to search for across account fields.
-
#sort_by ⇒ String?
Field used to sort results.
-
#sort_order ⇒ Symbol, ...
Sort direction.
-
#status ⇒ Symbol, ...
Account status to return.
-
#type ⇒ Symbol, ...
Account type to return.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
68 |
# File 'sig/straddle/models/account_list_params.rbs', line 68
def initialize: (
|
Instance Attribute Details
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
62 |
# File 'lib/straddle/models/account_list_params.rb', line 62 optional :correlation_id, String |
#external_id ⇒ String?
Your external ID for the account.
14 |
# File 'lib/straddle/models/account_list_params.rb', line 14 optional :external_id, String |
#page_number ⇒ Integer?
Page number. Defaults to 1.
20 |
# File 'lib/straddle/models/account_list_params.rb', line 20 optional :page_number, Integer |
#page_size ⇒ Integer?
Number of results per page. Defaults to 100. Maximum 1000.
26 |
# File 'lib/straddle/models/account_list_params.rb', line 26 optional :page_size, Integer |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
68 |
# File 'lib/straddle/models/account_list_params.rb', line 68 optional :request_id, String |
#search_text ⇒ String?
Text to search for across account fields.
32 |
# File 'lib/straddle/models/account_list_params.rb', line 32 optional :search_text, String |
#sort_by ⇒ String?
Field used to sort results. Defaults to id.
38 |
# File 'lib/straddle/models/account_list_params.rb', line 38 optional :sort_by, String |
#sort_order ⇒ Symbol, ...
Sort direction. Defaults to asc.
44 |
# File 'lib/straddle/models/account_list_params.rb', line 44 optional :sort_order, enum: -> { Straddle::AccountListParams::SortOrder } |
#status ⇒ Symbol, ...
Account status to return.
50 |
# File 'lib/straddle/models/account_list_params.rb', line 50 optional :status, enum: -> { Straddle::AccountListParams::Status } |
#type ⇒ Symbol, ...
Account type to return.
56 |
# File 'lib/straddle/models/account_list_params.rb', line 56 optional :type, enum: -> { Straddle::AccountListParams::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/straddle/models/account_list_params.rb', line 99
|
Instance Method Details
#to_hash ⇒ {
82 |
# File 'sig/straddle/models/account_list_params.rbs', line 82
def to_hash: -> {
|