Class: Straddle::Models::AccountOnboardParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::AccountOnboardParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/account_onboard_params.rb,
sig/straddle/models/account_onboard_params.rbs
Overview
Instance Attribute Summary collapse
- #account_id ⇒ String
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
- #terms_of_service ⇒ Straddle::Models::TermsOfService
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(account_id:, terms_of_service:, correlation_id: nil, idempotency_key: nil, request_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id:, terms_of_service:, correlation_id: nil, idempotency_key: nil, request_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/straddle/models/account_onboard_params.rb', line 38
|
Instance Attribute Details
#account_id ⇒ String
13 |
# File 'lib/straddle/models/account_onboard_params.rb', line 13 required :account_id, String |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
24 |
# File 'lib/straddle/models/account_onboard_params.rb', line 24 optional :correlation_id, String |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
30 |
# File 'lib/straddle/models/account_onboard_params.rb', line 30 optional :idempotency_key, String |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
36 |
# File 'lib/straddle/models/account_onboard_params.rb', line 36 optional :request_id, String |
#terms_of_service ⇒ Straddle::Models::TermsOfService
18 |
# File 'lib/straddle/models/account_onboard_params.rb', line 18 required :terms_of_service, -> { Straddle::TermsOfService } |
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/straddle/models/account_onboard_params.rbs', line 42
def to_hash: -> {
|