Class: Straddle::Models::AccountPayoutSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/account_payout_settings.rb,
sig/straddle/models/account_payout_settings.rbs

Defined Under Namespace

Modules: FundingTime

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(daily_amount:, funding_time:, linked_bank_account_id:, max_amount:, monthly_amount:, monthly_count:) ⇒ Object

Parameters:

  • daily_amount (Integer) —

    Daily payout amount limit in cents.

  • funding_time (Symbol, Straddle::Models::AccountPayoutSettings::FundingTime) —

    Funding schedule for payouts. Straddle sets this value.

  • linked_bank_account_id (String) —

    ID of the linked bank account used for payout settlement.

  • max_amount (Integer) —

    Maximum amount in cents for one payout.

  • monthly_amount (Integer) —

    Monthly payout amount limit in cents.

  • monthly_count (Integer) —

    Maximum number of payouts per calendar month.



# File 'lib/straddle/models/account_payout_settings.rb', line 42

Instance Attribute Details

#daily_amount ⇒ Integer

Daily payout amount limit in cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


10
# File 'lib/straddle/models/account_payout_settings.rb', line 10

required :daily_amount, Integer

#funding_time ⇒ Symbol, Straddle::Models::AccountPayoutSettings::FundingTime

Funding schedule for payouts. Straddle sets this value.

Parameters:

  • value (Straddle::Models::AccountPayoutSettings::funding_time)

Returns:



16
# File 'lib/straddle/models/account_payout_settings.rb', line 16

required :funding_time, enum: -> { Straddle::AccountPayoutSettings::FundingTime }

#linked_bank_account_id ⇒ String

ID of the linked bank account used for payout settlement.

Parameters:

  • value (String)

Returns:

  • (String)


22
# File 'lib/straddle/models/account_payout_settings.rb', line 22

required :linked_bank_account_id, String

#max_amount ⇒ Integer

Maximum amount in cents for one payout.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


28
# File 'lib/straddle/models/account_payout_settings.rb', line 28

required :max_amount, Integer

#monthly_amount ⇒ Integer

Monthly payout amount limit in cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


34
# File 'lib/straddle/models/account_payout_settings.rb', line 34

required :monthly_amount, Integer

#monthly_count ⇒ Integer

Maximum number of payouts per calendar month.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


40
# File 'lib/straddle/models/account_payout_settings.rb', line 40

required :monthly_count, Integer

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


35
# File 'sig/straddle/models/account_payout_settings.rbs', line 35

def to_hash: -> {