Class: Straddle::Models::AccountUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::AccountUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/account_update_params.rb,
sig/straddle/models/account_update_params.rbs
Overview
Instance Attribute Summary collapse
- #account_id ⇒ String
- #business_profile ⇒ Straddle::Models::AccountBusinessProfile
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#external_id ⇒ String?
Your unique ID for the account.
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
Up to 20 user-defined key-value pairs.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(account_id:, business_profile:, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id:, business_profile:, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/straddle/models/account_update_params.rb', line 50
|
Instance Attribute Details
#account_id ⇒ String
13 |
# File 'lib/straddle/models/account_update_params.rb', line 13 required :account_id, String |
#business_profile ⇒ Straddle::Models::AccountBusinessProfile
18 |
# File 'lib/straddle/models/account_update_params.rb', line 18 required :business_profile, -> { Straddle::AccountBusinessProfile } |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
36 |
# File 'lib/straddle/models/account_update_params.rb', line 36 optional :correlation_id, String |
#external_id ⇒ String?
Your unique ID for the account.
24 |
# File 'lib/straddle/models/account_update_params.rb', line 24 optional :external_id, String, nil?: true |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
42 |
# File 'lib/straddle/models/account_update_params.rb', line 42 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String, nil}?
Up to 20 user-defined key-value pairs.
30 |
# File 'lib/straddle/models/account_update_params.rb', line 30 optional :metadata, Straddle::Internal::Type::HashOf[String, nil?: true], nil?: true |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
48 |
# File 'lib/straddle/models/account_update_params.rb', line 48 optional :request_id, String |
Instance Method Details
#to_hash ⇒ {
50 |
# File 'sig/straddle/models/account_update_params.rbs', line 50
def to_hash: -> {
|