Class: Straddle::Models::BridgeCreateBankAccountPaykeyParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::BridgeCreateBankAccountPaykeyParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/bridge_create_bank_account_paykey_params.rb,
sig/straddle/models/bridge_create_bank_account_paykey_params.rbs
Overview
Constant Summary collapse
- Straddle =
Instance Attribute Summary collapse
-
#account_number ⇒ String
Bank account number.
- #account_type ⇒ Symbol, Straddle::Models::AccountType
- #config ⇒ Straddle::Models::PaykeyConfiguration?
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#customer_id ⇒ String
Unique identifier for the customer associated with the paykey.
-
#external_id ⇒ String?
Unique identifier for the paykey in your system.
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined key-value pairs associated with the paykey.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#routing_number ⇒ String
Bank routing number.
-
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(account_number:, account_type:, customer_id:, routing_number:, config: nil, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_number:, account_type:, customer_id:, routing_number:, config: nil, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 74
|
Instance Attribute Details
#account_number ⇒ String
Bank account number.
14 |
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 14 required :account_number, String |
#account_type ⇒ Symbol, Straddle::Models::AccountType
19 |
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 19 required :account_type, enum: -> { Straddle::AccountType } |
#config ⇒ Straddle::Models::PaykeyConfiguration?
36 |
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 36 optional :config, -> { Straddle::PaykeyConfiguration } |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
54 |
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 54 optional :correlation_id, String |
#customer_id ⇒ String
Unique identifier for the customer associated with the paykey.
25 |
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 25 required :customer_id, String |
#external_id ⇒ String?
Unique identifier for the paykey in your system.
42 |
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 42 optional :external_id, String, nil?: true |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
60 |
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 60 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined key-value pairs associated with the paykey.
48 |
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 48 optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
66 |
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 66 optional :request_id, String |
#routing_number ⇒ String
Bank routing number.
31 |
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 31 required :routing_number, String |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
72 |
# File 'lib/straddle/models/bridge_create_bank_account_paykey_params.rb', line 72 optional :straddle_account_id, String |
Instance Method Details
#to_hash ⇒ {
72 |
# File 'sig/straddle/models/bridge_create_bank_account_paykey_params.rbs', line 72
def to_hash: -> {
|