Class: Straddle::Models::BridgeCreatePlaidPaykeyParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/straddle/models/bridge_create_plaid_paykey_params.rb,
sig/straddle/models/bridge_create_plaid_paykey_params.rbs

Overview

See Also:

  • Straddle::Resources::Bridge#create_plaid_paykey

Constant Summary collapse

Straddle =

Returns:

  • (:PaykeyConfiguration)

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(customer_id:, plaid_token:, config: nil, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::BridgeCreatePlaidPaykeyParams for more details.

Parameters:

  • customer_id (String) —

    Unique identifier for the customer associated with the paykey.

  • plaid_token (String) —

    Plaid processor token generated by your application for use with the Straddle AP

  • config (Straddle::Models::PaykeyConfiguration) (defaults to: nil)
  • external_id (String, nil) (defaults to: nil) —

    Unique identifier for the paykey in your system.

  • metadata (Hash{Symbol=>String}, nil) (defaults to: nil) —

    Up to 20 user-defined key-value pairs associated with the paykey.

  • correlation_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing a series of related requests.

  • idempotency_key (String) (defaults to: nil) —

    Optional client-generated key for an idempotent request.

  • request_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing one request.

  • straddle_account_id (String) (defaults to: nil) —

    For platform requests, the embedded account UUID that sets the request scope.

  • request_options (Straddle::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/straddle/models/bridge_create_plaid_paykey_params.rb', line 64

Instance Attribute Details

#config ⇒ Straddle::Models::PaykeyConfiguration?



26
# File 'lib/straddle/models/bridge_create_plaid_paykey_params.rb', line 26

optional :config, -> { Straddle::PaykeyConfiguration }

#correlation_id ⇒ String?

Optional client-generated identifier for tracing a series of related requests.

Parameters:

  • (String)

Returns:

  • (String, nil)


44
# File 'lib/straddle/models/bridge_create_plaid_paykey_params.rb', line 44

optional :correlation_id, String

#customer_id ⇒ String

Unique identifier for the customer associated with the paykey.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/straddle/models/bridge_create_plaid_paykey_params.rb', line 14

required :customer_id, String

#external_id ⇒ String?

Unique identifier for the paykey in your system.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


32
# File 'lib/straddle/models/bridge_create_plaid_paykey_params.rb', line 32

optional :external_id, String, nil?: true

#idempotency_key ⇒ String?

Optional client-generated key for an idempotent request.

Parameters:

  • (String)

Returns:

  • (String, nil)


50
# File 'lib/straddle/models/bridge_create_plaid_paykey_params.rb', line 50

optional :idempotency_key, String

#metadata ⇒ Hash{Symbol=>String}?

Up to 20 user-defined key-value pairs associated with the paykey.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


38
# File 'lib/straddle/models/bridge_create_plaid_paykey_params.rb', line 38

optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true

#plaid_token ⇒ String

Plaid processor token generated by your application for use with the Straddle API.

Parameters:

  • value (String)

Returns:

  • (String)


21
# File 'lib/straddle/models/bridge_create_plaid_paykey_params.rb', line 21

required :plaid_token, String

#request_id ⇒ String?

Optional client-generated identifier for tracing one request.

Parameters:

  • (String)

Returns:

  • (String, nil)


56
# File 'lib/straddle/models/bridge_create_plaid_paykey_params.rb', line 56

optional :request_id, String

#straddle_account_id ⇒ String?

For platform requests, the embedded account UUID that sets the request scope.

Parameters:

  • (String)

Returns:

  • (String, nil)


62
# File 'lib/straddle/models/bridge_create_plaid_paykey_params.rb', line 62

optional :straddle_account_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


64
# File 'sig/straddle/models/bridge_create_plaid_paykey_params.rbs', line 64

def to_hash: -> {