Class: Straddle::Models::BridgeCreateQuilttPaykeyParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::BridgeCreateQuilttPaykeyParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/bridge_create_quiltt_paykey_params.rb,
sig/straddle/models/bridge_create_quiltt_paykey_params.rbs
Overview
Constant Summary collapse
- Straddle =
Instance Attribute Summary collapse
- #config ⇒ Straddle::Models::PaykeyConfiguration?
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#customer_id ⇒ String
Unique identifier for the customer associated with the paykey.
-
#external_id ⇒ String?
Unique identifier for the paykey in your system.
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined key-value pairs associated with the paykey.
-
#quiltt_token ⇒ String
Quiltt processor token generated by your application for use with the Straddle API.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(customer_id:, quiltt_token:, config: nil, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BridgeCreateQuilttPaykeyParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(customer_id:, quiltt_token:, config: nil, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::BridgeCreateQuilttPaykeyParams for more details.
|
|
# File 'lib/straddle/models/bridge_create_quiltt_paykey_params.rb', line 64
|
Instance Attribute Details
#config ⇒ Straddle::Models::PaykeyConfiguration?
26 |
# File 'lib/straddle/models/bridge_create_quiltt_paykey_params.rb', line 26 optional :config, -> { Straddle::PaykeyConfiguration } |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
44 |
# File 'lib/straddle/models/bridge_create_quiltt_paykey_params.rb', line 44 optional :correlation_id, String |
#customer_id ⇒ String
Unique identifier for the customer associated with the paykey.
14 |
# File 'lib/straddle/models/bridge_create_quiltt_paykey_params.rb', line 14 required :customer_id, String |
#external_id ⇒ String?
Unique identifier for the paykey in your system.
32 |
# File 'lib/straddle/models/bridge_create_quiltt_paykey_params.rb', line 32 optional :external_id, String, nil?: true |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
50 |
# File 'lib/straddle/models/bridge_create_quiltt_paykey_params.rb', line 50 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined key-value pairs associated with the paykey.
38 |
# File 'lib/straddle/models/bridge_create_quiltt_paykey_params.rb', line 38 optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true |
#quiltt_token ⇒ String
Quiltt processor token generated by your application for use with the Straddle API.
21 |
# File 'lib/straddle/models/bridge_create_quiltt_paykey_params.rb', line 21 required :quiltt_token, String |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
56 |
# File 'lib/straddle/models/bridge_create_quiltt_paykey_params.rb', line 56 optional :request_id, String |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
62 |
# File 'lib/straddle/models/bridge_create_quiltt_paykey_params.rb', line 62 optional :straddle_account_id, String |
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/straddle/models/bridge_create_quiltt_paykey_params.rbs', line 64
def to_hash: -> {
|