Class: Straddle::Models::BridgeCreateTokenParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::BridgeCreateTokenParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/bridge_create_token_params.rb,
sig/straddle/models/bridge_create_token_params.rbs
Overview
Constant Summary collapse
- Straddle =
Instance Attribute Summary collapse
- #config ⇒ Straddle::Models::PaykeyConfiguration?
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#customer_id ⇒ String
Unique identifier for the customer associated with the Bridge session.
-
#external_id ⇒ String?
Unique identifier for the paykey in your system.
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(customer_id:, config: nil, external_id: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(customer_id:, config: nil, external_id: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/straddle/models/bridge_create_token_params.rb', line 51
|
Instance Attribute Details
#config ⇒ Straddle::Models::PaykeyConfiguration?
19 |
# File 'lib/straddle/models/bridge_create_token_params.rb', line 19 optional :config, -> { Straddle::PaykeyConfiguration } |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
31 |
# File 'lib/straddle/models/bridge_create_token_params.rb', line 31 optional :correlation_id, String |
#customer_id ⇒ String
Unique identifier for the customer associated with the Bridge session.
14 |
# File 'lib/straddle/models/bridge_create_token_params.rb', line 14 required :customer_id, String |
#external_id ⇒ String?
Unique identifier for the paykey in your system.
25 |
# File 'lib/straddle/models/bridge_create_token_params.rb', line 25 optional :external_id, String, nil?: true |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
37 |
# File 'lib/straddle/models/bridge_create_token_params.rb', line 37 optional :idempotency_key, String |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
43 |
# File 'lib/straddle/models/bridge_create_token_params.rb', line 43 optional :request_id, String |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
49 |
# File 'lib/straddle/models/bridge_create_token_params.rb', line 49 optional :straddle_account_id, String |
Instance Method Details
#to_hash ⇒ {
56 |
# File 'sig/straddle/models/bridge_create_token_params.rbs', line 56
def to_hash: -> {
|