Class: Straddle::Models::CapabilityRequestCreateParams::Charges
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::CapabilityRequestCreateParams::Charges
- Defined in:
- lib/straddle/models/capability_request_create_params.rb,
sig/straddle/models/capability_request_create_params.rbs
Instance Attribute Summary collapse
-
#daily_amount ⇒ Float
Daily charge amount limit in cents.
-
#enable ⇒ Boolean
Whether to enable or disable charges for the account.
-
#max_amount ⇒ Float
Maximum amount in cents for one charge.
-
#monthly_amount ⇒ Float
Monthly charge amount limit in cents.
-
#monthly_count ⇒ Integer
Maximum number of charges per calendar month.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
130 |
# File 'sig/straddle/models/capability_request_create_params.rbs', line 130
def initialize: (
|
Instance Attribute Details
#daily_amount ⇒ Float
Daily charge amount limit in cents.
110 |
# File 'lib/straddle/models/capability_request_create_params.rb', line 110 required :daily_amount, Float |
#enable ⇒ Boolean
Whether to enable or disable charges for the account.
116 |
# File 'lib/straddle/models/capability_request_create_params.rb', line 116 required :enable, Straddle::Internal::Type::Boolean |
#max_amount ⇒ Float
Maximum amount in cents for one charge.
122 |
# File 'lib/straddle/models/capability_request_create_params.rb', line 122 required :max_amount, Float |
#monthly_amount ⇒ Float
Monthly charge amount limit in cents.
128 |
# File 'lib/straddle/models/capability_request_create_params.rb', line 128 required :monthly_amount, Float |
#monthly_count ⇒ Integer
Maximum number of charges per calendar month.
134 |
# File 'lib/straddle/models/capability_request_create_params.rb', line 134 required :monthly_count, Integer |
Instance Method Details
#to_hash ⇒ {
138 |
# File 'sig/straddle/models/capability_request_create_params.rbs', line 138
def to_hash: -> {
|