Class: Straddle::Models::CapabilityRequestCreateParams::Payouts
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::CapabilityRequestCreateParams::Payouts
- Defined in:
- lib/straddle/models/capability_request_create_params.rb,
sig/straddle/models/capability_request_create_params.rbs
Instance Attribute Summary collapse
-
#daily_amount ⇒ Float
Daily payout amount limit in cents.
-
#enable ⇒ Boolean
Whether to enable or disable payouts for the account.
-
#max_amount ⇒ Float
Maximum amount in cents for one payout.
-
#monthly_amount ⇒ Float
Monthly payout amount limit in cents.
-
#monthly_count ⇒ Integer
Maximum number of payouts per calendar month.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
187 |
# File 'sig/straddle/models/capability_request_create_params.rbs', line 187
def initialize: (
|
Instance Attribute Details
#daily_amount ⇒ Float
Daily payout amount limit in cents.
181 |
# File 'lib/straddle/models/capability_request_create_params.rb', line 181 required :daily_amount, Float |
#enable ⇒ Boolean
Whether to enable or disable payouts for the account.
187 |
# File 'lib/straddle/models/capability_request_create_params.rb', line 187 required :enable, Straddle::Internal::Type::Boolean |
#max_amount ⇒ Float
Maximum amount in cents for one payout.
193 |
# File 'lib/straddle/models/capability_request_create_params.rb', line 193 required :max_amount, Float |
#monthly_amount ⇒ Float
Monthly payout amount limit in cents.
199 |
# File 'lib/straddle/models/capability_request_create_params.rb', line 199 required :monthly_amount, Float |
#monthly_count ⇒ Integer
Maximum number of payouts per calendar month.
205 |
# File 'lib/straddle/models/capability_request_create_params.rb', line 205 required :monthly_count, Integer |
Instance Method Details
#to_hash ⇒ {
195 |
# File 'sig/straddle/models/capability_request_create_params.rbs', line 195
def to_hash: -> {
|