Class: Straddle::Models::ChargeCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::ChargeCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/charge_create_params.rb,
sig/straddle/models/charge_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Amount in cents.
- #config ⇒ Straddle::Models::ChargeConfiguration
-
#consent_type ⇒ Symbol, Straddle::Models::ConsentType
How the customer authorized the charge.
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#currency ⇒ String
Currency code.
-
#description ⇒ String?
Description shown on the customer's bank statement where supported.
- #device ⇒ Straddle::Models::PaymentDevice
-
#external_id ⇒ String
Your unique identifier for the charge.
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined string key-value pairs.
-
#paykey ⇒ String
The paykey token that identifies the customer's bank account.
-
#payment_date ⇒ Date
Date when Straddle submits the charge for processing.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(amount:, config:, consent_type:, currency:, description:, device:, external_id:, paykey:, payment_date:, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ChargeCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, config:, consent_type:, currency:, description:, device:, external_id:, paykey:, payment_date:, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::ChargeCreateParams for more details.
|
|
# File 'lib/straddle/models/charge_create_params.rb', line 93
|
Instance Attribute Details
#amount ⇒ Integer
Amount in cents.
14 |
# File 'lib/straddle/models/charge_create_params.rb', line 14 required :amount, Integer |
#config ⇒ Straddle::Models::ChargeConfiguration
19 |
# File 'lib/straddle/models/charge_create_params.rb', line 19 required :config, -> { Straddle::ChargeConfiguration } |
#consent_type ⇒ Symbol, Straddle::Models::ConsentType
How the customer authorized the charge. internet covers online and mobile
authorization. signed covers written or PDF-signed agreements.
26 |
# File 'lib/straddle/models/charge_create_params.rb', line 26 required :consent_type, enum: -> { Straddle::ConsentType } |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
73 |
# File 'lib/straddle/models/charge_create_params.rb', line 73 optional :correlation_id, String |
#currency ⇒ String
Currency code. Only USD is supported.
32 |
# File 'lib/straddle/models/charge_create_params.rb', line 32 required :currency, String |
#description ⇒ String?
Description shown on the customer's bank statement where supported.
38 |
# File 'lib/straddle/models/charge_create_params.rb', line 38 required :description, String, nil?: true |
#device ⇒ Straddle::Models::PaymentDevice
43 |
# File 'lib/straddle/models/charge_create_params.rb', line 43 required :device, -> { Straddle::PaymentDevice } |
#external_id ⇒ String
Your unique identifier for the charge. Must be unique across charges.
49 |
# File 'lib/straddle/models/charge_create_params.rb', line 49 required :external_id, String |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
79 |
# File 'lib/straddle/models/charge_create_params.rb', line 79 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined string key-value pairs.
67 |
# File 'lib/straddle/models/charge_create_params.rb', line 67 optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true |
#paykey ⇒ String
The paykey token that identifies the customer's bank account.
55 |
# File 'lib/straddle/models/charge_create_params.rb', line 55 required :paykey, String |
#payment_date ⇒ Date
Date when Straddle submits the charge for processing.
61 |
# File 'lib/straddle/models/charge_create_params.rb', line 61 required :payment_date, Date |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
85 |
# File 'lib/straddle/models/charge_create_params.rb', line 85 optional :request_id, String |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
91 |
# File 'lib/straddle/models/charge_create_params.rb', line 91 optional :straddle_account_id, String |
Instance Method Details
#to_hash ⇒ {
80 |
# File 'sig/straddle/models/charge_create_params.rbs', line 80
def to_hash: -> {
|