Class: Straddle::Models::ChargeCreatedV1WebhookEvent::Data::CustomerDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::ChargeCreatedV1WebhookEvent::Data::CustomerDetails
- Defined in:
- lib/straddle/models/charge_created_v1_webhook_event.rb,
sig/straddle/models/charge_created_v1_webhook_event.rbs
Overview
Instance Attribute Summary collapse
-
#customer_type ⇒ Symbol, Straddle::Models::CustomerType
Whether the customer is an individual or a business.
-
#email ⇒ String
Customer's email address.
-
#id ⇒ String
Unique identifier for the customer.
-
#name ⇒ String
Customer's full name or business name.
-
#phone ⇒ String
Customer's phone number in E.164 format.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
472 |
# File 'sig/straddle/models/charge_created_v1_webhook_event.rbs', line 472 def initialize: ( |
Instance Attribute Details
#customer_type ⇒ Symbol, Straddle::Models::CustomerType
Whether the customer is an individual or a business.
483 |
# File 'lib/straddle/models/charge_created_v1_webhook_event.rb', line 483 required :customer_type, enum: -> { Straddle::CustomerType } |
#email ⇒ String
Customer's email address.
489 |
# File 'lib/straddle/models/charge_created_v1_webhook_event.rb', line 489 required :email, String |
#id ⇒ String
Unique identifier for the customer.
477 |
# File 'lib/straddle/models/charge_created_v1_webhook_event.rb', line 477 required :id, String |
#name ⇒ String
Customer's full name or business name.
495 |
# File 'lib/straddle/models/charge_created_v1_webhook_event.rb', line 495 required :name, String |
#phone ⇒ String
Customer's phone number in E.164 format.
501 |
# File 'lib/straddle/models/charge_created_v1_webhook_event.rb', line 501 required :phone, String |
Instance Method Details
#to_hash ⇒ {
480 |
# File 'sig/straddle/models/charge_created_v1_webhook_event.rbs', line 480 def to_hash: -> { |