Class: Straddle::Models::ChargeCreatedV1WebhookEvent::Data::PaykeyDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/charge_created_v1_webhook_event.rb,
sig/straddle/models/charge_created_v1_webhook_event.rbs

Overview

See Also:

  • Straddle::Models::ChargeCreatedV1WebhookEvent::Data#paykey_details

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



501
# File 'sig/straddle/models/charge_created_v1_webhook_event.rbs', line 501

def initialize: (

Instance Attribute Details

#balance ⇒ Integer?

Available balance in cents when a balance check was performed. Null otherwise.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


539
# File 'lib/straddle/models/charge_created_v1_webhook_event.rb', line 539

optional :balance, Integer, nil?: true

#customer_id ⇒ String

Unique identifier for the customer associated with the paykey.

Parameters:

  • value (String)

Returns:

  • (String)


527
# File 'lib/straddle/models/charge_created_v1_webhook_event.rb', line 527

required :customer_id, String

#id ⇒ String

Unique identifier for the paykey.

Parameters:

  • value (String)

Returns:

  • (String)


521
# File 'lib/straddle/models/charge_created_v1_webhook_event.rb', line 521

required :id, String

#label ⇒ String

Display label combining the bank name and masked account number.

Parameters:

  • value (String)

Returns:

  • (String)


533
# File 'lib/straddle/models/charge_created_v1_webhook_event.rb', line 533

required :label, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


508
# File 'sig/straddle/models/charge_created_v1_webhook_event.rbs', line 508

def to_hash: -> {