Class: Straddle::Models::ChargeEventV1WebhookEvent::Data::PaykeyDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::ChargeEventV1WebhookEvent::Data::PaykeyDetails
- Defined in:
- lib/straddle/models/charge_event_v1_webhook_event.rb,
sig/straddle/models/charge_event_v1_webhook_event.rbs
Overview
Instance Attribute Summary collapse
-
#balance ⇒ Integer?
Available balance in cents when a balance check was performed.
-
#customer_id ⇒ String
Unique identifier for the customer associated with the paykey.
-
#id ⇒ String
Unique identifier for the paykey.
-
#label ⇒ String
Display label combining the bank name and masked account number.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
501 |
# File 'sig/straddle/models/charge_event_v1_webhook_event.rbs', line 501
def initialize: (
|
Instance Attribute Details
#balance ⇒ Integer?
Available balance in cents when a balance check was performed. Null otherwise.
537 |
# File 'lib/straddle/models/charge_event_v1_webhook_event.rb', line 537 optional :balance, Integer, nil?: true |
#customer_id ⇒ String
Unique identifier for the customer associated with the paykey.
525 |
# File 'lib/straddle/models/charge_event_v1_webhook_event.rb', line 525 required :customer_id, String |
#id ⇒ String
Unique identifier for the paykey.
519 |
# File 'lib/straddle/models/charge_event_v1_webhook_event.rb', line 519 required :id, String |
#label ⇒ String
Display label combining the bank name and masked account number.
531 |
# File 'lib/straddle/models/charge_event_v1_webhook_event.rb', line 531 required :label, String |
Instance Method Details
#to_hash ⇒ {
508 |
# File 'sig/straddle/models/charge_event_v1_webhook_event.rbs', line 508
def to_hash: -> {
|