Class: Straddle::Models::ChargeResubmitParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/straddle/models/charge_resubmit_params.rb,
sig/straddle/models/charge_resubmit_params.rbs

Overview

See Also:

  • Straddle::Resources::Charges#resubmit

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, description: nil, external_id: nil, payment_date: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::ChargeResubmitParams for more details.

Parameters:

  • id (String)
  • description (String, nil) (defaults to: nil) —

    Description for the resubmitted charge. Defaults to the original description if

  • external_id (String, nil) (defaults to: nil) —

    Your unique identifier for the resubmitted charge. Defaults to a new value if om

  • payment_date (Date, nil) (defaults to: nil) —

    Date when Straddle submits the resubmitted charge for processing. Defaults to to

  • correlation_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing a series of related requests.

  • idempotency_key (String) (defaults to: nil) —

    Optional client-generated key for an idempotent request.

  • request_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing one request.

  • straddle_account_id (String) (defaults to: nil) —

    For platform requests, the embedded account UUID that sets the request scope.

  • request_options (Straddle::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/straddle/models/charge_resubmit_params.rb', line 60

Instance Attribute Details

#correlation_id ⇒ String?

Optional client-generated identifier for tracing a series of related requests.

Parameters:

  • (String)

Returns:

  • (String, nil)


40
# File 'lib/straddle/models/charge_resubmit_params.rb', line 40

optional :correlation_id, String

#description ⇒ String?

Description for the resubmitted charge. Defaults to the original description if omitted.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


20
# File 'lib/straddle/models/charge_resubmit_params.rb', line 20

optional :description, String, nil?: true

#external_id ⇒ String?

Your unique identifier for the resubmitted charge. Defaults to a new value if omitted.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


27
# File 'lib/straddle/models/charge_resubmit_params.rb', line 27

optional :external_id, String, nil?: true

#id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/straddle/models/charge_resubmit_params.rb', line 13

required :id, String

#idempotency_key ⇒ String?

Optional client-generated key for an idempotent request.

Parameters:

  • (String)

Returns:

  • (String, nil)


46
# File 'lib/straddle/models/charge_resubmit_params.rb', line 46

optional :idempotency_key, String

#payment_date ⇒ Date?

Date when Straddle submits the resubmitted charge for processing. Defaults to today if omitted.

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


34
# File 'lib/straddle/models/charge_resubmit_params.rb', line 34

optional :payment_date, Date, nil?: true

#request_id ⇒ String?

Optional client-generated identifier for tracing one request.

Parameters:

  • (String)

Returns:

  • (String, nil)


52
# File 'lib/straddle/models/charge_resubmit_params.rb', line 52

optional :request_id, String

#straddle_account_id ⇒ String?

For platform requests, the embedded account UUID that sets the request scope.

Parameters:

  • (String)

Returns:

  • (String, nil)


58
# File 'lib/straddle/models/charge_resubmit_params.rb', line 58

optional :straddle_account_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


56
# File 'sig/straddle/models/charge_resubmit_params.rbs', line 56

def to_hash: -> {