Class: Straddle::Models::ChargeUploadAuthorizationProofParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::ChargeUploadAuthorizationProofParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/charge_upload_authorization_proof_params.rb,
sig/straddle/models/charge_upload_authorization_proof_params.rbs
Overview
Instance Attribute Summary collapse
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#file ⇒ Pathname, ...
The document file to upload as proof of authorization for this charge.
- #id ⇒ String
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, file:, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ChargeUploadAuthorizationProofParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, file:, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::ChargeUploadAuthorizationProofParams for more details.
|
|
# File 'lib/straddle/models/charge_upload_authorization_proof_params.rb', line 49
|
Instance Attribute Details
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
29 |
# File 'lib/straddle/models/charge_upload_authorization_proof_params.rb', line 29 optional :correlation_id, String |
#file ⇒ Pathname, ...
The document file to upload as proof of authorization for this charge. Supported file types are PDF (.pdf), PNG (.png), JPEG (.jpg, .jpeg), Word (.doc), and Word (.docx), with a maximum file size of 10 MiB (10,485,760 bytes). Empty (0-byte) files are rejected. Uploaded files are validated for matching file signatures (magic bytes) and file extension agreement.
23 |
# File 'lib/straddle/models/charge_upload_authorization_proof_params.rb', line 23 required :file, Straddle::Internal::Type::FileInput, api_name: :File |
#id ⇒ String
13 |
# File 'lib/straddle/models/charge_upload_authorization_proof_params.rb', line 13 required :id, String |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
35 |
# File 'lib/straddle/models/charge_upload_authorization_proof_params.rb', line 35 optional :idempotency_key, String |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
41 |
# File 'lib/straddle/models/charge_upload_authorization_proof_params.rb', line 41 optional :request_id, String |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
47 |
# File 'lib/straddle/models/charge_upload_authorization_proof_params.rb', line 47 optional :straddle_account_id, String |
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/straddle/models/charge_upload_authorization_proof_params.rbs', line 48
def to_hash: -> {
|