Class: Straddle::Models::CustomerCreatedV1WebhookEvent::Data::ComplianceProfile
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::CustomerCreatedV1WebhookEvent::Data::ComplianceProfile
- Defined in:
- lib/straddle/models/customer_created_v1_webhook_event.rb,
sig/straddle/models/customer_created_v1_webhook_event.rbs
Overview
Instance Attribute Summary collapse
-
#dob ⇒ String?
Masked date of birth for an individual customer in
****-**-**format. -
#ein ⇒ String?
Masked Employer Identification Number for a business customer in
**-*******format. -
#legal_business_name ⇒ String?
Official registered name of the business customer.
-
#ssn ⇒ String?
Masked Social Security number for an individual customer in
***-**-****format. -
#website ⇒ String?
Official website URL for the business customer.
Instance Method Summary collapse
-
#initialize(dob: nil, ein: nil, legal_business_name: nil, ssn: nil, website: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ComplianceProfile for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(dob: nil, ein: nil, legal_business_name: nil, ssn: nil, website: nil) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::CustomerCreatedV1WebhookEvent::Data::ComplianceProfile for more details.
|
|
# File 'lib/straddle/models/customer_created_v1_webhook_event.rb', line 232
|
Instance Attribute Details
#dob ⇒ String?
Masked date of birth for an individual customer in ****-**-** format.
204 |
# File 'lib/straddle/models/customer_created_v1_webhook_event.rb', line 204 optional :dob, String, nil?: true |
#ein ⇒ String?
Masked Employer Identification Number for a business customer in **-*******
format.
211 |
# File 'lib/straddle/models/customer_created_v1_webhook_event.rb', line 211 optional :ein, String, nil?: true |
#legal_business_name ⇒ String?
Official registered name of the business customer.
217 |
# File 'lib/straddle/models/customer_created_v1_webhook_event.rb', line 217 optional :legal_business_name, String, nil?: true |
#ssn ⇒ String?
Masked Social Security number for an individual customer in ***-**-****
format.
224 |
# File 'lib/straddle/models/customer_created_v1_webhook_event.rb', line 224 optional :ssn, String, nil?: true |
#website ⇒ String?
Official website URL for the business customer.
230 |
# File 'lib/straddle/models/customer_created_v1_webhook_event.rb', line 230 optional :website, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
197 |
# File 'sig/straddle/models/customer_created_v1_webhook_event.rbs', line 197
def to_hash: -> {
|