Class: Straddle::Models::CustomerEventV1WebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/customer_event_v1_webhook_event.rb,
sig/straddle/models/customer_event_v1_webhook_event.rbs

Overview

See Also:

  • Straddle::Models::CustomerEventV1WebhookEvent#data

Defined Under Namespace

Modules: Status Classes: Address, ComplianceProfile

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address1:, city:, state:, zip:, address2: nil) ⇒ Object

Parameters:

  • address1 (String) —

    Primary address line, such as a street address or PO Box.

  • city (String) —

    City, district, suburb, town, or village.

  • state (String) —

    Two-letter state code.

  • zip (String) —

    ZIP or postal code.

  • address2 (String, nil) (defaults to: nil) —

    Secondary address line, such as an apartment, suite, unit, or building.



# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 113

Instance Attribute Details

#address ⇒ Straddle::Models::CustomerEventV1WebhookEvent::Data::Address?



94
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 94

optional :address, -> { Straddle::CustomerEventV1WebhookEvent::Data::Address }

#compliance_profile ⇒ Straddle::Models::CustomerEventV1WebhookEvent::Data::ComplianceProfile?



99
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 99

optional :compliance_profile, -> { Straddle::CustomerEventV1WebhookEvent::Data::ComplianceProfile }

#created_at ⇒ Time

Timestamp of when the customer record was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


50
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 50

required :created_at, Time

#device ⇒ Straddle::Models::MaskedCustomerDevice



55
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 55

required :device, -> { Straddle::MaskedCustomerDevice }

#email ⇒ String

Customer email address.

Parameters:

  • value (String)

Returns:

  • (String)


61
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 61

required :email, String

#external_id ⇒ String?

Unique identifier for the customer in your system.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


105
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 105

optional :external_id, String, nil?: true

#id ⇒ String

Unique identifier for the customer.

Parameters:

  • value (String)

Returns:

  • (String)


44
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 44

required :id, String

#metadata ⇒ Hash{Symbol=>String, nil}?

Up to 20 user-defined key-value pairs associated with the customer.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


111
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 111

optional :metadata, Straddle::Internal::Type::HashOf[String, nil?: true], nil?: true

#name ⇒ String

Full name for an individual customer or business name for a business customer.

Parameters:

  • value (String)

Returns:

  • (String)


67
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 67

required :name, String

#phone ⇒ String

Customer phone number in E.164 format.

Parameters:

  • value (String)

Returns:

  • (String)


73
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 73

required :phone, String

#status ⇒ Symbol, Straddle::Models::CustomerEventV1WebhookEvent::Data::Status

Parameters:

  • value (Straddle::Models::CustomerEventV1WebhookEvent::Data::status)

Returns:



78
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 78

required :status, enum: -> { Straddle::CustomerEventV1WebhookEvent::Data::Status }

#type ⇒ Symbol, Straddle::Models::CustomerType

Parameters:

  • value (Straddle::Models::customer_type)

Returns:



83
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 83

required :type, enum: -> { Straddle::CustomerType }

#updated_at ⇒ Time

Timestamp of the most recent update to the customer record.

Parameters:

  • value (Time)

Returns:

  • (Time)


89
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 89

required :updated_at, Time

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 150

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


102
# File 'sig/straddle/models/customer_event_v1_webhook_event.rbs', line 102

def to_hash: -> {