Class: Straddle::Models::CustomerEventV1WebhookEvent::Data::Address

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/customer_event_v1_webhook_event.rb,
sig/straddle/models/customer_event_v1_webhook_event.rbs

Overview

See Also:

  • Straddle::Models::CustomerEventV1WebhookEvent::Data#address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



152
# File 'sig/straddle/models/customer_event_v1_webhook_event.rbs', line 152

def initialize: (

Instance Attribute Details

#address1 ⇒ String

Primary address line, such as a street address or PO Box.

Parameters:

  • value (String)

Returns:

  • (String)


160
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 160

required :address1, String

#address2 ⇒ String?

Secondary address line, such as an apartment, suite, unit, or building.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


184
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 184

optional :address2, String, nil?: true

#city ⇒ String

City, district, suburb, town, or village.

Parameters:

  • value (String)

Returns:

  • (String)


166
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 166

required :city, String

#state ⇒ String

Two-letter state code.

Parameters:

  • value (String)

Returns:

  • (String)


172
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 172

required :state, String

#zip ⇒ String

ZIP or postal code.

Parameters:

  • value (String)

Returns:

  • (String)


178
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 178

required :zip, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


160
# File 'sig/straddle/models/customer_event_v1_webhook_event.rbs', line 160

def to_hash: -> {