Class: Straddle::Models::CustomerEventV1WebhookEvent::Data::ComplianceProfile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/customer_event_v1_webhook_event.rb,
sig/straddle/models/customer_event_v1_webhook_event.rbs

Overview

See Also:

  • Straddle::Models::CustomerEventV1WebhookEvent::Data#compliance_profile

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(dob: nil, ein: nil, legal_business_name: nil, ssn: nil, website: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::CustomerEventV1WebhookEvent::Data::ComplianceProfile for more details.

Parameters:

  • dob (String, nil) (defaults to: nil) —

    Masked date of birth for an individual customer in ****-**-** format.

  • ein (String, nil) (defaults to: nil) —

    Masked Employer Identification Number for a business customer in **-******* fo

  • legal_business_name (String, nil) (defaults to: nil) —

    Official registered name of the business customer.

  • ssn (String, nil) (defaults to: nil) —

    Masked Social Security number for an individual customer in ***-**-**** format

  • website (String, nil) (defaults to: nil) —

    Official website URL for the business customer.



# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 232

Instance Attribute Details

#dob ⇒ String?

Masked date of birth for an individual customer in ****-**-** format.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


204
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 204

optional :dob, String, nil?: true

#ein ⇒ String?

Masked Employer Identification Number for a business customer in **-******* format.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


211
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 211

optional :ein, String, nil?: true

Official registered name of the business customer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


217
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 217

optional :legal_business_name, String, nil?: true

#ssn ⇒ String?

Masked Social Security number for an individual customer in ***-**-**** format.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


224
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 224

optional :ssn, String, nil?: true

#website ⇒ String?

Official website URL for the business customer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


230
# File 'lib/straddle/models/customer_event_v1_webhook_event.rb', line 230

optional :website, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


197
# File 'sig/straddle/models/customer_event_v1_webhook_event.rbs', line 197

def to_hash: -> {