Class: Straddle::Models::CustomerListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::CustomerListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/customer_list_params.rb,
sig/straddle/models/customer_list_params.rbs
Overview
Defined Under Namespace
Modules: SortBy
Instance Attribute Summary collapse
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#created_from ⇒ Time?
Start date for filtering by
created_atdate. -
#created_to ⇒ Time?
End date for filtering by
created_atdate. -
#email ⇒ String?
Filter customers by
emailaddress. -
#external_id ⇒ String?
Filter by your system's
external_id. -
#name ⇒ String?
Filter customers by
name(partial match). -
#page_number ⇒ Integer?
Page number for paginated results.
-
#page_size ⇒ Integer?
Number of results per page.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#search_text ⇒ String?
General search term to filter customers.
-
#sort_by ⇒ Symbol, ...
Field used to sort the results.
-
#sort_order ⇒ Symbol, ...
Order in which to sort the results.
-
#status ⇒ Array<Symbol, Straddle::Models::CustomerStatus>?
Filter customers by their current
status. -
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
-
#types ⇒ Array<Symbol, Straddle::Models::CustomerType>?
Filter by customer type
individualorbusiness.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
95 |
# File 'sig/straddle/models/customer_list_params.rbs', line 95
def initialize: (
|
Instance Attribute Details
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
86 |
# File 'lib/straddle/models/customer_list_params.rb', line 86 optional :correlation_id, String |
#created_from ⇒ Time?
Start date for filtering by created_at date.
14 |
# File 'lib/straddle/models/customer_list_params.rb', line 14 optional :created_from, Time |
#created_to ⇒ Time?
End date for filtering by created_at date.
20 |
# File 'lib/straddle/models/customer_list_params.rb', line 20 optional :created_to, Time |
#email ⇒ String?
Filter customers by email address.
26 |
# File 'lib/straddle/models/customer_list_params.rb', line 26 optional :email, String |
#external_id ⇒ String?
Filter by your system's external_id.
32 |
# File 'lib/straddle/models/customer_list_params.rb', line 32 optional :external_id, String |
#name ⇒ String?
Filter customers by name (partial match).
38 |
# File 'lib/straddle/models/customer_list_params.rb', line 38 optional :name, String |
#page_number ⇒ Integer?
Page number for paginated results. Starts at 1.
44 |
# File 'lib/straddle/models/customer_list_params.rb', line 44 optional :page_number, Integer |
#page_size ⇒ Integer?
Number of results per page. Maximum: 1000.
50 |
# File 'lib/straddle/models/customer_list_params.rb', line 50 optional :page_size, Integer |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
92 |
# File 'lib/straddle/models/customer_list_params.rb', line 92 optional :request_id, String |
#search_text ⇒ String?
General search term to filter customers.
56 |
# File 'lib/straddle/models/customer_list_params.rb', line 56 optional :search_text, String |
#sort_by ⇒ Symbol, ...
Field used to sort the results.
62 |
# File 'lib/straddle/models/customer_list_params.rb', line 62 optional :sort_by, enum: -> { Straddle::CustomerListParams::SortBy } |
#sort_order ⇒ Symbol, ...
Order in which to sort the results.
68 |
# File 'lib/straddle/models/customer_list_params.rb', line 68 optional :sort_order, enum: -> { Straddle::SortOrder } |
#status ⇒ Array<Symbol, Straddle::Models::CustomerStatus>?
Filter customers by their current status.
74 |
# File 'lib/straddle/models/customer_list_params.rb', line 74 optional :status, -> { Straddle::Internal::Type::ArrayOf[enum: Straddle::CustomerStatus] } |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
98 |
# File 'lib/straddle/models/customer_list_params.rb', line 98 optional :straddle_account_id, String |
#types ⇒ Array<Symbol, Straddle::Models::CustomerType>?
Filter by customer type individual or business.
80 |
# File 'lib/straddle/models/customer_list_params.rb', line 80 optional :types, -> { Straddle::Internal::Type::ArrayOf[enum: Straddle::CustomerType] } |
Instance Method Details
#to_hash ⇒ {
114 |
# File 'sig/straddle/models/customer_list_params.rbs', line 114
def to_hash: -> {
|