Class: Straddle::Models::CustomerSummary
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::CustomerSummary
- Defined in:
- lib/straddle/models/customer_summary.rb,
sig/straddle/models/customer_summary.rbs
Instance Attribute Summary collapse
-
#created_at ⇒ Time
Timestamp of when the customer record was created.
-
#email ⇒ String
The customer's email address.
-
#external_id ⇒ String?
Unique identifier for the customer in your system.
-
#id ⇒ String
Unique identifier for the customer.
-
#name ⇒ String
Full name for an individual customer or business name for a business customer.
-
#phone ⇒ String
The customer's phone number in E.164 format.
- #status ⇒ Symbol, Straddle::Models::CustomerStatus
- #type ⇒ Symbol, Straddle::Models::CustomerType
-
#updated_at ⇒ Time
Timestamp of the most recent update to the customer record.
Instance Method Summary collapse
- #initialize(id:, created_at:, email:, name:, phone:, status:, type:, updated_at:, external_id: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, email:, name:, phone:, status:, type:, updated_at:, external_id: nil) ⇒ Object
|
|
# File 'lib/straddle/models/customer_summary.rb', line 58
|
Instance Attribute Details
#created_at ⇒ Time
Timestamp of when the customer record was created.
16 |
# File 'lib/straddle/models/customer_summary.rb', line 16 required :created_at, Time |
#email ⇒ String
The customer's email address.
22 |
# File 'lib/straddle/models/customer_summary.rb', line 22 required :email, String |
#external_id ⇒ String?
Unique identifier for the customer in your system.
56 |
# File 'lib/straddle/models/customer_summary.rb', line 56 optional :external_id, String, nil?: true |
#id ⇒ String
Unique identifier for the customer.
10 |
# File 'lib/straddle/models/customer_summary.rb', line 10 required :id, String |
#name ⇒ String
Full name for an individual customer or business name for a business customer.
28 |
# File 'lib/straddle/models/customer_summary.rb', line 28 required :name, String |
#phone ⇒ String
The customer's phone number in E.164 format.
34 |
# File 'lib/straddle/models/customer_summary.rb', line 34 required :phone, String |
#status ⇒ Symbol, Straddle::Models::CustomerStatus
39 |
# File 'lib/straddle/models/customer_summary.rb', line 39 required :status, enum: -> { Straddle::CustomerStatus } |
#type ⇒ Symbol, Straddle::Models::CustomerType
44 |
# File 'lib/straddle/models/customer_summary.rb', line 44 required :type, enum: -> { Straddle::CustomerType } |
#updated_at ⇒ Time
Timestamp of the most recent update to the customer record.
50 |
# File 'lib/straddle/models/customer_summary.rb', line 50 required :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
47 |
# File 'sig/straddle/models/customer_summary.rbs', line 47
def to_hash: -> {
|