Class: Straddle::Models::CustomerUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::CustomerUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/customer_update_params.rb,
sig/straddle/models/customer_update_params.rbs
Overview
Instance Attribute Summary collapse
-
#address ⇒ Straddle::Models::CustomerAddress?
Customer postal address.
- #compliance_profile ⇒ Straddle::Models::UnmaskedComplianceProfile::IndividualComplianceProfile, ...
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
- #device ⇒ Straddle::Models::CustomerDevice
-
#email ⇒ String
Customer email address.
-
#external_id ⇒ String?
Unique identifier for the customer in your system.
- #id ⇒ String
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined key-value pairs associated with the customer.
-
#name ⇒ String
Full name for an individual customer or business name for a business customer.
-
#phone ⇒ String
Customer phone number in E.164 format.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
- #status ⇒ Symbol, Straddle::Models::CustomerStatus
-
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, device:, email:, name:, phone:, status:, address: nil, compliance_profile: nil, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomerUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, device:, email:, name:, phone:, status:, address: nil, compliance_profile: nil, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::CustomerUpdateParams for more details.
|
|
# File 'lib/straddle/models/customer_update_params.rb', line 91
|
Instance Attribute Details
#address ⇒ Straddle::Models::CustomerAddress?
Customer postal address. When provided, the object must include all required fields.
48 |
# File 'lib/straddle/models/customer_update_params.rb', line 48 optional :address, -> { Straddle::CustomerAddress }, nil?: true |
#compliance_profile ⇒ Straddle::Models::UnmaskedComplianceProfile::IndividualComplianceProfile, ...
53 |
# File 'lib/straddle/models/customer_update_params.rb', line 53 optional :compliance_profile, union: -> { Straddle::UnmaskedComplianceProfile }, nil?: true |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
71 |
# File 'lib/straddle/models/customer_update_params.rb', line 71 optional :correlation_id, String |
#device ⇒ Straddle::Models::CustomerDevice
18 |
# File 'lib/straddle/models/customer_update_params.rb', line 18 required :device, -> { Straddle::CustomerDevice } |
#email ⇒ String
Customer email address.
24 |
# File 'lib/straddle/models/customer_update_params.rb', line 24 required :email, String |
#external_id ⇒ String?
Unique identifier for the customer in your system.
59 |
# File 'lib/straddle/models/customer_update_params.rb', line 59 optional :external_id, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/straddle/models/customer_update_params.rb', line 13 required :id, String |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
77 |
# File 'lib/straddle/models/customer_update_params.rb', line 77 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined key-value pairs associated with the customer.
65 |
# File 'lib/straddle/models/customer_update_params.rb', line 65 optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true |
#name ⇒ String
Full name for an individual customer or business name for a business customer.
30 |
# File 'lib/straddle/models/customer_update_params.rb', line 30 required :name, String |
#phone ⇒ String
Customer phone number in E.164 format.
36 |
# File 'lib/straddle/models/customer_update_params.rb', line 36 required :phone, String |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
83 |
# File 'lib/straddle/models/customer_update_params.rb', line 83 optional :request_id, String |
#status ⇒ Symbol, Straddle::Models::CustomerStatus
41 |
# File 'lib/straddle/models/customer_update_params.rb', line 41 required :status, enum: -> { Straddle::CustomerStatus } |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
89 |
# File 'lib/straddle/models/customer_update_params.rb', line 89 optional :straddle_account_id, String |
Instance Method Details
#to_hash ⇒ {
80 |
# File 'sig/straddle/models/customer_update_params.rbs', line 80
def to_hash: -> {
|