Class: Straddle::Models::Customers::CustomerIdentityVerification

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/customers/customer_identity_verification.rb,
sig/straddle/models/customers/customer_identity_verification.rbs

Defined Under Namespace

Classes: Breakdown

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(breakdown:, created_at:, decision:, review_id:, updated_at:, kyc: nil, messages: nil, network_alerts: nil, reputation: nil, watch_list: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::Customers::CustomerIdentityVerification for more details.

Parameters:



# File 'lib/straddle/models/customers/customer_identity_verification.rb', line 63

Instance Attribute Details

#breakdown ⇒ Straddle::Models::Customers::CustomerIdentityVerification::Breakdown

Results for each customer verification check, including decisions, risk scores, and correlation scores.

Parameters:

  • value (Straddle::Customers::CustomerIdentityVerification::Breakdown)

Returns:



12
# File 'lib/straddle/models/customers/customer_identity_verification.rb', line 12

required :breakdown, -> { Straddle::Customers::CustomerIdentityVerification::Breakdown }

#created_at ⇒ Time

Timestamp of when the review was initiated.

Parameters:

  • value (Time)

Returns:

  • (Time)


18
# File 'lib/straddle/models/customers/customer_identity_verification.rb', line 18

required :created_at, Time

#decision ⇒ Symbol, Straddle::Models::Customers::VerificationDecision

Parameters:

  • value (Straddle::Models::Customers::verification_decision)

Returns:



23
# File 'lib/straddle/models/customers/customer_identity_verification.rb', line 23

required :decision, enum: -> { Straddle::Customers::VerificationDecision }

#kyc ⇒ Straddle::Models::Customers::CustomerKYCVerification?



40
# File 'lib/straddle/models/customers/customer_identity_verification.rb', line 40

optional :kyc, -> { Straddle::Customers::CustomerKYCVerification }

#messages ⇒ Hash{Symbol=>String}?

Messages returned by the customer verification process.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


46
# File 'lib/straddle/models/customers/customer_identity_verification.rb', line 46

optional :messages, Straddle::Internal::Type::HashOf[String], nil?: true

#network_alerts ⇒ Straddle::Models::Customers::IdentityVerificationAlerts?



51
# File 'lib/straddle/models/customers/customer_identity_verification.rb', line 51

optional :network_alerts, -> { Straddle::Customers::IdentityVerificationAlerts }

#reputation ⇒ Straddle::Models::Customers::ReputationCheck?



56
# File 'lib/straddle/models/customers/customer_identity_verification.rb', line 56

optional :reputation, -> { Straddle::Customers::ReputationCheck }

#review_id ⇒ String

Unique identifier for the review.

Parameters:

  • value (String)

Returns:

  • (String)


29
# File 'lib/straddle/models/customers/customer_identity_verification.rb', line 29

required :review_id, String

#updated_at ⇒ Time

Timestamp of the most recent update to the review.

Parameters:

  • value (Time)

Returns:

  • (Time)


35
# File 'lib/straddle/models/customers/customer_identity_verification.rb', line 35

required :updated_at, Time

#watch_list ⇒ Straddle::Models::Customers::IdentityVerificationWatchlist?



61
# File 'lib/straddle/models/customers/customer_identity_verification.rb', line 61

optional :watch_list, -> { Straddle::Customers::IdentityVerificationWatchlist }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


70
# File 'sig/straddle/models/customers/customer_identity_verification.rbs', line 70

def to_hash: -> {