Class: Straddle::Models::Customers::IdentityVerificationAlerts

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/customers/identity_verification_alerts.rb,
sig/straddle/models/customers/identity_verification_alerts.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(alerts: nil, codes: nil, decision: nil) ⇒ Object

Parameters:

  • alerts (Array<String>, nil) (defaults to: nil) —

    Any alerts or flags raised during the consortium alert screening.

  • codes (Array<String>, nil) (defaults to: nil) —

    List of specific result codes from the consortium alert screening.

  • decision (Symbol, Straddle::Models::Customers::VerificationDecision) (defaults to: nil)


# File 'lib/straddle/models/customers/identity_verification_alerts.rb', line 24

Instance Attribute Details

#alerts ⇒ Array<String>?

Any alerts or flags raised during the consortium alert screening.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


11
# File 'lib/straddle/models/customers/identity_verification_alerts.rb', line 11

optional :alerts, Straddle::Internal::Type::ArrayOf[String], nil?: true

#codes ⇒ Array<String>?

List of specific result codes from the consortium alert screening.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


17
# File 'lib/straddle/models/customers/identity_verification_alerts.rb', line 17

optional :codes, Straddle::Internal::Type::ArrayOf[String], nil?: true

#decision ⇒ Symbol, ...



22
# File 'lib/straddle/models/customers/identity_verification_alerts.rb', line 22

optional :decision, enum: -> { Straddle::Customers::VerificationDecision }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


28
# File 'sig/straddle/models/customers/identity_verification_alerts.rbs', line 28

def to_hash: -> {