Class: Straddle::Models::Customers::IdentityVerificationBreakdown

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/customers/identity_verification_breakdown.rb,
sig/straddle/models/customers/identity_verification_breakdown.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(codes: nil, correlation: nil, correlation_score: nil, decision: nil, risk_score: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::Customers::IdentityVerificationBreakdown for more details.

Parameters:

  • codes (Array<String>, nil) (defaults to: nil) —

    List of specific result codes from the fraud and risk screening.

  • correlation (Symbol, Straddle::Models::Customers::CorrelationBucket) (defaults to: nil)
  • correlation_score (Float, nil) (defaults to: nil) —

    Represents the strength of the correlation between provided and known informatio

  • decision (Symbol, Straddle::Models::Customers::VerificationDecision) (defaults to: nil)
  • risk_score (Float, nil) (defaults to: nil) —

    Predicts the inherent risk associated with the customer for a given module. A hi



# File 'lib/straddle/models/customers/identity_verification_breakdown.rb', line 37

Instance Attribute Details

#codes ⇒ Array<String>?

List of specific result codes from the fraud and risk screening.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


11
# File 'lib/straddle/models/customers/identity_verification_breakdown.rb', line 11

optional :codes, Straddle::Internal::Type::ArrayOf[String], nil?: true

#correlation ⇒ Symbol, ...



16
# File 'lib/straddle/models/customers/identity_verification_breakdown.rb', line 16

optional :correlation, enum: -> { Straddle::Customers::CorrelationBucket }

#correlation_score ⇒ Float?

Represents the strength of the correlation between provided and known information. A higher score indicates a stronger correlation.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


23
# File 'lib/straddle/models/customers/identity_verification_breakdown.rb', line 23

optional :correlation_score, Float, nil?: true

#decision ⇒ Symbol, ...



28
# File 'lib/straddle/models/customers/identity_verification_breakdown.rb', line 28

optional :decision, enum: -> { Straddle::Customers::VerificationDecision }

#risk_score ⇒ Float?

Predicts the inherent risk associated with the customer for a given module. A higher score indicates a greater likelihood of fraud.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


35
# File 'lib/straddle/models/customers/identity_verification_breakdown.rb', line 35

optional :risk_score, Float, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


40
# File 'sig/straddle/models/customers/identity_verification_breakdown.rbs', line 40

def to_hash: -> {