Class: Straddle::Models::Customers::ReputationInsights

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/customers/reputation_insights.rb,
sig/straddle/models/customers/reputation_insights.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(accounts_active_count: nil, accounts_closed_count: nil, accounts_closed_dates: nil, accounts_count: nil, accounts_fraud_count: nil, accounts_fraud_labeled_dates: nil, accounts_fraud_loss_total_amount: nil, ach_fraud_transactions_count: nil, ach_fraud_transactions_dates: nil, ach_fraud_transactions_total_amount: nil, ach_returned_transactions_count: nil, ach_returned_transactions_dates: nil, ach_returned_transactions_total_amount: nil, applications_approved_count: nil, applications_count: nil, applications_dates: nil, applications_declined_count: nil, applications_fraud_count: nil, card_disputed_transactions_count: nil, card_disputed_transactions_dates: nil, card_disputed_transactions_total_amount: nil, card_fraud_transactions_count: nil, card_fraud_transactions_dates: nil, card_fraud_transactions_total_amount: nil, card_stopped_transactions_count: nil, card_stopped_transactions_dates: nil, user_active_profile_count: nil, user_address_count: nil, user_closed_profile_count: nil, user_dob_count: nil, user_email_count: nil, user_institution_count: nil, user_mobile_count: nil) ⇒ Object

Parameters:

  • accounts_active_count (Integer, nil) (defaults to: nil) —

    Number of active accounts associated with the identity.

  • accounts_closed_count (Integer, nil) (defaults to: nil) —

    Number of closed accounts associated with the identity.

  • accounts_closed_dates (Array<Date>, nil) (defaults to: nil) —

    Dates when accounts associated with the identity were closed.

  • accounts_count (Integer, nil) (defaults to: nil) —

    Number of accounts associated with the identity.

  • accounts_fraud_count (Integer, nil) (defaults to: nil) —

    Number of accounts associated with fraud.

  • accounts_fraud_labeled_dates (Array<Date>, nil) (defaults to: nil) —

    Dates when accounts were labeled as fraudulent.

  • accounts_fraud_loss_total_amount (Float, nil) (defaults to: nil) —

    Total fraud loss associated with the accounts.

  • ach_fraud_transactions_count (Integer, nil) (defaults to: nil) —

    Number of fraudulent ACH transactions.

  • ach_fraud_transactions_dates (Array<Date>, nil) (defaults to: nil) —

    Dates when fraudulent ACH transactions occurred.

  • ach_fraud_transactions_total_amount (Float, nil) (defaults to: nil) —

    Total amount of fraudulent ACH transactions.

  • ach_returned_transactions_count (Integer, nil) (defaults to: nil) —

    Number of returned ACH transactions.

  • ach_returned_transactions_dates (Array<Date>, nil) (defaults to: nil) —

    Dates when ACH transactions were returned.

  • ach_returned_transactions_total_amount (Float, nil) (defaults to: nil) —

    Total amount of returned ACH transactions.

  • applications_approved_count (Integer, nil) (defaults to: nil) —

    Number of approved applications associated with the identity.

  • applications_count (Integer, nil) (defaults to: nil) —

    Number of applications associated with the identity.

  • applications_dates (Array<Date>, nil) (defaults to: nil) —

    Dates when applications associated with the identity were submitted.

  • applications_declined_count (Integer, nil) (defaults to: nil) —

    Number of declined applications associated with the identity.

  • applications_fraud_count (Integer, nil) (defaults to: nil) —

    Number of applications associated with fraud.

  • card_disputed_transactions_count (Integer, nil) (defaults to: nil) —

    Number of disputed card transactions.

  • card_disputed_transactions_dates (Array<Date>, nil) (defaults to: nil) —

    Dates when card transactions were disputed.

  • card_disputed_transactions_total_amount (Float, nil) (defaults to: nil) —

    Total amount of disputed card transactions.

  • card_fraud_transactions_count (Integer, nil) (defaults to: nil) —

    Number of fraudulent card transactions.

  • card_fraud_transactions_dates (Array<Date>, nil) (defaults to: nil) —

    Dates when fraudulent card transactions occurred.

  • card_fraud_transactions_total_amount (Float, nil) (defaults to: nil) —

    Total amount of fraudulent card transactions.

  • card_stopped_transactions_count (Integer, nil) (defaults to: nil) —

    Number of stopped card transactions.

  • card_stopped_transactions_dates (Array<Date>, nil) (defaults to: nil) —

    Dates when card transactions were stopped.

  • user_active_profile_count (Integer, nil) (defaults to: nil) —

    Number of active profiles associated with the identity.

  • user_address_count (Integer, nil) (defaults to: nil) —

    Number of addresses associated with the identity.

  • user_closed_profile_count (Integer, nil) (defaults to: nil) —

    Number of closed profiles associated with the identity.

  • user_dob_count (Integer, nil) (defaults to: nil) —

    Number of dates of birth associated with the identity.

  • user_email_count (Integer, nil) (defaults to: nil) —

    Number of email addresses associated with the identity.

  • user_institution_count (Integer, nil) (defaults to: nil) —

    Number of financial institutions associated with the identity.

  • user_mobile_count (Integer, nil) (defaults to: nil) —

    Number of mobile numbers associated with the identity.



# File 'lib/straddle/models/customers/reputation_insights.rb', line 205

Instance Attribute Details

#accounts_active_count ⇒ Integer?

Number of active accounts associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


11
# File 'lib/straddle/models/customers/reputation_insights.rb', line 11

optional :accounts_active_count, Integer, nil?: true

#accounts_closed_count ⇒ Integer?

Number of closed accounts associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


17
# File 'lib/straddle/models/customers/reputation_insights.rb', line 17

optional :accounts_closed_count, Integer, nil?: true

#accounts_closed_dates ⇒ Array<Date>?

Dates when accounts associated with the identity were closed.

Parameters:

  • value (::Array[Date], nil)

Returns:

  • (Array<Date>, nil)


23
# File 'lib/straddle/models/customers/reputation_insights.rb', line 23

optional :accounts_closed_dates, Straddle::Internal::Type::ArrayOf[Date], nil?: true

#accounts_count ⇒ Integer?

Number of accounts associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


29
# File 'lib/straddle/models/customers/reputation_insights.rb', line 29

optional :accounts_count, Integer, nil?: true

#accounts_fraud_count ⇒ Integer?

Number of accounts associated with fraud.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


35
# File 'lib/straddle/models/customers/reputation_insights.rb', line 35

optional :accounts_fraud_count, Integer, nil?: true

#accounts_fraud_labeled_dates ⇒ Array<Date>?

Dates when accounts were labeled as fraudulent.

Parameters:

  • value (::Array[Date], nil)

Returns:

  • (Array<Date>, nil)


41
# File 'lib/straddle/models/customers/reputation_insights.rb', line 41

optional :accounts_fraud_labeled_dates, Straddle::Internal::Type::ArrayOf[Date], nil?: true

#accounts_fraud_loss_total_amount ⇒ Float?

Total fraud loss associated with the accounts.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


47
# File 'lib/straddle/models/customers/reputation_insights.rb', line 47

optional :accounts_fraud_loss_total_amount, Float, nil?: true

#ach_fraud_transactions_count ⇒ Integer?

Number of fraudulent ACH transactions.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


53
# File 'lib/straddle/models/customers/reputation_insights.rb', line 53

optional :ach_fraud_transactions_count, Integer, nil?: true

#ach_fraud_transactions_dates ⇒ Array<Date>?

Dates when fraudulent ACH transactions occurred.

Parameters:

  • value (::Array[Date], nil)

Returns:

  • (Array<Date>, nil)


59
# File 'lib/straddle/models/customers/reputation_insights.rb', line 59

optional :ach_fraud_transactions_dates, Straddle::Internal::Type::ArrayOf[Date], nil?: true

#ach_fraud_transactions_total_amount ⇒ Float?

Total amount of fraudulent ACH transactions.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


65
# File 'lib/straddle/models/customers/reputation_insights.rb', line 65

optional :ach_fraud_transactions_total_amount, Float, nil?: true

#ach_returned_transactions_count ⇒ Integer?

Number of returned ACH transactions.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


71
# File 'lib/straddle/models/customers/reputation_insights.rb', line 71

optional :ach_returned_transactions_count, Integer, nil?: true

#ach_returned_transactions_dates ⇒ Array<Date>?

Dates when ACH transactions were returned.

Parameters:

  • value (::Array[Date], nil)

Returns:

  • (Array<Date>, nil)


77
# File 'lib/straddle/models/customers/reputation_insights.rb', line 77

optional :ach_returned_transactions_dates, Straddle::Internal::Type::ArrayOf[Date], nil?: true

#ach_returned_transactions_total_amount ⇒ Float?

Total amount of returned ACH transactions.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


83
# File 'lib/straddle/models/customers/reputation_insights.rb', line 83

optional :ach_returned_transactions_total_amount, Float, nil?: true

#applications_approved_count ⇒ Integer?

Number of approved applications associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


89
# File 'lib/straddle/models/customers/reputation_insights.rb', line 89

optional :applications_approved_count, Integer, nil?: true

#applications_count ⇒ Integer?

Number of applications associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


95
# File 'lib/straddle/models/customers/reputation_insights.rb', line 95

optional :applications_count, Integer, nil?: true

#applications_dates ⇒ Array<Date>?

Dates when applications associated with the identity were submitted.

Parameters:

  • value (::Array[Date], nil)

Returns:

  • (Array<Date>, nil)


101
# File 'lib/straddle/models/customers/reputation_insights.rb', line 101

optional :applications_dates, Straddle::Internal::Type::ArrayOf[Date], nil?: true

#applications_declined_count ⇒ Integer?

Number of declined applications associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


107
# File 'lib/straddle/models/customers/reputation_insights.rb', line 107

optional :applications_declined_count, Integer, nil?: true

#applications_fraud_count ⇒ Integer?

Number of applications associated with fraud.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


113
# File 'lib/straddle/models/customers/reputation_insights.rb', line 113

optional :applications_fraud_count, Integer, nil?: true

#card_disputed_transactions_count ⇒ Integer?

Number of disputed card transactions.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


119
# File 'lib/straddle/models/customers/reputation_insights.rb', line 119

optional :card_disputed_transactions_count, Integer, nil?: true

#card_disputed_transactions_dates ⇒ Array<Date>?

Dates when card transactions were disputed.

Parameters:

  • value (::Array[Date], nil)

Returns:

  • (Array<Date>, nil)


125
# File 'lib/straddle/models/customers/reputation_insights.rb', line 125

optional :card_disputed_transactions_dates, Straddle::Internal::Type::ArrayOf[Date], nil?: true

#card_disputed_transactions_total_amount ⇒ Float?

Total amount of disputed card transactions.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


131
# File 'lib/straddle/models/customers/reputation_insights.rb', line 131

optional :card_disputed_transactions_total_amount, Float, nil?: true

#card_fraud_transactions_count ⇒ Integer?

Number of fraudulent card transactions.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


137
# File 'lib/straddle/models/customers/reputation_insights.rb', line 137

optional :card_fraud_transactions_count, Integer, nil?: true

#card_fraud_transactions_dates ⇒ Array<Date>?

Dates when fraudulent card transactions occurred.

Parameters:

  • value (::Array[Date], nil)

Returns:

  • (Array<Date>, nil)


143
# File 'lib/straddle/models/customers/reputation_insights.rb', line 143

optional :card_fraud_transactions_dates, Straddle::Internal::Type::ArrayOf[Date], nil?: true

#card_fraud_transactions_total_amount ⇒ Float?

Total amount of fraudulent card transactions.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


149
# File 'lib/straddle/models/customers/reputation_insights.rb', line 149

optional :card_fraud_transactions_total_amount, Float, nil?: true

#card_stopped_transactions_count ⇒ Integer?

Number of stopped card transactions.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


155
# File 'lib/straddle/models/customers/reputation_insights.rb', line 155

optional :card_stopped_transactions_count, Integer, nil?: true

#card_stopped_transactions_dates ⇒ Array<Date>?

Dates when card transactions were stopped.

Parameters:

  • value (::Array[Date], nil)

Returns:

  • (Array<Date>, nil)


161
# File 'lib/straddle/models/customers/reputation_insights.rb', line 161

optional :card_stopped_transactions_dates, Straddle::Internal::Type::ArrayOf[Date], nil?: true

#user_active_profile_count ⇒ Integer?

Number of active profiles associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


167
# File 'lib/straddle/models/customers/reputation_insights.rb', line 167

optional :user_active_profile_count, Integer, nil?: true

#user_address_count ⇒ Integer?

Number of addresses associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


173
# File 'lib/straddle/models/customers/reputation_insights.rb', line 173

optional :user_address_count, Integer, nil?: true

#user_closed_profile_count ⇒ Integer?

Number of closed profiles associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


179
# File 'lib/straddle/models/customers/reputation_insights.rb', line 179

optional :user_closed_profile_count, Integer, nil?: true

#user_dob_count ⇒ Integer?

Number of dates of birth associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


185
# File 'lib/straddle/models/customers/reputation_insights.rb', line 185

optional :user_dob_count, Integer, nil?: true

#user_email_count ⇒ Integer?

Number of email addresses associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


191
# File 'lib/straddle/models/customers/reputation_insights.rb', line 191

optional :user_email_count, Integer, nil?: true

#user_institution_count ⇒ Integer?

Number of financial institutions associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


197
# File 'lib/straddle/models/customers/reputation_insights.rb', line 197

optional :user_institution_count, Integer, nil?: true

#user_mobile_count ⇒ Integer?

Number of mobile numbers associated with the identity.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


203
# File 'lib/straddle/models/customers/reputation_insights.rb', line 203

optional :user_mobile_count, Integer, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


144
# File 'sig/straddle/models/customers/reputation_insights.rbs', line 144

def to_hash: -> {