Class: Straddle::Models::FundingEventCreatedV1WebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::FundingEventCreatedV1WebhookEvent::Data
- Defined in:
- lib/straddle/models/funding_event_created_v1_webhook_event.rb,
sig/straddle/models/funding_event_created_v1_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Status Classes: StatusDetails, StatusHistory
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Total funding event amount in the smallest currency unit.
-
#created_at ⇒ Time
Timestamp when this funding event was created.
-
#direction ⇒ Symbol, Straddle::Models::FundingEventTransferDirection
Transfer direction relative to the linked bank account.
-
#event_type ⇒ Symbol, Straddle::Models::FundingEventType
Reason for the funding event.
-
#id ⇒ String
Unique identifier for this funding event.
-
#payment_count ⇒ Integer
Number of payments included in this funding event.
-
#status ⇒ Symbol, ...
Current status of this funding event.
-
#status_details ⇒ Straddle::Models::FundingEventCreatedV1WebhookEvent::Data::StatusDetails?
Reason, source, and message for the most recent status change.
-
#status_history ⇒ Array<Straddle::Models::FundingEventCreatedV1WebhookEvent::Data::StatusHistory>
Complete ordered history of all status changes for this funding event.
-
#trace_ids ⇒ Hash{Symbol=>String}
Network-level trace identifiers assigned during processing.
-
#transfer_date ⇒ Date
The date the funds transfer was initiated.
-
#updated_at ⇒ Time
Timestamp when this funding event was last updated.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
83 |
# File 'sig/straddle/models/funding_event_created_v1_webhook_event.rbs', line 83
def initialize: (
|
Instance Attribute Details
#amount ⇒ Integer
Total funding event amount in the smallest currency unit. For example, 1000 is
$10.00 USD.
51 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 51 required :amount, Integer |
#created_at ⇒ Time
Timestamp when this funding event was created.
57 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 57 required :created_at, Time |
#direction ⇒ Symbol, Straddle::Models::FundingEventTransferDirection
Transfer direction relative to the linked bank account. deposit moves funds
into the account, and withdrawal moves funds out.
64 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 64 required :direction, enum: -> { Straddle::FundingEventTransferDirection } |
#event_type ⇒ Symbol, Straddle::Models::FundingEventType
Reason for the funding event. charge_deposit settles collected charges to the
linked bank account. charge_reversal withdraws funds for reversed charges.
payout_withdrawal withdraws funds for payouts. payout_return deposits
returned payout funds.
73 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 73 required :event_type, enum: -> { Straddle::FundingEventType } |
#id ⇒ String
Unique identifier for this funding event.
44 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 44 required :id, String |
#payment_count ⇒ Integer
Number of payments included in this funding event.
79 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 79 required :payment_count, Integer |
#status ⇒ Symbol, ...
Current status of this funding event.
115 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 115 optional :status, enum: -> { Straddle::FundingEventCreatedV1WebhookEvent::Data::Status } |
#status_details ⇒ Straddle::Models::FundingEventCreatedV1WebhookEvent::Data::StatusDetails?
Reason, source, and message for the most recent status change.
121 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 121 optional :status_details, -> { Straddle::FundingEventCreatedV1WebhookEvent::Data::StatusDetails } |
#status_history ⇒ Array<Straddle::Models::FundingEventCreatedV1WebhookEvent::Data::StatusHistory>
Complete ordered history of all status changes for this funding event.
85 86 87 88 89 90 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 85 required :status_history, -> do Straddle::Internal::Type::ArrayOf[ Straddle::FundingEventCreatedV1WebhookEvent::Data::StatusHistory ] end |
#trace_ids ⇒ Hash{Symbol=>String}
Network-level trace identifiers assigned during processing. Keys vary by payment rail.
97 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 97 required :trace_ids, Straddle::Internal::Type::HashOf[String] |
#transfer_date ⇒ Date
The date the funds transfer was initiated.
103 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 103 required :transfer_date, Date |
#updated_at ⇒ Time
Timestamp when this funding event was last updated.
109 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 109 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 244
|
Instance Method Details
#to_hash ⇒ {
98 |
# File 'sig/straddle/models/funding_event_created_v1_webhook_event.rbs', line 98
def to_hash: -> {
|