Class: Straddle::Models::FundingEventCreatedV1WebhookEvent::Data::StatusDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::FundingEventCreatedV1WebhookEvent::Data::StatusDetails
- Defined in:
- lib/straddle/models/funding_event_created_v1_webhook_event.rb,
sig/straddle/models/funding_event_created_v1_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#changed_at ⇒ Time
The time the status change occurred.
-
#code ⇒ String?
The status code if applicable.
-
#message ⇒ String
A human-readable description of the current status.
- #reason ⇒ Symbol, Straddle::Models::FundingEventCreatedV1WebhookEvent::Data::StatusDetails::Reason
- #source ⇒ Symbol, Straddle::Models::PaymentStatusSource
Instance Method Summary collapse
-
#initialize(changed_at:, code:, message:, reason:, source:) ⇒ Object
constructor
Reason, source, and message for the most recent status change.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(changed_at:, code:, message:, reason:, source:) ⇒ Object
Reason, source, and message for the most recent status change.
|
|
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 299
|
Instance Attribute Details
#changed_at ⇒ Time
The time the status change occurred.
274 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 274 required :changed_at, Time |
#code ⇒ String?
The status code if applicable.
280 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 280 required :code, String, nil?: true |
#message ⇒ String
A human-readable description of the current status.
286 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 286 required :message, String |
#reason ⇒ Symbol, Straddle::Models::FundingEventCreatedV1WebhookEvent::Data::StatusDetails::Reason
291 292 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 291 required :reason, enum: -> { Straddle::FundingEventCreatedV1WebhookEvent::Data::StatusDetails::Reason } |
#source ⇒ Symbol, Straddle::Models::PaymentStatusSource
297 |
# File 'lib/straddle/models/funding_event_created_v1_webhook_event.rb', line 297 required :source, enum: -> { Straddle::PaymentStatusSource } |
Instance Method Details
#to_hash ⇒ {
286 |
# File 'sig/straddle/models/funding_event_created_v1_webhook_event.rbs', line 286
def to_hash: -> {
|