Class: Straddle::Models::FundingEventListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/straddle/models/funding_event_list_params.rb,
sig/straddle/models/funding_event_list_params.rbs

Overview

See Also:

  • Straddle::Resources::FundingEvents#list

Defined Under Namespace

Modules: SortBy

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



89
# File 'sig/straddle/models/funding_event_list_params.rbs', line 89

def initialize: (

Instance Attribute Details

#correlation_id ⇒ String?

Optional client-generated identifier for tracing a series of related requests.

Parameters:

  • (String)

Returns:

  • (String, nil)


102
# File 'lib/straddle/models/funding_event_list_params.rb', line 102

optional :correlation_id, String

#created_from ⇒ Date?

Filter to funding events created on or after this date.

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


14
# File 'lib/straddle/models/funding_event_list_params.rb', line 14

optional :created_from, Date, nil?: true

#created_to ⇒ Date?

Filter to funding events created on or before this date.

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


20
# File 'lib/straddle/models/funding_event_list_params.rb', line 20

optional :created_to, Date, nil?: true

#direction ⇒ Symbol, ...

Filter by transfer direction relative to the linked bank account.

Returns:



26
# File 'lib/straddle/models/funding_event_list_params.rb', line 26

optional :direction, enum: -> { Straddle::TransferDirection }

#event_type ⇒ Symbol, ...

Filter by funding event type.

Returns:



32
# File 'lib/straddle/models/funding_event_list_params.rb', line 32

optional :event_type, enum: -> { Straddle::FundingEventType }

#page_number ⇒ Integer?

Results page number. Starts at page 1.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


38
# File 'lib/straddle/models/funding_event_list_params.rb', line 38

optional :page_number, Integer

#page_size ⇒ Integer?

Results page size. Max value: 1000.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


44
# File 'lib/straddle/models/funding_event_list_params.rb', line 44

optional :page_size, Integer

#request_id ⇒ String?

Optional client-generated identifier for tracing one request.

Parameters:

  • (String)

Returns:

  • (String, nil)


108
# File 'lib/straddle/models/funding_event_list_params.rb', line 108

optional :request_id, String

#search_text ⇒ String?

Free-text search across funding event fields.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


50
# File 'lib/straddle/models/funding_event_list_params.rb', line 50

optional :search_text, String, nil?: true

#sort_by ⇒ Symbol, ...

Field used to sort the results.



56
# File 'lib/straddle/models/funding_event_list_params.rb', line 56

optional :sort_by, enum: -> { Straddle::FundingEventListParams::SortBy }

#sort_order ⇒ Symbol, ...

Order in which to sort the results.

Returns:



62
# File 'lib/straddle/models/funding_event_list_params.rb', line 62

optional :sort_order, enum: -> { Straddle::SortOrder }

#status ⇒ Array<Symbol, Straddle::Models::PaymentStatus>?

Filter by funding event status.

Parameters:

  • value (::Array[Straddle::Models::payment_status], nil)

Returns:



68
# File 'lib/straddle/models/funding_event_list_params.rb', line 68

optional :status, -> { Straddle::Internal::Type::ArrayOf[enum: Straddle::PaymentStatus] }, nil?: true

#status_reason ⇒ Array<Symbol, Straddle::Models::PaymentStatusReason>?

Filter by the reason for the most recent status change.

Parameters:

  • value (::Array[Straddle::Models::payment_status_reason], nil)

Returns:



74
75
76
# File 'lib/straddle/models/funding_event_list_params.rb', line 74

optional :status_reason,
-> { Straddle::Internal::Type::ArrayOf[enum: Straddle::PaymentStatusReason] },
nil?: true

#status_source ⇒ Array<Symbol, Straddle::Models::PaymentStatusSource>?

Filter by the source of the most recent status change.

Parameters:

  • value (::Array[Straddle::Models::payment_status_source], nil)

Returns:



82
83
84
# File 'lib/straddle/models/funding_event_list_params.rb', line 82

optional :status_source,
-> { Straddle::Internal::Type::ArrayOf[enum: Straddle::PaymentStatusSource] },
nil?: true

#straddle_account_id ⇒ String?

For platform requests, the embedded account UUID that sets the request scope.

Parameters:

  • (String)

Returns:

  • (String, nil)


114
# File 'lib/straddle/models/funding_event_list_params.rb', line 114

optional :straddle_account_id, String

#trace_id ⇒ String?

Filter by a network-level trace identifier assigned during processing.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


90
# File 'lib/straddle/models/funding_event_list_params.rb', line 90

optional :trace_id, String, nil?: true

#trace_number ⇒ String?

Filter by a network trace number assigned during processing.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


96
# File 'lib/straddle/models/funding_event_list_params.rb', line 96

optional :trace_number, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


110
# File 'sig/straddle/models/funding_event_list_params.rbs', line 110

def to_hash: -> {