Module: Straddle::Models::FundingEventListParams::SortBy

Extended by:
Internal::Type::Enum
Defined in:
lib/straddle/models/funding_event_list_params.rb,
sig/straddle/models/funding_event_list_params.rbs

Constant Summary collapse

TRANSFER_DATE =

Returns:

  • (:transfer_date)
:transfer_date
ID =

Returns:

  • (:id)
:id
AMOUNT =

Returns:

  • (:amount)
:amount

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/straddle/models/funding_event_list_params.rb', line 160

Instance Method Details

#initialize(created_from: nil, created_to: nil, direction: nil, event_type: nil, page_number: nil, page_size: nil, search_text: nil, sort_by: nil, sort_order: nil, status: nil, status_reason: nil, status_source: nil, trace_id: nil, trace_number: nil, correlation_id: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object

Parameters:

  • created_from (Date, nil) (defaults to: nil) —

    Filter to funding events created on or after this date.

  • created_to (Date, nil) (defaults to: nil) —

    Filter to funding events created on or before this date.

  • direction (Symbol, Straddle::Models::TransferDirection) (defaults to: nil) —

    Filter by transfer direction relative to the linked bank account.

  • event_type (Symbol, Straddle::Models::FundingEventType) (defaults to: nil) —

    Filter by funding event type.

  • page_number (Integer) (defaults to: nil) —

    Results page number. Starts at page 1.

  • page_size (Integer) (defaults to: nil) —

    Results page size. Max value: 1000.

  • search_text (String, nil) (defaults to: nil) —

    Free-text search across funding event fields.

  • sort_by (Symbol, Straddle::Models::FundingEventListParams::SortBy) (defaults to: nil) —

    Field used to sort the results.

  • sort_order (Symbol, Straddle::Models::SortOrder) (defaults to: nil) —

    Order in which to sort the results.

  • status (Array<Symbol, Straddle::Models::PaymentStatus>, nil) (defaults to: nil) —

    Filter by funding event status.

  • status_reason (Array<Symbol, Straddle::Models::PaymentStatusReason>, nil) (defaults to: nil) —

    Filter by the reason for the most recent status change.

  • status_source (Array<Symbol, Straddle::Models::PaymentStatusSource>, nil) (defaults to: nil) —

    Filter by the source of the most recent status change.

  • trace_id (String, nil) (defaults to: nil) —

    Filter by a network-level trace identifier assigned during processing.

  • trace_number (String, nil) (defaults to: nil) —

    Filter by a network trace number assigned during processing.

  • correlation_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing a series of related requests.

  • request_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing one request.

  • straddle_account_id (String) (defaults to: nil) —

    For platform requests, the embedded account UUID that sets the request scope.

  • request_options (Straddle::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


153
154
155
156
157
158
159
160
161
162
# File 'lib/straddle/models/funding_event_list_params.rb', line 153

module SortBy
  extend Straddle::Internal::Type::Enum

  TRANSFER_DATE = :transfer_date
  ID = :id
  AMOUNT = :amount

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values ⇒ ::Array[Straddle::Models::FundingEventListParams::sort_by]

Returns:

  • (::Array[Straddle::Models::FundingEventListParams::sort_by])


140
# File 'sig/straddle/models/funding_event_list_params.rbs', line 140

def self?.values: -> ::Array[Straddle::Models::FundingEventListParams::sort_by]