Class: Straddle::Models::FundingEventPayment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/funding_event_payment.rb,
sig/straddle/models/funding_event_payment.rbs

Constant Summary collapse

Straddle =

Returns:

  • (:CustomerDetails)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, currency:, external_id:, funding_amount:, payment_amount:, payment_date:, payment_type:, reason:, status:, trace_ids:, customer_details: nil, metadata: nil, paykey_details: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::FundingEventPayment for more details.

Parameters:

  • id (String) —

    Unique identifier for this payment.

  • currency (String) —

    Three-letter ISO 4217 currency code.

  • external_id (String) —

    Your unique identifier for this payment, used to correlate with your internal re

  • funding_amount (Integer) —

    Portion of the payment amount included in this funding event, in the smallest cu

  • payment_amount (Integer) —

    Total payment amount in the smallest currency unit (e.g. 1000 = $10.00 USD).

  • payment_date (Date) —

    The date on which this payment was submitted for processing.

  • payment_type (Symbol, Straddle::Models::PaymentType) —

    Whether this payment is a charge or payout.

  • reason (Symbol, Straddle::Models::FundingEventPaymentReason) —

    Reason this payment was included in the funding event.

  • status (Symbol, Straddle::Models::PaymentStatus) —

    Current status of this payment.

  • trace_ids (Hash{Symbol=>String}) —

    Network-level trace identifiers assigned during processing. Keys vary by payment

  • customer_details (Straddle::Models::CustomerDetails) (defaults to: nil) —

    Details of the customer associated with this payment.

  • metadata (Hash{Symbol=>String}, nil) (defaults to: nil) —

    Key-value metadata for this payment. Included only when include_metadata is `t

  • paykey_details (Straddle::Models::PaykeyDetails) (defaults to: nil) —

    Details of the paykey used for this payment.



# File 'lib/straddle/models/funding_event_payment.rb', line 88

Instance Attribute Details

#currency ⇒ String

Three-letter ISO 4217 currency code.

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/straddle/models/funding_event_payment.rb', line 16

required :currency, String

#customer_details ⇒ Straddle::Models::CustomerDetails?

Details of the customer associated with this payment.



73
# File 'lib/straddle/models/funding_event_payment.rb', line 73

optional :customer_details, -> { Straddle::CustomerDetails }

#external_id ⇒ String

Your unique identifier for this payment, used to correlate with your internal records.

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/straddle/models/funding_event_payment.rb', line 23

required :external_id, String

#funding_amount ⇒ Integer

Portion of the payment amount included in this funding event, in the smallest currency unit.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


30
# File 'lib/straddle/models/funding_event_payment.rb', line 30

required :funding_amount, Integer

#id ⇒ String

Unique identifier for this payment.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/funding_event_payment.rb', line 10

required :id, String

#metadata ⇒ Hash{Symbol=>String}?

Key-value metadata for this payment. Included only when include_metadata is true.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


80
# File 'lib/straddle/models/funding_event_payment.rb', line 80

optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true

#paykey_details ⇒ Straddle::Models::PaykeyDetails?

Details of the paykey used for this payment.



86
# File 'lib/straddle/models/funding_event_payment.rb', line 86

optional :paykey_details, -> { Straddle::PaykeyDetails }

#payment_amount ⇒ Integer

Total payment amount in the smallest currency unit (e.g. 1000 = $10.00 USD).

Parameters:

  • value (Integer)

Returns:

  • (Integer)


36
# File 'lib/straddle/models/funding_event_payment.rb', line 36

required :payment_amount, Integer

#payment_date ⇒ Date

The date on which this payment was submitted for processing.

Parameters:

  • value (Date)

Returns:

  • (Date)


42
# File 'lib/straddle/models/funding_event_payment.rb', line 42

required :payment_date, Date

#payment_type ⇒ Symbol, Straddle::Models::PaymentType

Whether this payment is a charge or payout.

Parameters:

  • value (Straddle::Models::payment_type)

Returns:



48
# File 'lib/straddle/models/funding_event_payment.rb', line 48

required :payment_type, enum: -> { Straddle::PaymentType }

#reason ⇒ Symbol, Straddle::Models::FundingEventPaymentReason

Reason this payment was included in the funding event.

Parameters:

  • value (Straddle::Models::funding_event_payment_reason)

Returns:



54
# File 'lib/straddle/models/funding_event_payment.rb', line 54

required :reason, enum: -> { Straddle::FundingEventPaymentReason }

#status ⇒ Symbol, Straddle::Models::PaymentStatus

Current status of this payment.

Parameters:

  • value (Straddle::Models::payment_status)

Returns:



60
# File 'lib/straddle/models/funding_event_payment.rb', line 60

required :status, enum: -> { Straddle::PaymentStatus }

#trace_ids ⇒ Hash{Symbol=>String}

Network-level trace identifiers assigned during processing. Keys vary by payment rail.

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


67
# File 'lib/straddle/models/funding_event_payment.rb', line 67

required :trace_ids, Straddle::Internal::Type::HashOf[String]

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


69
# File 'sig/straddle/models/funding_event_payment.rbs', line 69

def to_hash: -> {