Class: Straddle::Models::FundingEventSummary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/funding_event_summary.rb,
sig/straddle/models/funding_event_summary.rbs

Constant Summary collapse

Straddle =

Returns:

  • (:PaymentStatusDetails)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, created_at:, direction:, event_type:, payment_count:, trace_ids:, trace_numbers:, transfer_date:, updated_at:, status: nil, status_details: nil, trace_number: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::FundingEventSummary for more details.

Parameters:

  • id (String) —

    Unique identifier for this funding event.

  • amount (Integer) —

    Total funding event amount in the smallest currency unit. For example, 1000 is

  • created_at (Time) —

    Timestamp when this funding event was created.

  • direction (Symbol, Straddle::Models::TransferDirection) —

    Transfer direction relative to the linked bank account. deposit moves funds in

  • event_type (Symbol, Straddle::Models::FundingEventType) —

    Reason for the funding event. charge_deposit settles collected charges to the

  • payment_count (Integer) —

    Number of payments included in this funding event.

  • trace_ids (Hash{Symbol=>String}) —

    Network-level trace identifiers assigned during processing. Keys vary by payment

  • trace_numbers (Array<String>) —

    Network trace numbers associated with payments in this funding event.

  • transfer_date (Date) —

    The date the funds transfer was initiated.

  • updated_at (Time) —

    Timestamp when this funding event was last updated.

  • status (Symbol, Straddle::Models::PaymentStatus) (defaults to: nil) —

    Current status of this funding event.

  • status_details (Straddle::Models::PaymentStatusDetails) (defaults to: nil) —

    Reason, source, and message for the most recent status change.

  • trace_number (String, nil) (defaults to: nil) —

    The trace number of the funding event.



# File 'lib/straddle/models/funding_event_summary.rb', line 90

Instance Attribute Details

#amount ⇒ Integer

Total funding event amount in the smallest currency unit. For example, 1000 is $10.00 USD.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


17
# File 'lib/straddle/models/funding_event_summary.rb', line 17

required :amount, Integer

#created_at ⇒ Time

Timestamp when this funding event was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


23
# File 'lib/straddle/models/funding_event_summary.rb', line 23

required :created_at, Time

#direction ⇒ Symbol, Straddle::Models::TransferDirection

Transfer direction relative to the linked bank account. deposit moves funds into the account, and withdrawal moves funds out.

Parameters:

  • value (Straddle::Models::transfer_direction)

Returns:



30
# File 'lib/straddle/models/funding_event_summary.rb', line 30

required :direction, enum: -> { Straddle::TransferDirection }

#event_type ⇒ Symbol, Straddle::Models::FundingEventType

Reason for the funding event. charge_deposit settles collected charges to the linked bank account. charge_reversal withdraws funds for reversed charges. payout_withdrawal withdraws funds for payouts. payout_return deposits returned payout funds.

Parameters:

  • value (Straddle::Models::funding_event_type)

Returns:



39
# File 'lib/straddle/models/funding_event_summary.rb', line 39

required :event_type, enum: -> { Straddle::FundingEventType }

#id ⇒ String

Unique identifier for this funding event.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/funding_event_summary.rb', line 10

required :id, String

#payment_count ⇒ Integer

Number of payments included in this funding event.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


45
# File 'lib/straddle/models/funding_event_summary.rb', line 45

required :payment_count, Integer

#status ⇒ Symbol, ...

Current status of this funding event.

Returns:



76
# File 'lib/straddle/models/funding_event_summary.rb', line 76

optional :status, enum: -> { Straddle::PaymentStatus }

#status_details ⇒ Straddle::Models::PaymentStatusDetails?

Reason, source, and message for the most recent status change.



82
# File 'lib/straddle/models/funding_event_summary.rb', line 82

optional :status_details, -> { Straddle::PaymentStatusDetails }

#trace_ids ⇒ Hash{Symbol=>String}

Network-level trace identifiers assigned during processing. Keys vary by payment rail.

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


52
# File 'lib/straddle/models/funding_event_summary.rb', line 52

required :trace_ids, Straddle::Internal::Type::HashOf[String]

#trace_number ⇒ String?

The trace number of the funding event.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


88
# File 'lib/straddle/models/funding_event_summary.rb', line 88

optional :trace_number, String, nil?: true

#trace_numbers ⇒ Array<String>

Network trace numbers associated with payments in this funding event.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


58
# File 'lib/straddle/models/funding_event_summary.rb', line 58

required :trace_numbers, Straddle::Internal::Type::ArrayOf[String]

#transfer_date ⇒ Date

The date the funds transfer was initiated.

Parameters:

  • value (Date)

Returns:

  • (Date)


64
# File 'lib/straddle/models/funding_event_summary.rb', line 64

required :transfer_date, Date

#updated_at ⇒ Time

Timestamp when this funding event was last updated.

Parameters:

  • value (Time)

Returns:

  • (Time)


70
# File 'lib/straddle/models/funding_event_summary.rb', line 70

required :updated_at, Time

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


71
# File 'sig/straddle/models/funding_event_summary.rbs', line 71

def to_hash: -> {