Class: Straddle::Models::LinkedBankAccount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/linked_bank_account.rb,
sig/straddle/models/linked_bank_account.rbs

Defined Under Namespace

Modules: Purpose, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



41
# File 'sig/straddle/models/linked_bank_account.rbs', line 41

def initialize: (

Instance Attribute Details

#account_id ⇒ String?

ID of the related account, if this is an account-level linked bank account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


16
# File 'lib/straddle/models/linked_bank_account.rb', line 16

required :account_id, String, nil?: true

#bank_account ⇒ Straddle::Models::MaskedLinkedBankAccountDetails



21
# File 'lib/straddle/models/linked_bank_account.rb', line 21

required :bank_account, -> { Straddle::MaskedLinkedBankAccountDetails }

#created_at ⇒ Time

Date and time when Straddle created the linked bank account.

Parameters:

  • value (Time)

Returns:

  • (Time)


27
# File 'lib/straddle/models/linked_bank_account.rb', line 27

required :created_at, Time

#description ⇒ String?

Your description for the linked bank account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


56
# File 'lib/straddle/models/linked_bank_account.rb', line 56

optional :description, String, nil?: true

#id ⇒ String

Straddle's unique ID for the linked bank account.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/linked_bank_account.rb', line 10

required :id, String

#metadata ⇒ Hash{Symbol=>String, nil}?

Up to 20 user-defined key-value pairs.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


62
# File 'lib/straddle/models/linked_bank_account.rb', line 62

optional :metadata, Straddle::Internal::Type::HashOf[String, nil?: true], nil?: true

#platform_id ⇒ String?

ID of the related platform, if this is a platform-level linked bank account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


68
# File 'lib/straddle/models/linked_bank_account.rb', line 68

optional :platform_id, String, nil?: true

#purposes ⇒ Array<Symbol, Straddle::Models::LinkedBankAccount::Purpose>

Payment purposes assigned to the linked bank account.

Parameters:

  • value (::Array[Straddle::Models::LinkedBankAccount::purpose])

Returns:



33
# File 'lib/straddle/models/linked_bank_account.rb', line 33

required :purposes, -> { Straddle::Internal::Type::ArrayOf[enum: Straddle::LinkedBankAccount::Purpose] }

#status ⇒ Symbol, Straddle::Models::LinkedBankAccount::Status

Status of the linked bank account.

Parameters:

  • value (Straddle::Models::LinkedBankAccount::status)

Returns:



39
# File 'lib/straddle/models/linked_bank_account.rb', line 39

required :status, enum: -> { Straddle::LinkedBankAccount::Status }

#status_detail ⇒ Straddle::Models::LinkedBankAccountStatusDetail



44
# File 'lib/straddle/models/linked_bank_account.rb', line 44

required :status_detail, -> { Straddle::LinkedBankAccountStatusDetail }

#updated_at ⇒ Time

Date and time of the most recent linked bank account update.

Parameters:

  • value (Time)

Returns:

  • (Time)


50
# File 'lib/straddle/models/linked_bank_account.rb', line 50

required :updated_at, Time

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/straddle/models/linked_bank_account.rb', line 100

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


55
# File 'sig/straddle/models/linked_bank_account.rbs', line 55

def to_hash: -> {