Module: Straddle::Models::LinkedBankAccount::Purpose

Extended by:
Internal::Type::Enum
Defined in:
lib/straddle/models/linked_bank_account.rb,
sig/straddle/models/linked_bank_account.rbs

Constant Summary collapse

CHARGES =

Returns:

  • (:charges)
:charges
PAYOUTS =

Returns:

  • (:payouts)
:payouts
BILLING =

Returns:

  • (:billing)
:billing

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(id:, account_id:, bank_account:, created_at:, purposes:, status:, status_detail:, updated_at:, description: nil, metadata: nil, platform_id: nil) ⇒ Object

Parameters:

  • id (String) —

    Straddle's unique ID for the linked bank account.

  • account_id (String, nil) —

    ID of the related account, if this is an account-level linked bank account.

  • bank_account (Straddle::Models::MaskedLinkedBankAccountDetails)
  • created_at (Time) —

    Date and time when Straddle created the linked bank account.

  • purposes (Array<Symbol, Straddle::Models::LinkedBankAccount::Purpose>) —

    Payment purposes assigned to the linked bank account.

  • status (Symbol, Straddle::Models::LinkedBankAccount::Status) —

    Status of the linked bank account.

  • status_detail (Straddle::Models::LinkedBankAccountStatusDetail)
  • updated_at (Time) —

    Date and time of the most recent linked bank account update.

  • description (String, nil) (defaults to: nil) —

    Your description for the linked bank account.

  • metadata (Hash{Symbol=>String, nil}, nil) (defaults to: nil) —

    Up to 20 user-defined key-value pairs.

  • platform_id (String, nil) (defaults to: nil) —

    ID of the related platform, if this is a platform-level linked bank account.



93
94
95
96
97
98
99
100
101
102
# File 'lib/straddle/models/linked_bank_account.rb', line 93

module Purpose
  extend Straddle::Internal::Type::Enum

  CHARGES = :charges
  PAYOUTS = :payouts
  BILLING = :billing

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values ⇒ ::Array[Straddle::Models::LinkedBankAccount::purpose]

Returns:

  • (::Array[Straddle::Models::LinkedBankAccount::purpose])


78
# File 'sig/straddle/models/linked_bank_account.rbs', line 78

def self?.values: -> ::Array[Straddle::Models::LinkedBankAccount::purpose]