Class: Straddle::Models::LinkedBankAccountCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/straddle/models/linked_bank_account_create_params.rb,
sig/straddle/models/linked_bank_account_create_params.rbs

Overview

See Also:

  • Straddle::Resources::LinkedBankAccounts#create

Defined Under Namespace

Modules: Purpose Classes: BankAccount

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_holder:, account_number:, routing_number:) ⇒ Object

Some parameter documentations has been truncated, see BankAccount for more details.

Parameters:

  • account_holder (String) —

    Account holder name as it appears on the bank account. This is usually the busin

  • account_number (String) —

    The bank account number.

  • routing_number (String) —

    Nine-digit ABA routing number.



# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 113

Instance Attribute Details

#account_id ⇒ String?

ID of the account that will own the linked bank account. Omit this field to assign ownership to the platform in the authenticated request context.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


20
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 20

optional :account_id, String, nil?: true

#bank_account ⇒ Straddle::Models::LinkedBankAccountCreateParams::BankAccount

Parameters:

  • value (Straddle::LinkedBankAccountCreateParams::BankAccount)

Returns:



13
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 13

required :bank_account, -> { Straddle::LinkedBankAccountCreateParams::BankAccount }

#correlation_id ⇒ String?

Optional client-generated identifier for tracing a series of related requests.

Parameters:

  • (String)

Returns:

  • (String, nil)


55
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 55

optional :correlation_id, String

#description ⇒ String?

Your description for the linked bank account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


26
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 26

optional :description, String, nil?: true

#idempotency_key ⇒ String?

Optional client-generated key for an idempotent request.

Parameters:

  • (String)

Returns:

  • (String, nil)


61
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 61

optional :idempotency_key, String

#metadata ⇒ Hash{Symbol=>String, nil}?

Up to 20 user-defined key-value pairs.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


32
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 32

optional :metadata, Straddle::Internal::Type::HashOf[String, nil?: true], nil?: true

#platform_id ⇒ String?

ID of the platform to associate with the linked bank account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 38

optional :platform_id, String, nil?: true

#purposes ⇒ Array<Symbol, Straddle::Models::LinkedBankAccountCreateParams::Purpose>?

Payment purposes for the linked bank account. Defaults to charges, payouts, and billing.

Parameters:

  • value (::Array[Straddle::Models::LinkedBankAccountCreateParams::purpose], nil)

Returns:



45
46
47
48
49
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 45

optional :purposes,
-> do
  Straddle::Internal::Type::ArrayOf[enum: Straddle::LinkedBankAccountCreateParams::Purpose]
end,
nil?: true

#request_id ⇒ String?

Optional client-generated identifier for tracing one request.

Parameters:

  • (String)

Returns:

  • (String, nil)


67
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 67

optional :request_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


58
# File 'sig/straddle/models/linked_bank_account_create_params.rbs', line 58

def to_hash: -> {