Class: Straddle::Models::LinkedBankAccountCreateParams::BankAccount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/linked_bank_account_create_params.rb,
sig/straddle/models/linked_bank_account_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(bank_account:, account_id: nil, description: nil, metadata: nil, platform_id: nil, purposes: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::LinkedBankAccountCreateParams for more details.

Parameters:

  • bank_account (Straddle::Models::LinkedBankAccountCreateParams::BankAccount)
  • account_id (String, nil) (defaults to: nil) —

    ID of the account that will own the linked bank account. Omit this field to assi

  • description (String, nil) (defaults to: nil) —

    Your description for the linked bank account.

  • metadata (Hash{Symbol=>String, nil}, nil) (defaults to: nil) —

    Up to 20 user-defined key-value pairs.

  • platform_id (String, nil) (defaults to: nil) —

    ID of the platform to associate with the linked bank account.

  • purposes (Array<Symbol, Straddle::Models::LinkedBankAccountCreateParams::Purpose>, nil) (defaults to: nil) —

    Payment purposes for the linked bank account. Defaults to charges, payouts,

  • correlation_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing a series of related requests.

  • idempotency_key (String) (defaults to: nil) —

    Optional client-generated key for an idempotent request.

  • request_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing one request.

  • request_options (Straddle::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 93

class BankAccount < Straddle::Internal::Type::BaseModel
  # @!attribute account_holder
  #   Account holder name as it appears on the bank account. This is usually the
  #   business's legal name.
  #
  #   @return [String]
  required :account_holder, String

  # @!attribute account_number
  #   The bank account number.
  #
  #   @return [String]
  required :account_number, String

  # @!attribute routing_number
  #   Nine-digit ABA routing number.
  #
  #   @return [String]
  required :routing_number, String

  # @!method initialize(account_holder:, account_number:, routing_number:)
  #   Some parameter documentations has been truncated, see
  #   {Straddle::Models::LinkedBankAccountCreateParams::BankAccount} for more details.
  #
  #   @param account_holder [String] Account holder name as it appears on the bank account. This is usually the busin
  #
  #   @param account_number [String] The bank account number.
  #
  #   @param routing_number [String] Nine-digit ABA routing number.
end

Instance Attribute Details

#account_holder ⇒ String

Account holder name as it appears on the bank account. This is usually the business's legal name.

Parameters:

  • value (String)

Returns:

  • (String)


99
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 99

required :account_holder, String

#account_number ⇒ String

The bank account number.

Parameters:

  • value (String)

Returns:

  • (String)


105
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 105

required :account_number, String

#routing_number ⇒ String

Nine-digit ABA routing number.

Parameters:

  • value (String)

Returns:

  • (String)


111
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 111

required :routing_number, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


91
# File 'sig/straddle/models/linked_bank_account_create_params.rbs', line 91

def to_hash: -> {