Class: Straddle::Models::LinkedBankAccountCreatedV1WebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/linked_bank_account_created_v1_webhook_event.rb,
sig/straddle/models/linked_bank_account_created_v1_webhook_event.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, data:, event_id:, event_type:) ⇒ Object

Parameters:

  • account_id (String) —

    Unique identifier for the account associated with this event.

  • data (Straddle::Models::LinkedBankAccount)
  • event_id (String) —

    Unique identifier for this event.

  • event_type (String) —

    Type of this event.



# File 'lib/straddle/models/linked_bank_account_created_v1_webhook_event.rb', line 29

Instance Attribute Details

#account_id ⇒ String

Unique identifier for the account associated with this event.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/linked_bank_account_created_v1_webhook_event.rb', line 10

required :account_id, String

#data ⇒ Straddle::Models::LinkedBankAccount



15
# File 'lib/straddle/models/linked_bank_account_created_v1_webhook_event.rb', line 15

required :data, -> { Straddle::LinkedBankAccount }

#event_id ⇒ String

Unique identifier for this event.

Parameters:

  • value (String)

Returns:

  • (String)


21
# File 'lib/straddle/models/linked_bank_account_created_v1_webhook_event.rb', line 21

required :event_id, String

#event_type ⇒ String

Type of this event.

Parameters:

  • value (String)

Returns:

  • (String)


27
# File 'lib/straddle/models/linked_bank_account_created_v1_webhook_event.rb', line 27

required :event_type, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


27
# File 'sig/straddle/models/linked_bank_account_created_v1_webhook_event.rbs', line 27

def to_hash: -> {