Class: Straddle::Models::LinkedBankAccountListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::LinkedBankAccountListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/linked_bank_account_list_params.rb,
sig/straddle/models/linked_bank_account_list_params.rbs
Overview
Defined Under Namespace
Modules: Level, Purpose, SortOrder, Status
Instance Attribute Summary collapse
-
#account_id ⇒ String?
Account ID used to filter the results.
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#level ⇒ Symbol, ...
Scope of linked bank accounts to return.
-
#page_number ⇒ Integer?
Page number.
-
#page_size ⇒ Integer?
Number of results per page.
-
#purpose ⇒ Symbol, ...
Linked bank account purpose.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#sort_by ⇒ String?
Field used to sort results.
-
#sort_order ⇒ Symbol, ...
Sort direction.
-
#status ⇒ Symbol, ...
Linked bank account status.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
70 |
# File 'sig/straddle/models/linked_bank_account_list_params.rbs', line 70
def initialize: (
|
Instance Attribute Details
#account_id ⇒ String?
Account ID used to filter the results.
14 |
# File 'lib/straddle/models/linked_bank_account_list_params.rb', line 14 optional :account_id, String |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
64 |
# File 'lib/straddle/models/linked_bank_account_list_params.rb', line 64 optional :correlation_id, String |
#level ⇒ Symbol, ...
Scope of linked bank accounts to return.
20 |
# File 'lib/straddle/models/linked_bank_account_list_params.rb', line 20 optional :level, enum: -> { Straddle::LinkedBankAccountListParams::Level } |
#page_number ⇒ Integer?
Page number. Defaults to 1.
26 |
# File 'lib/straddle/models/linked_bank_account_list_params.rb', line 26 optional :page_number, Integer |
#page_size ⇒ Integer?
Number of results per page. Defaults to 100. Maximum 1000.
32 |
# File 'lib/straddle/models/linked_bank_account_list_params.rb', line 32 optional :page_size, Integer |
#purpose ⇒ Symbol, ...
Linked bank account purpose. Accepted values are charges, payouts, and
billing.
39 |
# File 'lib/straddle/models/linked_bank_account_list_params.rb', line 39 optional :purpose, enum: -> { Straddle::LinkedBankAccountListParams::Purpose } |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
70 |
# File 'lib/straddle/models/linked_bank_account_list_params.rb', line 70 optional :request_id, String |
#sort_by ⇒ String?
Field used to sort results. Defaults to id.
45 |
# File 'lib/straddle/models/linked_bank_account_list_params.rb', line 45 optional :sort_by, String |
#sort_order ⇒ Symbol, ...
Sort direction. Defaults to asc.
51 |
# File 'lib/straddle/models/linked_bank_account_list_params.rb', line 51 optional :sort_order, enum: -> { Straddle::LinkedBankAccountListParams::SortOrder } |
#status ⇒ Symbol, ...
Linked bank account status. Accepted values are created, onboarding,
active, rejected, inactive, and canceled.
58 |
# File 'lib/straddle/models/linked_bank_account_list_params.rb', line 58 optional :status, enum: -> { Straddle::LinkedBankAccountListParams::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/straddle/models/linked_bank_account_list_params.rb', line 104
|
Instance Method Details
#to_hash ⇒ {
84 |
# File 'sig/straddle/models/linked_bank_account_list_params.rbs', line 84
def to_hash: -> {
|