Class: Straddle::Models::LinkedBankAccountUpdateParams::BankAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::LinkedBankAccountUpdateParams::BankAccount
- Defined in:
- lib/straddle/models/linked_bank_account_update_params.rb,
sig/straddle/models/linked_bank_account_update_params.rbs
Instance Attribute Summary collapse
-
#account_holder ⇒ String
Account holder name as it appears on the bank account.
-
#account_number ⇒ String
The bank account number.
-
#routing_number ⇒ String
Nine-digit ABA routing number.
Instance Method Summary collapse
-
#initialize(account_holder:, account_number:, routing_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BankAccount for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_holder:, account_number:, routing_number:) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::LinkedBankAccountUpdateParams::BankAccount for more details.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/straddle/models/linked_bank_account_update_params.rb', line 59 class BankAccount < Straddle::Internal::Type::BaseModel # @!attribute account_holder # Account holder name as it appears on the bank account. This is usually the # business's legal name. # # @return [String] required :account_holder, String # @!attribute account_number # The bank account number. # # @return [String] required :account_number, String # @!attribute routing_number # Nine-digit ABA routing number. # # @return [String] required :routing_number, String # @!method initialize(account_holder:, account_number:, routing_number:) # Some parameter documentations has been truncated, see # {Straddle::Models::LinkedBankAccountUpdateParams::BankAccount} for more details. # # @param account_holder [String] Account holder name as it appears on the bank account. This is usually the busin # # @param account_number [String] The bank account number. # # @param routing_number [String] Nine-digit ABA routing number. end |
Instance Attribute Details
#account_holder ⇒ String
Account holder name as it appears on the bank account. This is usually the business's legal name.
65 |
# File 'lib/straddle/models/linked_bank_account_update_params.rb', line 65 required :account_holder, String |
#account_number ⇒ String
The bank account number.
71 |
# File 'lib/straddle/models/linked_bank_account_update_params.rb', line 71 required :account_number, String |
#routing_number ⇒ String
Nine-digit ABA routing number.
77 |
# File 'lib/straddle/models/linked_bank_account_update_params.rb', line 77 required :routing_number, String |
Instance Method Details
#to_hash ⇒ {
76 |
# File 'sig/straddle/models/linked_bank_account_update_params.rbs', line 76
def to_hash: -> {
|