Class: Straddle::Models::MaskedPaymentDevice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/masked_payment_device.rb,
sig/straddle/models/masked_payment_device.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ip_address:) ⇒ MaskedPaymentDevice

Some parameter documentations has been truncated, see Straddle::Models::MaskedPaymentDevice for more details.

Parameters:

  • ip_address (String) —

    Masked IP address of the device used when the customer authorized the charge or

  • ip_address: (String)


# File 'lib/straddle/models/masked_payment_device.rb', line 13

Instance Attribute Details

#ip_address ⇒ String

Masked IP address of the device used when the customer authorized the charge or payout.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/straddle/models/masked_payment_device.rb', line 11

required :ip_address, String

Instance Method Details

#to_hash ⇒ { ip_address: String }

Returns:

  • ({ ip_address: String })


10
# File 'sig/straddle/models/masked_payment_device.rbs', line 10

def to_hash: -> { ip_address: String }