Class: Straddle::Models::OrganizationListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::OrganizationListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/organization_list_params.rb,
sig/straddle/models/organization_list_params.rbs
Overview
Defined Under Namespace
Modules: SortOrder
Instance Attribute Summary collapse
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#external_id ⇒ String?
Your external ID for the organization.
-
#name ⇒ String?
Organization name.
-
#page_number ⇒ Integer?
Page number.
-
#page_size ⇒ Integer?
Number of results per page.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#sort_by ⇒ String?
Field used to sort results.
-
#sort_order ⇒ Symbol, ...
Sort direction.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
54 |
# File 'sig/straddle/models/organization_list_params.rbs', line 54
def initialize: (
|
Instance Attribute Details
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
50 |
# File 'lib/straddle/models/organization_list_params.rb', line 50 optional :correlation_id, String |
#external_id ⇒ String?
Your external ID for the organization.
14 |
# File 'lib/straddle/models/organization_list_params.rb', line 14 optional :external_id, String |
#name ⇒ String?
Organization name. Supports partial matches.
20 |
# File 'lib/straddle/models/organization_list_params.rb', line 20 optional :name, String |
#page_number ⇒ Integer?
Page number. Defaults to 1.
26 |
# File 'lib/straddle/models/organization_list_params.rb', line 26 optional :page_number, Integer |
#page_size ⇒ Integer?
Number of results per page. Defaults to 100. Maximum 1000.
32 |
# File 'lib/straddle/models/organization_list_params.rb', line 32 optional :page_size, Integer |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
56 |
# File 'lib/straddle/models/organization_list_params.rb', line 56 optional :request_id, String |
#sort_by ⇒ String?
Field used to sort results. Defaults to id.
38 |
# File 'lib/straddle/models/organization_list_params.rb', line 38 optional :sort_by, String |
#sort_order ⇒ Symbol, ...
Sort direction. Defaults to asc.
44 |
# File 'lib/straddle/models/organization_list_params.rb', line 44 optional :sort_order, enum: -> { Straddle::OrganizationListParams::SortOrder } |
Instance Method Details
#to_hash ⇒ {
66 |
# File 'sig/straddle/models/organization_list_params.rbs', line 66
def to_hash: -> {
|