Class: Straddle::Models::PaykeyDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/paykey_details.rb,
sig/straddle/models/paykey_details.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, customer_id:, label:, balance: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::PaykeyDetails for more details.

Parameters:

  • id (String) —

    Unique identifier for the paykey.

  • customer_id (String) —

    Unique identifier for the customer associated with the paykey.

  • label (String) —

    Display label combining the bank name and masked account number.

  • balance (Integer, nil) (defaults to: nil) —

    The most recent available balance in the smallest currency unit, if a balance ch



# File 'lib/straddle/models/paykey_details.rb', line 31

Instance Attribute Details

#balance ⇒ Integer?

The most recent available balance in the smallest currency unit, if a balance check was performed.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


29
# File 'lib/straddle/models/paykey_details.rb', line 29

optional :balance, Integer, nil?: true

#customer_id ⇒ String

Unique identifier for the customer associated with the paykey.

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/straddle/models/paykey_details.rb', line 16

required :customer_id, String

#id ⇒ String

Unique identifier for the paykey.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/paykey_details.rb', line 10

required :id, String

#label ⇒ String

Display label combining the bank name and masked account number.

Parameters:

  • value (String)

Returns:

  • (String)


22
# File 'lib/straddle/models/paykey_details.rb', line 22

required :label, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


22
# File 'sig/straddle/models/paykey_details.rbs', line 22

def to_hash: -> {