Class: Straddle::Models::PaykeyEventV1WebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::PaykeyEventV1WebhookEvent::Data
- Defined in:
- lib/straddle/models/paykey_event_v1_webhook_event.rb,
sig/straddle/models/paykey_event_v1_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Status Classes: Balance, BankData, StatusDetails
Instance Attribute Summary collapse
- #balance ⇒ Straddle::Models::PaykeyEventV1WebhookEvent::Data::Balance?
- #bank_data ⇒ Straddle::Models::PaykeyEventV1WebhookEvent::Data::BankData?
-
#created_at ⇒ Time
Timestamp of when the paykey was created.
-
#customer_id ⇒ String?
Unique identifier for the customer associated with the paykey.
-
#expires_at ⇒ Time?
Expiration date and time of the paykey, if applicable.
-
#id ⇒ String
Unique identifier for the paykey.
-
#institution_name ⇒ String?
Name of the financial institution.
-
#label ⇒ String
Human-readable label for the paykey.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
Up to 20 user-defined key-value pairs associated with the paykey.
-
#paykey ⇒ String
Full paykey value for creating payments.
- #source ⇒ Symbol, Straddle::Models::PaykeySource
- #status ⇒ Symbol, Straddle::Models::PaykeyEventV1WebhookEvent::Data::Status
- #status_details ⇒ Straddle::Models::PaykeyEventV1WebhookEvent::Data::StatusDetails?
-
#updated_at ⇒ Time
Timestamp of the most recent update to the paykey.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_number:, account_type:, routing_number:) ⇒ Object
|
|
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 119
|
Instance Attribute Details
#balance ⇒ Straddle::Models::PaykeyEventV1WebhookEvent::Data::Balance?
83 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 83 optional :balance, -> { Straddle::PaykeyEventV1WebhookEvent::Data::Balance } |
#bank_data ⇒ Straddle::Models::PaykeyEventV1WebhookEvent::Data::BankData?
88 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 88 optional :bank_data, -> { Straddle::PaykeyEventV1WebhookEvent::Data::BankData } |
#created_at ⇒ Time
Timestamp of when the paykey was created.
50 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 50 required :created_at, Time |
#customer_id ⇒ String?
Unique identifier for the customer associated with the paykey.
94 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 94 optional :customer_id, String, nil?: true |
#expires_at ⇒ Time?
Expiration date and time of the paykey, if applicable.
100 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 100 optional :expires_at, Time, nil?: true |
#id ⇒ String
Unique identifier for the paykey.
44 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 44 required :id, String |
#institution_name ⇒ String?
Name of the financial institution.
106 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 106 optional :institution_name, String, nil?: true |
#label ⇒ String
Human-readable label for the paykey.
56 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 56 required :label, String |
#metadata ⇒ Hash{Symbol=>String, nil}?
Up to 20 user-defined key-value pairs associated with the paykey.
112 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 112 optional :metadata, Straddle::Internal::Type::HashOf[String, nil?: true], nil?: true |
#paykey ⇒ String
Full paykey value for creating payments. Store this value securely.
62 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 62 required :paykey, String |
#source ⇒ Symbol, Straddle::Models::PaykeySource
67 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 67 required :source, enum: -> { Straddle::PaykeySource } |
#status ⇒ Symbol, Straddle::Models::PaykeyEventV1WebhookEvent::Data::Status
72 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 72 required :status, enum: -> { Straddle::PaykeyEventV1WebhookEvent::Data::Status } |
#status_details ⇒ Straddle::Models::PaykeyEventV1WebhookEvent::Data::StatusDetails?
117 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 117 optional :status_details, -> { Straddle::PaykeyEventV1WebhookEvent::Data::StatusDetails } |
#updated_at ⇒ Time
Timestamp of the most recent update to the paykey.
78 |
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 78 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/straddle/models/paykey_event_v1_webhook_event.rb', line 159
|
Instance Method Details
#to_hash ⇒ {
110 |
# File 'sig/straddle/models/paykey_event_v1_webhook_event.rbs', line 110
def to_hash: -> {
|