Class: Straddle::Models::PaykeySummary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/paykey_summary.rb,
sig/straddle/models/paykey_summary.rbs

Constant Summary collapse

Straddle =

Returns:

  • (:PaykeyBankDetails)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, config:, created_at:, label:, paykey:, source:, status:, updated_at:, bank_data: nil, customer_id: nil, expires_at: nil, external_id: nil, institution_name: nil, status_details: nil, unblock_eligible: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::PaykeySummary for more details.

Parameters:

  • id (String) —

    Unique identifier for the paykey.

  • config (Straddle::Models::PaykeyConfiguration)
  • created_at (Time) —

    Timestamp of when the paykey was created.

  • label (String) —

    Display label combining the bank name and masked account number.

  • paykey (String) —

    Masked paykey value.

  • source (Symbol, Straddle::Models::PaykeySource)
  • status (Symbol, Straddle::Models::PaykeyStatus)
  • updated_at (Time) —

    Timestamp of the most recent update to the paykey.

  • bank_data (Straddle::Models::PaykeyBankDetails) (defaults to: nil)
  • customer_id (String, nil) (defaults to: nil) —

    Unique identifier for the customer associated with the paykey.

  • expires_at (Time, nil) (defaults to: nil) —

    Expiration date and time of the paykey, if applicable.

  • external_id (String, nil) (defaults to: nil) —

    Unique identifier for the paykey in your system.

  • institution_name (String, nil) (defaults to: nil) —

    Name of the financial institution.

  • status_details (Straddle::Models::PaymentStatusDetails) (defaults to: nil)
  • unblock_eligible (Boolean, nil) (defaults to: nil) —

    Whether the paykey is eligible for client-initiated unblocking. true only when



# File 'lib/straddle/models/paykey_summary.rb', line 93

Instance Attribute Details

#bank_data ⇒ Straddle::Models::PaykeyBankDetails?



54
# File 'lib/straddle/models/paykey_summary.rb', line 54

optional :bank_data, -> { Straddle::PaykeyBankDetails }

#config ⇒ Straddle::Models::PaykeyConfiguration



15
# File 'lib/straddle/models/paykey_summary.rb', line 15

required :config, -> { Straddle::PaykeyConfiguration }

#created_at ⇒ Time

Timestamp of when the paykey was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


21
# File 'lib/straddle/models/paykey_summary.rb', line 21

required :created_at, Time

#customer_id ⇒ String?

Unique identifier for the customer associated with the paykey.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


60
# File 'lib/straddle/models/paykey_summary.rb', line 60

optional :customer_id, String, nil?: true

#expires_at ⇒ Time?

Expiration date and time of the paykey, if applicable.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


66
# File 'lib/straddle/models/paykey_summary.rb', line 66

optional :expires_at, Time, nil?: true

#external_id ⇒ String?

Unique identifier for the paykey in your system.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


72
# File 'lib/straddle/models/paykey_summary.rb', line 72

optional :external_id, String, nil?: true

#id ⇒ String

Unique identifier for the paykey.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/paykey_summary.rb', line 10

required :id, String

#institution_name ⇒ String?

Name of the financial institution.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


78
# File 'lib/straddle/models/paykey_summary.rb', line 78

optional :institution_name, String, nil?: true

#label ⇒ String

Display label combining the bank name and masked account number.

Parameters:

  • value (String)

Returns:

  • (String)


27
# File 'lib/straddle/models/paykey_summary.rb', line 27

required :label, String

#paykey ⇒ String

Masked paykey value.

Parameters:

  • value (String)

Returns:

  • (String)


33
# File 'lib/straddle/models/paykey_summary.rb', line 33

required :paykey, String

#source ⇒ Symbol, Straddle::Models::PaykeySource

Parameters:

  • value (Straddle::Models::paykey_source)

Returns:



38
# File 'lib/straddle/models/paykey_summary.rb', line 38

required :source, enum: -> { Straddle::PaykeySource }

#status ⇒ Symbol, Straddle::Models::PaykeyStatus

Parameters:

  • value (Straddle::Models::paykey_status)

Returns:



43
# File 'lib/straddle/models/paykey_summary.rb', line 43

required :status, enum: -> { Straddle::PaykeyStatus }

#status_details ⇒ Straddle::Models::PaymentStatusDetails?



83
# File 'lib/straddle/models/paykey_summary.rb', line 83

optional :status_details, -> { Straddle::PaymentStatusDetails }

#unblock_eligible ⇒ Boolean?

Whether the paykey is eligible for client-initiated unblocking. true only when the paykey is blocked by an R29 return and has not been unblocked before. false for other blocked paykeys. null when the paykey is not blocked.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


91
# File 'lib/straddle/models/paykey_summary.rb', line 91

optional :unblock_eligible, Straddle::Internal::Type::Boolean, nil?: true

#updated_at ⇒ Time

Timestamp of the most recent update to the paykey.

Parameters:

  • value (Time)

Returns:

  • (Time)


49
# File 'lib/straddle/models/paykey_summary.rb', line 49

required :updated_at, Time

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


79
# File 'sig/straddle/models/paykey_summary.rbs', line 79

def to_hash: -> {