Class: Straddle::Models::Paykeys::AccountNameMatchDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/paykeys/account_name_match_details.rb,
sig/straddle/models/paykeys/account_name_match_details.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(codes:, decision:, correlation_score: nil, customer_name: nil, matched_name: nil, names_on_account: nil, reason: nil) ⇒ Object

Parameters:

  • codes (Array<String>) —

    Result codes returned by the name-match check.

  • decision (Symbol, Straddle::Models::Paykeys::PaykeyVerificationResult)
  • correlation_score (Float, nil) (defaults to: nil) —

    Strength of the match between the customer name and account-holder names.

  • customer_name (String, nil) (defaults to: nil) —

    Customer name evaluated during account verification.

  • matched_name (String, nil) (defaults to: nil) —

    Account-holder name that matched the customer record.

  • names_on_account (Array<String>, nil) (defaults to: nil) —

    Account-holder names returned by the financial institution.

  • reason (String, nil) (defaults to: nil) —

    Reason for the name-match decision.



# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 48

Instance Attribute Details

#codes ⇒ Array<String>

Result codes returned by the name-match check.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


11
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 11

required :codes, Straddle::Internal::Type::ArrayOf[String]

#correlation_score ⇒ Float?

Strength of the match between the customer name and account-holder names.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


22
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 22

optional :correlation_score, Float, nil?: true

#customer_name ⇒ String?

Customer name evaluated during account verification.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


28
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 28

optional :customer_name, String, nil?: true

#decision ⇒ Symbol, Straddle::Models::Paykeys::PaykeyVerificationResult

Parameters:

  • value (Straddle::Models::Paykeys::paykey_verification_result)

Returns:



16
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 16

required :decision, enum: -> { Straddle::Paykeys::PaykeyVerificationResult }

#matched_name ⇒ String?

Account-holder name that matched the customer record.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


34
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 34

optional :matched_name, String, nil?: true

#names_on_account ⇒ Array<String>?

Account-holder names returned by the financial institution.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


40
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 40

optional :names_on_account, Straddle::Internal::Type::ArrayOf[String], nil?: true

#reason ⇒ String?

Reason for the name-match decision.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


46
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 46

optional :reason, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


40
# File 'sig/straddle/models/paykeys/account_name_match_details.rbs', line 40

def to_hash: -> {