Class: Straddle::Models::Paykeys::PaykeyVerificationDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::Paykeys::PaykeyVerificationDetails
- Defined in:
- lib/straddle/models/paykeys/paykey_verification_details.rb,
sig/straddle/models/paykeys/paykey_verification_details.rbs
Instance Attribute Summary collapse
- #breakdown ⇒ Straddle::Models::Paykeys::PaykeyVerificationBreakdown
-
#created_at ⇒ Time
Timestamp of when the verification was initiated.
- #decision ⇒ Symbol, Straddle::Models::Paykeys::PaykeyVerificationResult
-
#id ⇒ String
Unique identifier for the verification details.
-
#messages ⇒ Hash{Symbol=>String}
Messages returned by the paykey verification process.
-
#updated_at ⇒ Time
Timestamp of the most recent update to the verification details.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
29 |
# File 'sig/straddle/models/paykeys/paykey_verification_details.rbs', line 29
def initialize: (
|
Instance Attribute Details
#breakdown ⇒ Straddle::Models::Paykeys::PaykeyVerificationBreakdown
16 |
# File 'lib/straddle/models/paykeys/paykey_verification_details.rb', line 16 required :breakdown, -> { Straddle::Paykeys::PaykeyVerificationBreakdown } |
#created_at ⇒ Time
Timestamp of when the verification was initiated.
22 |
# File 'lib/straddle/models/paykeys/paykey_verification_details.rb', line 22 required :created_at, Time |
#decision ⇒ Symbol, Straddle::Models::Paykeys::PaykeyVerificationResult
27 |
# File 'lib/straddle/models/paykeys/paykey_verification_details.rb', line 27 required :decision, enum: -> { Straddle::Paykeys::PaykeyVerificationResult } |
#id ⇒ String
Unique identifier for the verification details.
11 |
# File 'lib/straddle/models/paykeys/paykey_verification_details.rb', line 11 required :id, String |
#messages ⇒ Hash{Symbol=>String}
Messages returned by the paykey verification process.
33 |
# File 'lib/straddle/models/paykeys/paykey_verification_details.rb', line 33 required :messages, Straddle::Internal::Type::HashOf[String] |
#updated_at ⇒ Time
Timestamp of the most recent update to the verification details.
39 |
# File 'lib/straddle/models/paykeys/paykey_verification_details.rb', line 39 required :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/straddle/models/paykeys/paykey_verification_details.rbs', line 38
def to_hash: -> {
|