Class: Straddle::Models::Paykeys::ReviewSetVerificationDecisionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::Paykeys::ReviewSetVerificationDecisionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/paykeys/review_set_verification_decision_params.rb,
sig/straddle/models/paykeys/review_set_verification_decision_params.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
- #id ⇒ String
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
- #status ⇒ Symbol, Straddle::Models::Paykeys::ReviewSetVerificationDecisionParams::Status
-
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
39 |
# File 'sig/straddle/models/paykeys/review_set_verification_decision_params.rbs', line 39
def initialize: (
|
Instance Attribute Details
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
25 |
# File 'lib/straddle/models/paykeys/review_set_verification_decision_params.rb', line 25 optional :correlation_id, String |
#id ⇒ String
14 |
# File 'lib/straddle/models/paykeys/review_set_verification_decision_params.rb', line 14 required :id, String |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
31 |
# File 'lib/straddle/models/paykeys/review_set_verification_decision_params.rb', line 31 optional :idempotency_key, String |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
37 |
# File 'lib/straddle/models/paykeys/review_set_verification_decision_params.rb', line 37 optional :request_id, String |
#status ⇒ Symbol, Straddle::Models::Paykeys::ReviewSetVerificationDecisionParams::Status
19 |
# File 'lib/straddle/models/paykeys/review_set_verification_decision_params.rb', line 19 required :status, enum: -> { Straddle::Paykeys::ReviewSetVerificationDecisionParams::Status } |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
43 |
# File 'lib/straddle/models/paykeys/review_set_verification_decision_params.rb', line 43 optional :straddle_account_id, String |
Instance Method Details
#to_hash ⇒ {
49 |
# File 'sig/straddle/models/paykeys/review_set_verification_decision_params.rbs', line 49
def to_hash: -> {
|