Class: Straddle::Models::PaymentSummary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/payment_summary.rb,
sig/straddle/models/payment_summary.rbs

Constant Summary collapse

Straddle =

Returns:

  • (:CustomerDetails)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, created_at:, currency:, description:, external_id:, funding_ids:, has_refund:, has_resubmit:, is_refund:, is_resubmit:, paykey:, payment_date:, payment_type:, status:, status_details:, trace_ids:, updated_at:, customer_details: nil, effective_at: nil, funding_id: nil, metadata: nil, paykey_details: nil, related_payments: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::PaymentSummary for more details.

Parameters:

  • id (String) —

    Unique identifier for this charge or payout.

  • amount (Integer) —

    Amount in cents.

  • created_at (Time) —

    Timestamp when the charge or payout was created.

  • currency (String) —

    Currency code. Only USD is supported.

  • description (String, nil) —

    Human-readable description of the payment.

  • external_id (String) —

    Your unique identifier for the charge or payout.

  • funding_ids (Array<String>) —

    IDs of the funding events that included this payment.

  • has_refund (Boolean) —

    Whether this payment is a charge refunded by an associated payout.

  • has_resubmit (Boolean) —

    Whether this payment has been resubmitted.

  • is_refund (Boolean) —

    Whether this payment is a payout that refunds an original charge.

  • is_resubmit (Boolean) —

    Whether this payment resubmits an original payment.

  • paykey (String) —

    Masked paykey token used for the charge or payout.

  • payment_date (Date) —

    Date when Straddle submits the payment for processing.

  • payment_type (Symbol, Straddle::Models::PaymentType) —

    Whether this payment is a charge or payout.

  • status (Symbol, Straddle::Models::PaymentStatus) —

    Current status of the charge or payout.

  • status_details (Straddle::Models::PaymentStatusDetails) —

    Reason, source, and message for the most recent status change.

  • trace_ids (Hash{Symbol=>String}) —

    Network-level trace identifiers assigned during processing. Keys vary by payment

  • updated_at (Time) —

    Timestamp when the charge or payout was last updated.

  • customer_details (Straddle::Models::CustomerDetails) (defaults to: nil) —

    Information about the customer associated with the charge or payout.

  • effective_at (Time, nil) (defaults to: nil) —

    Timestamp when funds settled. Null until settlement is confirmed.

  • funding_id (String, nil) (defaults to: nil) —

    Unique identifier for the funding event associated with the charge or payout

  • metadata (Hash{Symbol=>String}, nil) (defaults to: nil) —

    Key-value metadata for the payment. Included only when include_metadata is tru

  • paykey_details (Straddle::Models::PaykeyDetails) (defaults to: nil) —

    Details of the paykey used for the charge or payout.

  • related_payments (Array<Straddle::Models::RelatedPayment>, nil) (defaults to: nil) —

    Related payments and their relationship to this charge or payout.



# File 'lib/straddle/models/payment_summary.rb', line 155

Instance Attribute Details

#amount ⇒ Integer

Amount in cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


16
# File 'lib/straddle/models/payment_summary.rb', line 16

required :amount, Integer

#created_at ⇒ Time

Timestamp when the charge or payout was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


22
# File 'lib/straddle/models/payment_summary.rb', line 22

required :created_at, Time

#currency ⇒ String

Currency code. Only USD is supported.

Parameters:

  • value (String)

Returns:

  • (String)


28
# File 'lib/straddle/models/payment_summary.rb', line 28

required :currency, String

#customer_details ⇒ Straddle::Models::CustomerDetails?

Information about the customer associated with the charge or payout.



119
# File 'lib/straddle/models/payment_summary.rb', line 119

optional :customer_details, -> { Straddle::CustomerDetails }

#description ⇒ String?

Human-readable description of the payment.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


34
# File 'lib/straddle/models/payment_summary.rb', line 34

required :description, String, nil?: true

#effective_at ⇒ Time?

Timestamp when funds settled. Null until settlement is confirmed.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


125
# File 'lib/straddle/models/payment_summary.rb', line 125

optional :effective_at, Time, nil?: true

#external_id ⇒ String

Your unique identifier for the charge or payout.

Parameters:

  • value (String)

Returns:

  • (String)


40
# File 'lib/straddle/models/payment_summary.rb', line 40

required :external_id, String

#funding_id ⇒ String?

Unique identifier for the funding event associated with the charge or payout.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


132
# File 'lib/straddle/models/payment_summary.rb', line 132

optional :funding_id, String, nil?: true

#funding_ids ⇒ Array<String>

IDs of the funding events that included this payment.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


46
# File 'lib/straddle/models/payment_summary.rb', line 46

required :funding_ids, Straddle::Internal::Type::ArrayOf[String]

#has_refund ⇒ Boolean

Whether this payment is a charge refunded by an associated payout.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


52
# File 'lib/straddle/models/payment_summary.rb', line 52

required :has_refund, Straddle::Internal::Type::Boolean

#has_resubmit ⇒ Boolean

Whether this payment has been resubmitted.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


58
# File 'lib/straddle/models/payment_summary.rb', line 58

required :has_resubmit, Straddle::Internal::Type::Boolean

#id ⇒ String

Unique identifier for this charge or payout.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/payment_summary.rb', line 10

required :id, String

#is_refund ⇒ Boolean

Whether this payment is a payout that refunds an original charge.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


64
# File 'lib/straddle/models/payment_summary.rb', line 64

required :is_refund, Straddle::Internal::Type::Boolean

#is_resubmit ⇒ Boolean

Whether this payment resubmits an original payment.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


70
# File 'lib/straddle/models/payment_summary.rb', line 70

required :is_resubmit, Straddle::Internal::Type::Boolean

#metadata ⇒ Hash{Symbol=>String}?

Key-value metadata for the payment. Included only when include_metadata is true.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


139
# File 'lib/straddle/models/payment_summary.rb', line 139

optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true

#paykey ⇒ String

Masked paykey token used for the charge or payout.

Parameters:

  • value (String)

Returns:

  • (String)


76
# File 'lib/straddle/models/payment_summary.rb', line 76

required :paykey, String

#paykey_details ⇒ Straddle::Models::PaykeyDetails?

Details of the paykey used for the charge or payout.



145
# File 'lib/straddle/models/payment_summary.rb', line 145

optional :paykey_details, -> { Straddle::PaykeyDetails }

#payment_date ⇒ Date

Date when Straddle submits the payment for processing.

Parameters:

  • value (Date)

Returns:

  • (Date)


82
# File 'lib/straddle/models/payment_summary.rb', line 82

required :payment_date, Date

#payment_type ⇒ Symbol, Straddle::Models::PaymentType

Whether this payment is a charge or payout.

Parameters:

  • value (Straddle::Models::payment_type)

Returns:



88
# File 'lib/straddle/models/payment_summary.rb', line 88

required :payment_type, enum: -> { Straddle::PaymentType }

Related payments and their relationship to this charge or payout.

Parameters:

Returns:



151
152
153
# File 'lib/straddle/models/payment_summary.rb', line 151

optional :related_payments,
-> { Straddle::Internal::Type::ArrayOf[Straddle::RelatedPayment] },
nil?: true

#status ⇒ Symbol, Straddle::Models::PaymentStatus

Current status of the charge or payout.

Parameters:

  • value (Straddle::Models::payment_status)

Returns:



94
# File 'lib/straddle/models/payment_summary.rb', line 94

required :status, enum: -> { Straddle::PaymentStatus }

#status_details ⇒ Straddle::Models::PaymentStatusDetails

Reason, source, and message for the most recent status change.



100
# File 'lib/straddle/models/payment_summary.rb', line 100

required :status_details, -> { Straddle::PaymentStatusDetails }

#trace_ids ⇒ Hash{Symbol=>String}

Network-level trace identifiers assigned during processing. Keys vary by payment rail.

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


107
# File 'lib/straddle/models/payment_summary.rb', line 107

required :trace_ids, Straddle::Internal::Type::HashOf[String]

#updated_at ⇒ Time

Timestamp when the charge or payout was last updated.

Parameters:

  • value (Time)

Returns:

  • (Time)


113
# File 'lib/straddle/models/payment_summary.rb', line 113

required :updated_at, Time

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


113
# File 'sig/straddle/models/payment_summary.rbs', line 113

def to_hash: -> {