Class: Straddle::Models::Payout

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/payout.rb,
sig/straddle/models/payout.rbs

Constant Summary collapse

Straddle =

Returns:

  • (:CustomerDetails)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, config:, created_at:, currency:, description:, device:, external_id:, funding_ids:, has_resubmit:, is_refund:, is_resubmit:, paykey:, payment_date:, status:, status_details:, status_history:, trace_ids:, updated_at:, customer_details: nil, documents: nil, effective_at: nil, metadata: nil, paykey_details: nil, payment_rail: nil, processed_at: nil, related_payments: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::Payout for more details.

Parameters:

  • id (String) —

    Unique identifier for this payout.

  • amount (Integer) —

    Amount in cents.

  • config (Straddle::Models::PayoutConfiguration) —

    Configuration for the payout.

  • created_at (Time) —

    Timestamp when this payout was created.

  • currency (String) —

    Currency code. Only USD is supported.

  • description (String, nil) —

    A human-readable description of the payout.

  • device (Straddle::Models::MaskedPaymentDevice) —

    Device used when the customer authorized the payout.

  • external_id (String) —

    Your unique identifier for this payout, used to correlate with your internal rec

  • funding_ids (Array<String>) —

    IDs of the funding events that included this payout.

  • has_resubmit (Boolean) —

    Whether this payout has been resubmitted.

  • is_refund (Boolean) —

    Whether this payout refunds an original charge.

  • is_resubmit (Boolean) —

    Whether this payout resubmits an original payout.

  • paykey (String) —

    The masked paykey token used for this payout.

  • payment_date (Date) —

    Date when Straddle submits the payout for processing.

  • status (Symbol, Straddle::Models::PaymentStatus) —

    The current status of the payout.

  • status_details (Straddle::Models::PaymentStatusDetails) —

    Reason, source, and message for the most recent payout status change.

  • status_history (Array<Straddle::Models::PaymentStatusHistory>) —

    Complete ordered history of all status changes for this payout.

  • trace_ids (Hash{Symbol=>String}) —

    Trace identifiers from the payment network. Keys depend on the payment rail.

  • updated_at (Time) —

    Timestamp when this payout was last updated.

  • customer_details (Straddle::Models::CustomerDetails) (defaults to: nil) —

    Information about the customer associated with the payout.

  • documents (Array<Straddle::Models::PaymentAuthorizationProof>, nil) (defaults to: nil) —

    Authorization documents for this payout, ordered by upload time.

  • effective_at (Time, nil) (defaults to: nil) —

    Timestamp when funds were settled. Null until settlement is confirmed.

  • metadata (Hash{Symbol=>String}, nil) (defaults to: nil) —

    Key-value metadata stored with this payout.

  • paykey_details (Straddle::Models::PaykeyDetails) (defaults to: nil) —

    Information about the paykey used for the payout.

  • payment_rail (Symbol, Straddle::Models::PaymentRail) (defaults to: nil) —

    Payment rail used to process the payout.

  • processed_at (Time, nil) (defaults to: nil) —

    Timestamp when this payout was submitted to the payment network. Null until proc

  • related_payments (Array<Straddle::Models::RelatedPayment>, nil) (defaults to: nil) —

    Related payments and their relationship to this payout.



# File 'lib/straddle/models/payout.rb', line 174

Instance Attribute Details

#amount ⇒ Integer

Amount in cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


16
# File 'lib/straddle/models/payout.rb', line 16

required :amount, Integer

#config ⇒ Straddle::Models::PayoutConfiguration

Configuration for the payout.



22
# File 'lib/straddle/models/payout.rb', line 22

required :config, -> { Straddle::PayoutConfiguration }

#created_at ⇒ Time

Timestamp when this payout was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


28
# File 'lib/straddle/models/payout.rb', line 28

required :created_at, Time

#currency ⇒ String

Currency code. Only USD is supported.

Parameters:

  • value (String)

Returns:

  • (String)


34
# File 'lib/straddle/models/payout.rb', line 34

required :currency, String

#customer_details ⇒ Straddle::Models::CustomerDetails?

Information about the customer associated with the payout.



125
# File 'lib/straddle/models/payout.rb', line 125

optional :customer_details, -> { Straddle::CustomerDetails }

#description ⇒ String?

A human-readable description of the payout.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


40
# File 'lib/straddle/models/payout.rb', line 40

required :description, String, nil?: true

#device ⇒ Straddle::Models::MaskedPaymentDevice

Device used when the customer authorized the payout.



46
# File 'lib/straddle/models/payout.rb', line 46

required :device, -> { Straddle::MaskedPaymentDevice }

#documents ⇒ Array<Straddle::Models::PaymentAuthorizationProof>?

Authorization documents for this payout, ordered by upload time.

Parameters:

Returns:



131
132
133
# File 'lib/straddle/models/payout.rb', line 131

optional :documents,
-> { Straddle::Internal::Type::ArrayOf[Straddle::PaymentAuthorizationProof] },
nil?: true

#effective_at ⇒ Time?

Timestamp when funds were settled. Null until settlement is confirmed.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


139
# File 'lib/straddle/models/payout.rb', line 139

optional :effective_at, Time, nil?: true

#external_id ⇒ String

Your unique identifier for this payout, used to correlate with your internal records.

Parameters:

  • value (String)

Returns:

  • (String)


53
# File 'lib/straddle/models/payout.rb', line 53

required :external_id, String

#funding_ids ⇒ Array<String>

IDs of the funding events that included this payout.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


59
# File 'lib/straddle/models/payout.rb', line 59

required :funding_ids, Straddle::Internal::Type::ArrayOf[String]

#has_resubmit ⇒ Boolean

Whether this payout has been resubmitted.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


65
# File 'lib/straddle/models/payout.rb', line 65

required :has_resubmit, Straddle::Internal::Type::Boolean

#id ⇒ String

Unique identifier for this payout.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/payout.rb', line 10

required :id, String

#is_refund ⇒ Boolean

Whether this payout refunds an original charge.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


71
# File 'lib/straddle/models/payout.rb', line 71

required :is_refund, Straddle::Internal::Type::Boolean

#is_resubmit ⇒ Boolean

Whether this payout resubmits an original payout.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


77
# File 'lib/straddle/models/payout.rb', line 77

required :is_resubmit, Straddle::Internal::Type::Boolean

#metadata ⇒ Hash{Symbol=>String}?

Key-value metadata stored with this payout.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


145
# File 'lib/straddle/models/payout.rb', line 145

optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true

#paykey ⇒ String

The masked paykey token used for this payout.

Parameters:

  • value (String)

Returns:

  • (String)


83
# File 'lib/straddle/models/payout.rb', line 83

required :paykey, String

#paykey_details ⇒ Straddle::Models::PaykeyDetails?

Information about the paykey used for the payout.



151
# File 'lib/straddle/models/payout.rb', line 151

optional :paykey_details, -> { Straddle::PaykeyDetails }

#payment_date ⇒ Date

Date when Straddle submits the payout for processing.

Parameters:

  • value (Date)

Returns:

  • (Date)


89
# File 'lib/straddle/models/payout.rb', line 89

required :payment_date, Date

#payment_rail ⇒ Symbol, ...

Payment rail used to process the payout.

Returns:



157
# File 'lib/straddle/models/payout.rb', line 157

optional :payment_rail, enum: -> { Straddle::PaymentRail }

#processed_at ⇒ Time?

Timestamp when this payout was submitted to the payment network. Null until processed.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


164
# File 'lib/straddle/models/payout.rb', line 164

optional :processed_at, Time, nil?: true

Related payments and their relationship to this payout.

Parameters:

Returns:



170
171
172
# File 'lib/straddle/models/payout.rb', line 170

optional :related_payments,
-> { Straddle::Internal::Type::ArrayOf[Straddle::RelatedPayment] },
nil?: true

#status ⇒ Symbol, Straddle::Models::PaymentStatus

The current status of the payout.

Parameters:

  • value (Straddle::Models::payment_status)

Returns:



95
# File 'lib/straddle/models/payout.rb', line 95

required :status, enum: -> { Straddle::PaymentStatus }

#status_details ⇒ Straddle::Models::PaymentStatusDetails

Reason, source, and message for the most recent payout status change.



101
# File 'lib/straddle/models/payout.rb', line 101

required :status_details, -> { Straddle::PaymentStatusDetails }

#status_history ⇒ Array<Straddle::Models::PaymentStatusHistory>

Complete ordered history of all status changes for this payout.

Parameters:

Returns:



107
# File 'lib/straddle/models/payout.rb', line 107

required :status_history, -> { Straddle::Internal::Type::ArrayOf[Straddle::PaymentStatusHistory] }

#trace_ids ⇒ Hash{Symbol=>String}

Trace identifiers from the payment network. Keys depend on the payment rail.

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


113
# File 'lib/straddle/models/payout.rb', line 113

required :trace_ids, Straddle::Internal::Type::HashOf[String]

#updated_at ⇒ Time

Timestamp when this payout was last updated.

Parameters:

  • value (Time)

Returns:

  • (Time)


119
# File 'lib/straddle/models/payout.rb', line 119

required :updated_at, Time

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


129
# File 'sig/straddle/models/payout.rbs', line 129

def to_hash: -> {