Class: Straddle::Models::PayoutCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::PayoutCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/payout_create_params.rb,
sig/straddle/models/payout_create_params.rbs
Overview
Constant Summary collapse
- Straddle =
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Amount in cents.
- #config ⇒ Straddle::Models::PayoutConfiguration?
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#currency ⇒ String
Currency code.
-
#description ⇒ String?
Description shown on the customer's bank statement where supported.
-
#device ⇒ Straddle::Models::PaymentDevice
Device used when the customer authorized the payout.
-
#external_id ⇒ String
Your unique identifier for the payout.
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined string key-value pairs.
-
#paykey ⇒ String
The paykey token that identifies the customer's bank account.
-
#payment_date ⇒ Date
Date when Straddle submits the payout for processing.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(amount:, currency:, description:, device:, external_id:, paykey:, payment_date:, config: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:, description:, device:, external_id:, paykey:, payment_date:, config: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/straddle/models/payout_create_params.rb', line 87
|
Instance Attribute Details
#amount ⇒ Integer
Amount in cents.
14 |
# File 'lib/straddle/models/payout_create_params.rb', line 14 required :amount, Integer |
#config ⇒ Straddle::Models::PayoutConfiguration?
55 |
# File 'lib/straddle/models/payout_create_params.rb', line 55 optional :config, -> { Straddle::PayoutConfiguration } |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
67 |
# File 'lib/straddle/models/payout_create_params.rb', line 67 optional :correlation_id, String |
#currency ⇒ String
Currency code. Only USD is supported.
20 |
# File 'lib/straddle/models/payout_create_params.rb', line 20 required :currency, String |
#description ⇒ String?
Description shown on the customer's bank statement where supported.
26 |
# File 'lib/straddle/models/payout_create_params.rb', line 26 required :description, String, nil?: true |
#device ⇒ Straddle::Models::PaymentDevice
Device used when the customer authorized the payout.
32 |
# File 'lib/straddle/models/payout_create_params.rb', line 32 required :device, -> { Straddle::PaymentDevice } |
#external_id ⇒ String
Your unique identifier for the payout. Must be unique across payouts.
38 |
# File 'lib/straddle/models/payout_create_params.rb', line 38 required :external_id, String |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
73 |
# File 'lib/straddle/models/payout_create_params.rb', line 73 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined string key-value pairs.
61 |
# File 'lib/straddle/models/payout_create_params.rb', line 61 optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true |
#paykey ⇒ String
The paykey token that identifies the customer's bank account.
44 |
# File 'lib/straddle/models/payout_create_params.rb', line 44 required :paykey, String |
#payment_date ⇒ Date
Date when Straddle submits the payout for processing.
50 |
# File 'lib/straddle/models/payout_create_params.rb', line 50 required :payment_date, Date |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
79 |
# File 'lib/straddle/models/payout_create_params.rb', line 79 optional :request_id, String |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
85 |
# File 'lib/straddle/models/payout_create_params.rb', line 85 optional :straddle_account_id, String |
Instance Method Details
#to_hash ⇒ {
80 |
# File 'sig/straddle/models/payout_create_params.rbs', line 80
def to_hash: -> {
|