Class: Straddle::Models::PayoutEventV1WebhookEvent::Data::CustomerDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::PayoutEventV1WebhookEvent::Data::CustomerDetails
- Defined in:
- lib/straddle/models/payout_event_v1_webhook_event.rb,
sig/straddle/models/payout_event_v1_webhook_event.rbs
Overview
Instance Attribute Summary collapse
-
#customer_type ⇒ Symbol, Straddle::Models::CustomerType
Whether the customer is an individual or a business.
-
#email ⇒ String
Customer's email address.
-
#id ⇒ String
Unique identifier for the customer.
-
#name ⇒ String
Customer's full name or business name.
-
#phone ⇒ String
Customer's phone number in E.164 format.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
458 |
# File 'sig/straddle/models/payout_event_v1_webhook_event.rbs', line 458
def initialize: (
|
Instance Attribute Details
#customer_type ⇒ Symbol, Straddle::Models::CustomerType
Whether the customer is an individual or a business.
470 |
# File 'lib/straddle/models/payout_event_v1_webhook_event.rb', line 470 required :customer_type, enum: -> { Straddle::CustomerType } |
#email ⇒ String
Customer's email address.
476 |
# File 'lib/straddle/models/payout_event_v1_webhook_event.rb', line 476 required :email, String |
#id ⇒ String
Unique identifier for the customer.
464 |
# File 'lib/straddle/models/payout_event_v1_webhook_event.rb', line 464 required :id, String |
#name ⇒ String
Customer's full name or business name.
482 |
# File 'lib/straddle/models/payout_event_v1_webhook_event.rb', line 482 required :name, String |
#phone ⇒ String
Customer's phone number in E.164 format.
488 |
# File 'lib/straddle/models/payout_event_v1_webhook_event.rb', line 488 required :phone, String |
Instance Method Details
#to_hash ⇒ {
466 |
# File 'sig/straddle/models/payout_event_v1_webhook_event.rbs', line 466
def to_hash: -> {
|