Class: Straddle::Models::PayoutSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/payout_settings.rb,
sig/straddle/models/payout_settings.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(daily_amount:, max_amount:, monthly_amount:, monthly_count:, funding_time: nil, linked_bank_account_id: nil) ⇒ Object

Parameters:

  • daily_amount (Integer) —

    Daily payout amount limit in cents.

  • max_amount (Integer) —

    Maximum amount in cents for one payout.

  • monthly_amount (Integer) —

    Monthly payout amount limit in cents.

  • monthly_count (Integer) —

    Maximum number of payouts per calendar month.

  • funding_time (String, nil) (defaults to: nil) —

    Funding schedule applied to payouts.

  • linked_bank_account_id (String, nil) (defaults to: nil) —

    ID of the linked bank account used for payout settlement.



# File 'lib/straddle/models/payout_settings.rb', line 42

Instance Attribute Details

#daily_amount ⇒ Integer

Daily payout amount limit in cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


10
# File 'lib/straddle/models/payout_settings.rb', line 10

required :daily_amount, Integer

#funding_time ⇒ String?

Funding schedule applied to payouts.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


34
# File 'lib/straddle/models/payout_settings.rb', line 34

optional :funding_time, String, nil?: true

#linked_bank_account_id ⇒ String?

ID of the linked bank account used for payout settlement.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


40
# File 'lib/straddle/models/payout_settings.rb', line 40

optional :linked_bank_account_id, String, nil?: true

#max_amount ⇒ Integer

Maximum amount in cents for one payout.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


16
# File 'lib/straddle/models/payout_settings.rb', line 16

required :max_amount, Integer

#monthly_amount ⇒ Integer

Monthly payout amount limit in cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


22
# File 'lib/straddle/models/payout_settings.rb', line 22

required :monthly_amount, Integer

#monthly_count ⇒ Integer

Maximum number of payouts per calendar month.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


28
# File 'lib/straddle/models/payout_settings.rb', line 28

required :monthly_count, Integer

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


35
# File 'sig/straddle/models/payout_settings.rbs', line 35

def to_hash: -> {