Class: Straddle::Models::PayoutUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::PayoutUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/payout_update_params.rb,
sig/straddle/models/payout_update_params.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Amount in cents.
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#description ⇒ String?
Updated description for the payout.
- #id ⇒ String
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#metadata ⇒ Hash{Symbol=>String}?
Replacement metadata for the payout.
-
#payment_date ⇒ Date
New date for Straddle to submit the payout for processing.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, amount:, description:, payment_date:, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PayoutUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, description:, payment_date:, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::PayoutUpdateParams for more details.
|
|
# File 'lib/straddle/models/payout_update_params.rb', line 64
|
Instance Attribute Details
#amount ⇒ Integer
Amount in cents.
19 |
# File 'lib/straddle/models/payout_update_params.rb', line 19 required :amount, Integer |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
44 |
# File 'lib/straddle/models/payout_update_params.rb', line 44 optional :correlation_id, String |
#description ⇒ String?
Updated description for the payout.
25 |
# File 'lib/straddle/models/payout_update_params.rb', line 25 required :description, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/straddle/models/payout_update_params.rb', line 13 required :id, String |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
50 |
# File 'lib/straddle/models/payout_update_params.rb', line 50 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String}?
Replacement metadata for the payout. Up to 20 user-defined string key-value pairs.
38 |
# File 'lib/straddle/models/payout_update_params.rb', line 38 optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true |
#payment_date ⇒ Date
New date for Straddle to submit the payout for processing.
31 |
# File 'lib/straddle/models/payout_update_params.rb', line 31 required :payment_date, Date |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
56 |
# File 'lib/straddle/models/payout_update_params.rb', line 56 optional :request_id, String |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
62 |
# File 'lib/straddle/models/payout_update_params.rb', line 62 optional :straddle_account_id, String |
Instance Method Details
#to_hash ⇒ {
60 |
# File 'sig/straddle/models/payout_update_params.rbs', line 60
def to_hash: -> {
|