Class: Straddle::Models::PlatformCreatedV1WebhookEvent::Data::BusinessProfile::Address
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::PlatformCreatedV1WebhookEvent::Data::BusinessProfile::Address
- Defined in:
- lib/straddle/models/platform_created_v1_webhook_event.rb,
sig/straddle/models/platform_created_v1_webhook_event.rbs
Overview
Instance Attribute Summary collapse
-
#city ⇒ String?
City for the address.
-
#country ⇒ String?
Two-letter ISO 3166-1 country code.
-
#line1 ⇒ String?
Primary street address.
-
#line2 ⇒ String?
Additional address information, such as a suite or unit.
-
#postal_code ⇒ String?
Postal code for the address.
-
#state ⇒ String?
State or region for the address.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
268 |
# File 'sig/straddle/models/platform_created_v1_webhook_event.rbs', line 268
def initialize: (
|
Instance Attribute Details
#city ⇒ String?
City for the address.
274 |
# File 'lib/straddle/models/platform_created_v1_webhook_event.rb', line 274 optional :city, String, nil?: true |
#country ⇒ String?
Two-letter ISO 3166-1 country code.
280 |
# File 'lib/straddle/models/platform_created_v1_webhook_event.rb', line 280 optional :country, String, nil?: true |
#line1 ⇒ String?
Primary street address.
286 |
# File 'lib/straddle/models/platform_created_v1_webhook_event.rb', line 286 optional :line1, String, nil?: true |
#line2 ⇒ String?
Additional address information, such as a suite or unit.
292 |
# File 'lib/straddle/models/platform_created_v1_webhook_event.rb', line 292 optional :line2, String, nil?: true |
#postal_code ⇒ String?
Postal code for the address.
298 |
# File 'lib/straddle/models/platform_created_v1_webhook_event.rb', line 298 optional :postal_code, String, nil?: true |
#state ⇒ String?
State or region for the address.
304 |
# File 'lib/straddle/models/platform_created_v1_webhook_event.rb', line 304 optional :state, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
277 |
# File 'sig/straddle/models/platform_created_v1_webhook_event.rbs', line 277
def to_hash: -> {
|