Class: Straddle::Models::PlatformCreatedV1WebhookEvent::Data::BusinessProfile::SupportChannels

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/platform_created_v1_webhook_event.rb,
sig/straddle/models/platform_created_v1_webhook_event.rbs

Overview

See Also:

  • Straddle::Models::PlatformCreatedV1WebhookEvent::Data::BusinessProfile#support_channels

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(email: nil, phone: nil, url: nil) ⇒ Object

Parameters:

  • email (String, nil) (defaults to: nil) —

    Customer support email address.

  • phone (String, nil) (defaults to: nil) —

    Customer support phone number.

  • url (String, nil) (defaults to: nil) —

    URL of the customer support page or contact form.



# File 'lib/straddle/models/platform_created_v1_webhook_event.rb', line 368

Instance Attribute Details

#email ⇒ String?

Customer support email address.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


354
# File 'lib/straddle/models/platform_created_v1_webhook_event.rb', line 354

optional :email, String, nil?: true

#phone ⇒ String?

Customer support phone number.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


360
# File 'lib/straddle/models/platform_created_v1_webhook_event.rb', line 360

optional :phone, String, nil?: true

#url ⇒ String?

URL of the customer support page or contact form.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


366
# File 'lib/straddle/models/platform_created_v1_webhook_event.rb', line 366

optional :url, String, nil?: true

Instance Method Details

#to_hash ⇒ { email: String?, phone: String?, url: String? }

Returns:

  • ({ email: String?, phone: String?, url: String? })


321
# File 'sig/straddle/models/platform_created_v1_webhook_event.rbs', line 321

def to_hash: -> { email: String?, phone: String?, url: String? }