Class: Straddle::Models::RepresentativeCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::RepresentativeCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/representative_create_params.rb,
sig/straddle/models/representative_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#account_id ⇒ String
ID of the account associated with the representative.
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#dob ⇒ Date
Representative's date of birth in
YYYY-MM-DDformat. -
#email ⇒ String
Representative's company email address.
-
#external_id ⇒ String?
Your unique ID for the representative.
-
#first_name ⇒ String
Representative's first name.
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#last_name ⇒ String
Representative's last name.
-
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined key-value pairs.
-
#mobile_number ⇒ String
Representative's mobile phone number in E.164 format.
- #relationship ⇒ Straddle::Models::RepresentativeRelationship
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#ssn_last4 ⇒ String
Last four digits of the representative's Social Security number.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(account_id:, dob:, email:, first_name:, last_name:, mobile_number:, relationship:, ssn_last4:, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id:, dob:, email:, first_name:, last_name:, mobile_number:, relationship:, ssn_last4:, external_id: nil, metadata: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/straddle/models/representative_create_params.rb', line 87
|
Instance Attribute Details
#account_id ⇒ String
ID of the account associated with the representative.
14 |
# File 'lib/straddle/models/representative_create_params.rb', line 14 required :account_id, String |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
73 |
# File 'lib/straddle/models/representative_create_params.rb', line 73 optional :correlation_id, String |
#dob ⇒ Date
Representative's date of birth in YYYY-MM-DD format.
20 |
# File 'lib/straddle/models/representative_create_params.rb', line 20 required :dob, Date |
#email ⇒ String
Representative's company email address.
26 |
# File 'lib/straddle/models/representative_create_params.rb', line 26 required :email, String |
#external_id ⇒ String?
Your unique ID for the representative.
61 |
# File 'lib/straddle/models/representative_create_params.rb', line 61 optional :external_id, String, nil?: true |
#first_name ⇒ String
Representative's first name.
32 |
# File 'lib/straddle/models/representative_create_params.rb', line 32 required :first_name, String |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
79 |
# File 'lib/straddle/models/representative_create_params.rb', line 79 optional :idempotency_key, String |
#last_name ⇒ String
Representative's last name.
38 |
# File 'lib/straddle/models/representative_create_params.rb', line 38 required :last_name, String |
#metadata ⇒ Hash{Symbol=>String}?
Up to 20 user-defined key-value pairs.
67 |
# File 'lib/straddle/models/representative_create_params.rb', line 67 optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true |
#mobile_number ⇒ String
Representative's mobile phone number in E.164 format.
44 |
# File 'lib/straddle/models/representative_create_params.rb', line 44 required :mobile_number, String |
#relationship ⇒ Straddle::Models::RepresentativeRelationship
49 |
# File 'lib/straddle/models/representative_create_params.rb', line 49 required :relationship, -> { Straddle::RepresentativeRelationship } |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
85 |
# File 'lib/straddle/models/representative_create_params.rb', line 85 optional :request_id, String |
#ssn_last4 ⇒ String
Last four digits of the representative's Social Security number.
55 |
# File 'lib/straddle/models/representative_create_params.rb', line 55 required :ssn_last4, String |
Instance Method Details
#to_hash ⇒ {
74 |
# File 'sig/straddle/models/representative_create_params.rbs', line 74
def to_hash: -> {
|