Class: Straddle::Models::RepresentativeListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::RepresentativeListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/representative_list_params.rb,
sig/straddle/models/representative_list_params.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#account_id ⇒ String?
Account ID used to filter the results.
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#level ⇒ Symbol, ...
Scope of representatives to return.
-
#organization_id ⇒ String?
Organization ID used to filter the results.
-
#page_number ⇒ Integer?
Page number.
-
#page_size ⇒ Integer?
Number of results per page.
-
#platform_id ⇒ String?
Platform ID used to filter the results.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#sort_by ⇒ String?
Field used to sort results.
-
#sort_order ⇒ Symbol, ...
Sort direction.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
66 |
# File 'sig/straddle/models/representative_list_params.rbs', line 66
def initialize: (
|
Instance Attribute Details
#account_id ⇒ String?
Account ID used to filter the results.
14 |
# File 'lib/straddle/models/representative_list_params.rb', line 14 optional :account_id, String |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
62 |
# File 'lib/straddle/models/representative_list_params.rb', line 62 optional :correlation_id, String |
#level ⇒ Symbol, ...
Scope of representatives to return.
20 |
# File 'lib/straddle/models/representative_list_params.rb', line 20 optional :level, enum: -> { Straddle::RepresentativeListParams::Level } |
#organization_id ⇒ String?
Organization ID used to filter the results.
26 |
# File 'lib/straddle/models/representative_list_params.rb', line 26 optional :organization_id, String |
#page_number ⇒ Integer?
Page number. Defaults to 1.
32 |
# File 'lib/straddle/models/representative_list_params.rb', line 32 optional :page_number, Integer |
#page_size ⇒ Integer?
Number of results per page. Defaults to 100. Maximum 1000.
38 |
# File 'lib/straddle/models/representative_list_params.rb', line 38 optional :page_size, Integer |
#platform_id ⇒ String?
Platform ID used to filter the results.
44 |
# File 'lib/straddle/models/representative_list_params.rb', line 44 optional :platform_id, String |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
68 |
# File 'lib/straddle/models/representative_list_params.rb', line 68 optional :request_id, String |
#sort_by ⇒ String?
Field used to sort results. Defaults to id.
50 |
# File 'lib/straddle/models/representative_list_params.rb', line 50 optional :sort_by, String |
#sort_order ⇒ Symbol, ...
Sort direction. Defaults to asc.
56 |
# File 'lib/straddle/models/representative_list_params.rb', line 56 optional :sort_order, enum: -> { Straddle::RepresentativeListParams::SortOrder } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/straddle/models/representative_list_params.rb', line 99
|
Instance Method Details
#to_hash ⇒ {
80 |
# File 'sig/straddle/models/representative_list_params.rbs', line 80
def to_hash: -> {
|