Class: Straddle::Models::RepresentativeListUnmaskedParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/straddle/models/representative_list_unmasked_params.rb,
sig/straddle/models/representative_list_unmasked_params.rbs

Overview

See Also:

  • Straddle::Resources::Representatives#list_unmasked

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(representative_id:, correlation_id: nil, request_id: nil, request_options: {}) ⇒ Object

Parameters:

  • representative_id (String)
  • correlation_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing a series of related requests.

  • request_id (String) (defaults to: nil) —

    Optional client-generated identifier for tracing one request.

  • request_options (Straddle::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/straddle/models/representative_list_unmasked_params.rb', line 27

Instance Attribute Details

#correlation_id ⇒ String?

Optional client-generated identifier for tracing a series of related requests.

Parameters:

  • (String)

Returns:

  • (String, nil)


19
# File 'lib/straddle/models/representative_list_unmasked_params.rb', line 19

optional :correlation_id, String

#representative_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/straddle/models/representative_list_unmasked_params.rb', line 13

required :representative_id, String

#request_id ⇒ String?

Optional client-generated identifier for tracing one request.

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/straddle/models/representative_list_unmasked_params.rb', line 25

optional :request_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


28
# File 'sig/straddle/models/representative_list_unmasked_params.rbs', line 28

def to_hash: -> {