Class: Straddle::Models::TermsOfService

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/terms_of_service.rb,
sig/straddle/models/terms_of_service.rbs

Defined Under Namespace

Modules: AgreementType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(accepted_date:, agreement_type:, agreement_url:, accepted_ip: nil, accepted_user_agent: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::TermsOfService for more details.

Parameters:

  • accepted_date (Time) —

    Date and time when the account accepted the Terms of Service.

  • agreement_type (Symbol, Straddle::Models::TermsOfService::AgreementType) —

    Agreement type. Use embedded unless Straddle has enabled the platform for `dir

  • agreement_url (String, nil) —

    URL of the accepted agreement.

  • accepted_ip (String, nil) (defaults to: nil) —

    IP address used to accept the Terms of Service.

  • accepted_user_agent (String, nil) (defaults to: nil) —

    User agent of the browser or application that accepted the Terms of Service.



# File 'lib/straddle/models/terms_of_service.rb', line 37

Instance Attribute Details

#accepted_date ⇒ Time

Date and time when the account accepted the Terms of Service.

Parameters:

  • value (Time)

Returns:

  • (Time)


10
# File 'lib/straddle/models/terms_of_service.rb', line 10

required :accepted_date, Time

#accepted_ip ⇒ String?

IP address used to accept the Terms of Service.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


29
# File 'lib/straddle/models/terms_of_service.rb', line 29

optional :accepted_ip, String, nil?: true

#accepted_user_agent ⇒ String?

User agent of the browser or application that accepted the Terms of Service.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


35
# File 'lib/straddle/models/terms_of_service.rb', line 35

optional :accepted_user_agent, String, nil?: true

#agreement_type ⇒ Symbol, Straddle::Models::TermsOfService::AgreementType

Agreement type. Use embedded unless Straddle has enabled the platform for direct agreements.

Parameters:

  • value (Straddle::Models::TermsOfService::agreement_type)

Returns:



17
# File 'lib/straddle/models/terms_of_service.rb', line 17

required :agreement_type, enum: -> { Straddle::TermsOfService::AgreementType }

#agreement_url ⇒ String?

URL of the accepted agreement.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


23
# File 'lib/straddle/models/terms_of_service.rb', line 23

required :agreement_url, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


31
# File 'sig/straddle/models/terms_of_service.rbs', line 31

def to_hash: -> {