Class: Straddle::Models::UnmaskedCustomer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/unmasked_customer.rb,
sig/straddle/models/unmasked_customer.rbs

Constant Summary collapse

Straddle =

Returns:

  • (:CustomerConfiguration)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, email:, name:, phone:, status:, type:, updated_at:, address: nil, compliance_profile: nil, config: nil, device: nil, external_id: nil, metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see Straddle::Models::UnmaskedCustomer for more details.

Parameters:



# File 'lib/straddle/models/unmasked_customer.rb', line 86

Instance Attribute Details

#address ⇒ Straddle::Models::CustomerAddress?

Customer postal address. When provided, the object must include all required fields.

Parameters:

Returns:



57
# File 'lib/straddle/models/unmasked_customer.rb', line 57

optional :address, -> { Straddle::CustomerAddress }, nil?: true

#compliance_profile ⇒ Straddle::Models::UnmaskedComplianceProfile::IndividualComplianceProfile, ...



62
# File 'lib/straddle/models/unmasked_customer.rb', line 62

optional :compliance_profile, union: -> { Straddle::UnmaskedComplianceProfile }, nil?: true

#config ⇒ Straddle::Models::CustomerConfiguration?



67
# File 'lib/straddle/models/unmasked_customer.rb', line 67

optional :config, -> { Straddle::CustomerConfiguration }

#created_at ⇒ Time

Timestamp of when the customer record was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


16
# File 'lib/straddle/models/unmasked_customer.rb', line 16

required :created_at, Time

#device ⇒ Straddle::Models::CustomerDevice?



72
# File 'lib/straddle/models/unmasked_customer.rb', line 72

optional :device, -> { Straddle::CustomerDevice }

#email ⇒ String

The customer's email address.

Parameters:

  • value (String)

Returns:

  • (String)


22
# File 'lib/straddle/models/unmasked_customer.rb', line 22

required :email, String

#external_id ⇒ String?

Unique identifier for the customer in your system.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


78
# File 'lib/straddle/models/unmasked_customer.rb', line 78

optional :external_id, String, nil?: true

#id ⇒ String

Unique identifier for the customer.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/unmasked_customer.rb', line 10

required :id, String

#metadata ⇒ Hash{Symbol=>String}?

Up to 20 user-defined key-value pairs associated with the customer.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


84
# File 'lib/straddle/models/unmasked_customer.rb', line 84

optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true

#name ⇒ String

Full name for an individual customer or business name for a business customer.

Parameters:

  • value (String)

Returns:

  • (String)


28
# File 'lib/straddle/models/unmasked_customer.rb', line 28

required :name, String

#phone ⇒ String

The customer's phone number in E.164 format.

Parameters:

  • value (String)

Returns:

  • (String)


34
# File 'lib/straddle/models/unmasked_customer.rb', line 34

required :phone, String

#status ⇒ Symbol, Straddle::Models::CustomerStatus

Parameters:

  • value (Straddle::Models::customer_status)

Returns:



39
# File 'lib/straddle/models/unmasked_customer.rb', line 39

required :status, enum: -> { Straddle::CustomerStatus }

#type ⇒ Symbol, Straddle::Models::CustomerType

Parameters:

  • value (Straddle::Models::customer_type)

Returns:



44
# File 'lib/straddle/models/unmasked_customer.rb', line 44

required :type, enum: -> { Straddle::CustomerType }

#updated_at ⇒ Time

Timestamp of the most recent update to the customer record.

Parameters:

  • value (Time)

Returns:

  • (Time)


50
# File 'lib/straddle/models/unmasked_customer.rb', line 50

required :updated_at, Time

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


73
# File 'sig/straddle/models/unmasked_customer.rbs', line 73

def to_hash: -> {