Class: Straddle::Models::UnmaskedLinkedBankAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::UnmaskedLinkedBankAccount
- Defined in:
- lib/straddle/models/unmasked_linked_bank_account.rb,
sig/straddle/models/unmasked_linked_bank_account.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#account_id ⇒ String
ID of the Straddle account associated with the linked bank account.
-
#bank_account ⇒ Straddle::Models::UnmaskedLinkedBankAccountDetails
Unmasked bank account details.
-
#created_at ⇒ Time
Date and time when Straddle created the linked bank account.
-
#id ⇒ String
Straddle's unique ID for the linked bank account.
- #metadata ⇒ Hash{Symbol=>String, nil}?
-
#status ⇒ Symbol, Straddle::Models::UnmaskedLinkedBankAccount::Status
Status of the linked bank account.
-
#status_detail ⇒ Straddle::Models::LinkedBankAccountStatusDetail
Details about the linked bank account's status.
-
#updated_at ⇒ Time
Date and time of the most recent linked bank account update.
Instance Method Summary collapse
- #initialize(id:, account_id:, bank_account:, created_at:, status:, status_detail:, updated_at:, metadata: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, account_id:, bank_account:, created_at:, status:, status_detail:, updated_at:, metadata: nil) ⇒ Object
|
|
# File 'lib/straddle/models/unmasked_linked_bank_account.rb', line 53
|
Instance Attribute Details
#account_id ⇒ String
ID of the Straddle account associated with the linked bank account.
16 |
# File 'lib/straddle/models/unmasked_linked_bank_account.rb', line 16 required :account_id, String |
#bank_account ⇒ Straddle::Models::UnmaskedLinkedBankAccountDetails
Unmasked bank account details.
22 |
# File 'lib/straddle/models/unmasked_linked_bank_account.rb', line 22 required :bank_account, -> { Straddle::UnmaskedLinkedBankAccountDetails } |
#created_at ⇒ Time
Date and time when Straddle created the linked bank account.
28 |
# File 'lib/straddle/models/unmasked_linked_bank_account.rb', line 28 required :created_at, Time |
#id ⇒ String
Straddle's unique ID for the linked bank account.
10 |
# File 'lib/straddle/models/unmasked_linked_bank_account.rb', line 10 required :id, String |
#metadata ⇒ Hash{Symbol=>String, nil}?
51 |
# File 'lib/straddle/models/unmasked_linked_bank_account.rb', line 51 optional :metadata, Straddle::Internal::Type::HashOf[String, nil?: true], nil?: true |
#status ⇒ Symbol, Straddle::Models::UnmaskedLinkedBankAccount::Status
Status of the linked bank account.
34 |
# File 'lib/straddle/models/unmasked_linked_bank_account.rb', line 34 required :status, enum: -> { Straddle::UnmaskedLinkedBankAccount::Status } |
#status_detail ⇒ Straddle::Models::LinkedBankAccountStatusDetail
Details about the linked bank account's status.
40 |
# File 'lib/straddle/models/unmasked_linked_bank_account.rb', line 40 required :status_detail, -> { Straddle::LinkedBankAccountStatusDetail } |
#updated_at ⇒ Time
Date and time of the most recent linked bank account update.
46 |
# File 'lib/straddle/models/unmasked_linked_bank_account.rb', line 46 required :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
43 |
# File 'sig/straddle/models/unmasked_linked_bank_account.rbs', line 43
def to_hash: -> {
|