Class: Straddle::Models::UnmaskedPaykey

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/unmasked_paykey.rb,
sig/straddle/models/unmasked_paykey.rbs

Constant Summary collapse

Straddle =

Returns:

  • (:PaykeyBalanceDetails)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, config:, created_at:, label:, paykey:, source:, status:, updated_at:, balance: nil, bank_data: nil, customer_id: nil, expires_at: nil, external_id: nil, institution_name: nil, metadata: nil, status_details: nil) ⇒ Object

Parameters:

  • id (String) —

    Unique identifier for the paykey.

  • config (Straddle::Models::PaykeyConfiguration)
  • created_at (Time) —

    Timestamp of when the paykey was created.

  • label (String) —

    Human-readable label for the paykey.

  • paykey (String) —

    Full paykey value for creating payments. Store this value securely.

  • source (Symbol, Straddle::Models::PaykeySource)
  • status (Symbol, Straddle::Models::PaykeyStatus)
  • updated_at (Time) —

    Timestamp of the most recent update to the paykey.

  • balance (Straddle::Models::PaykeyBalanceDetails) (defaults to: nil)
  • bank_data (Straddle::Models::UnmaskedPaykeyBankDetails) (defaults to: nil)
  • customer_id (String, nil) (defaults to: nil) —

    Unique identifier for the customer associated with the paykey.

  • expires_at (Time, nil) (defaults to: nil) —

    Expiration date and time of the paykey, if applicable.

  • external_id (String, nil) (defaults to: nil) —

    Unique identifier for the paykey in your system.

  • institution_name (String, nil) (defaults to: nil) —

    Name of the financial institution.

  • metadata (Hash{Symbol=>String}, nil) (defaults to: nil) —

    Up to 20 user-defined key-value pairs associated with the paykey.

  • status_details (Straddle::Models::PaymentStatusDetails) (defaults to: nil)


# File 'lib/straddle/models/unmasked_paykey.rb', line 96

Instance Attribute Details

#balance ⇒ Straddle::Models::PaykeyBalanceDetails?



54
# File 'lib/straddle/models/unmasked_paykey.rb', line 54

optional :balance, -> { Straddle::PaykeyBalanceDetails }

#bank_data ⇒ Straddle::Models::UnmaskedPaykeyBankDetails?



59
# File 'lib/straddle/models/unmasked_paykey.rb', line 59

optional :bank_data, -> { Straddle::UnmaskedPaykeyBankDetails }

#config ⇒ Straddle::Models::PaykeyConfiguration



15
# File 'lib/straddle/models/unmasked_paykey.rb', line 15

required :config, -> { Straddle::PaykeyConfiguration }

#created_at ⇒ Time

Timestamp of when the paykey was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


21
# File 'lib/straddle/models/unmasked_paykey.rb', line 21

required :created_at, Time

#customer_id ⇒ String?

Unique identifier for the customer associated with the paykey.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


65
# File 'lib/straddle/models/unmasked_paykey.rb', line 65

optional :customer_id, String, nil?: true

#expires_at ⇒ Time?

Expiration date and time of the paykey, if applicable.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


71
# File 'lib/straddle/models/unmasked_paykey.rb', line 71

optional :expires_at, Time, nil?: true

#external_id ⇒ String?

Unique identifier for the paykey in your system.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


77
# File 'lib/straddle/models/unmasked_paykey.rb', line 77

optional :external_id, String, nil?: true

#id ⇒ String

Unique identifier for the paykey.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/unmasked_paykey.rb', line 10

required :id, String

#institution_name ⇒ String?

Name of the financial institution.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


83
# File 'lib/straddle/models/unmasked_paykey.rb', line 83

optional :institution_name, String, nil?: true

#label ⇒ String

Human-readable label for the paykey.

Parameters:

  • value (String)

Returns:

  • (String)


27
# File 'lib/straddle/models/unmasked_paykey.rb', line 27

required :label, String

#metadata ⇒ Hash{Symbol=>String}?

Up to 20 user-defined key-value pairs associated with the paykey.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


89
# File 'lib/straddle/models/unmasked_paykey.rb', line 89

optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true

#paykey ⇒ String

Full paykey value for creating payments. Store this value securely.

Parameters:

  • value (String)

Returns:

  • (String)


33
# File 'lib/straddle/models/unmasked_paykey.rb', line 33

required :paykey, String

#source ⇒ Symbol, Straddle::Models::PaykeySource

Parameters:

  • value (Straddle::Models::paykey_source)

Returns:



38
# File 'lib/straddle/models/unmasked_paykey.rb', line 38

required :source, enum: -> { Straddle::PaykeySource }

#status ⇒ Symbol, Straddle::Models::PaykeyStatus

Parameters:

  • value (Straddle::Models::paykey_status)

Returns:



43
# File 'lib/straddle/models/unmasked_paykey.rb', line 43

required :status, enum: -> { Straddle::PaykeyStatus }

#status_details ⇒ Straddle::Models::PaymentStatusDetails?



94
# File 'lib/straddle/models/unmasked_paykey.rb', line 94

optional :status_details, -> { Straddle::PaymentStatusDetails }

#updated_at ⇒ Time

Timestamp of the most recent update to the paykey.

Parameters:

  • value (Time)

Returns:

  • (Time)


49
# File 'lib/straddle/models/unmasked_paykey.rb', line 49

required :updated_at, Time

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


87
# File 'sig/straddle/models/unmasked_paykey.rbs', line 87

def to_hash: -> {