Class: Straddle::Models::UnmaskedRepresentative

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/unmasked_representative.rb,
sig/straddle/models/unmasked_representative.rbs

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, account_id:, created_at:, dob:, email:, first_name:, last_name:, mobile_number:, relationship:, ssn_last4:, status:, status_detail:, updated_at:, external_id: nil, metadata: nil, user_id: nil) ⇒ Object

Parameters:

  • id (String) —

    Straddle's unique ID for the representative.

  • account_id (String) —

    ID of the account associated with the representative.

  • created_at (Time) —

    Date and time when Straddle created the representative.

  • dob (Date) —

    Representative's date of birth in YYYY-MM-DD format.

  • email (String) —

    Representative's email address.

  • first_name (String) —

    Representative's first name.

  • last_name (String) —

    Representative's last name.

  • mobile_number (String) —

    Representative's mobile phone number.

  • relationship (Straddle::Models::RepresentativeRelationship)
  • ssn_last4 (String) —

    Last four digits of the representative's Social Security number.

  • status (Symbol, Straddle::Models::UnmaskedRepresentative::Status) —

    Status of the representative.

  • status_detail (Straddle::Models::RepresentativeStatusDetail)
  • updated_at (Time) —

    Date and time of the most recent representative update.

  • external_id (String, nil) (defaults to: nil) —

    Your unique ID for the representative.

  • metadata (Hash{Symbol=>String}, nil) (defaults to: nil) —

    Up to 20 user-defined key-value pairs.

  • user_id (String, nil) (defaults to: nil) —

    ID of the Straddle user linked to the representative, if any.



# File 'lib/straddle/models/unmasked_representative.rb', line 100

Instance Attribute Details

#account_id ⇒ String

ID of the account associated with the representative.

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/straddle/models/unmasked_representative.rb', line 16

required :account_id, String

#created_at ⇒ Time

Date and time when Straddle created the representative.

Parameters:

  • value (Time)

Returns:

  • (Time)


22
# File 'lib/straddle/models/unmasked_representative.rb', line 22

required :created_at, Time

#dob ⇒ Date

Representative's date of birth in YYYY-MM-DD format.

Parameters:

  • value (Date)

Returns:

  • (Date)


28
# File 'lib/straddle/models/unmasked_representative.rb', line 28

required :dob, Date

#email ⇒ String

Representative's email address.

Parameters:

  • value (String)

Returns:

  • (String)


34
# File 'lib/straddle/models/unmasked_representative.rb', line 34

required :email, String

#external_id ⇒ String?

Your unique ID for the representative.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


86
# File 'lib/straddle/models/unmasked_representative.rb', line 86

optional :external_id, String, nil?: true

#first_name ⇒ String

Representative's first name.

Parameters:

  • value (String)

Returns:

  • (String)


40
# File 'lib/straddle/models/unmasked_representative.rb', line 40

required :first_name, String

#id ⇒ String

Straddle's unique ID for the representative.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/straddle/models/unmasked_representative.rb', line 10

required :id, String

#last_name ⇒ String

Representative's last name.

Parameters:

  • value (String)

Returns:

  • (String)


46
# File 'lib/straddle/models/unmasked_representative.rb', line 46

required :last_name, String

#metadata ⇒ Hash{Symbol=>String}?

Up to 20 user-defined key-value pairs.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


92
# File 'lib/straddle/models/unmasked_representative.rb', line 92

optional :metadata, Straddle::Internal::Type::HashOf[String], nil?: true

#mobile_number ⇒ String

Representative's mobile phone number.

Parameters:

  • value (String)

Returns:

  • (String)


52
# File 'lib/straddle/models/unmasked_representative.rb', line 52

required :mobile_number, String

#relationship ⇒ Straddle::Models::RepresentativeRelationship



57
# File 'lib/straddle/models/unmasked_representative.rb', line 57

required :relationship, -> { Straddle::RepresentativeRelationship }

#ssn_last4 ⇒ String

Last four digits of the representative's Social Security number.

Parameters:

  • value (String)

Returns:

  • (String)


63
# File 'lib/straddle/models/unmasked_representative.rb', line 63

required :ssn_last4, String

#status ⇒ Symbol, Straddle::Models::UnmaskedRepresentative::Status

Status of the representative.

Parameters:

  • value (Straddle::Models::UnmaskedRepresentative::status)

Returns:



69
# File 'lib/straddle/models/unmasked_representative.rb', line 69

required :status, enum: -> { Straddle::UnmaskedRepresentative::Status }

#status_detail ⇒ Straddle::Models::RepresentativeStatusDetail



74
# File 'lib/straddle/models/unmasked_representative.rb', line 74

required :status_detail, -> { Straddle::RepresentativeStatusDetail }

#updated_at ⇒ Time

Date and time of the most recent representative update.

Parameters:

  • value (Time)

Returns:

  • (Time)


80
# File 'lib/straddle/models/unmasked_representative.rb', line 80

required :updated_at, Time

#user_id ⇒ String?

ID of the Straddle user linked to the representative, if any.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


98
# File 'lib/straddle/models/unmasked_representative.rb', line 98

optional :user_id, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


75
# File 'sig/straddle/models/unmasked_representative.rbs', line 75

def to_hash: -> {