Class: Straddle::Models::UserCreatedV1WebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/straddle/models/user_created_v1_webhook_event.rb,
sig/straddle/models/user_created_v1_webhook_event.rbs

Overview

See Also:

  • Straddle::Models::UserCreatedV1WebhookEvent#data

Defined Under Namespace

Modules: Level, Role, Status Classes: Membership

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, email:, first_name:, last_name:, level:, memberships:, roles:, status:, updated_at:, authenticator_id: nil, organization_id: nil, platform_id: nil) ⇒ Object

Parameters:

  • id (String) —

    The unique identifier of the user.

  • created_at (Time) —

    Timestamp of when the user was created.

  • email (String) —

    The email address of the user.

  • first_name (String) —

    The first name of the user.

  • last_name (String) —

    The last name of the user.

  • level (Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Level) —

    The current status of the user.

  • memberships (Array<Straddle::Models::UserCreatedV1WebhookEvent::Data::Membership>) —

    Memberships that grant the user access to Straddle entities.

  • roles (Array<Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Role>) —

    The role assigned to the user, determining their permissions within the system.

  • status (Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Status) —

    The current status of the user.

  • updated_at (Time) —

    Timestamp of the most recent update to the user.

  • authenticator_id (String, nil) (defaults to: nil) —

    The unique identifier used for authentication purposes.

  • organization_id (String, nil) (defaults to: nil) —

    The unique identifier of the organization this user belongs to.

  • platform_id (String, nil) (defaults to: nil) —

    The unique identifier of the organization this user belongs to.



# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 124

Instance Attribute Details

#authenticator_id ⇒ String?

The unique identifier used for authentication purposes.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


110
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 110

optional :authenticator_id, String, nil?: true

#created_at ⇒ Time

Timestamp of when the user was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


50
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 50

required :created_at, Time

#email ⇒ String

The email address of the user.

Parameters:

  • value (String)

Returns:

  • (String)


56
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 56

required :email, String

#first_name ⇒ String

The first name of the user.

Parameters:

  • value (String)

Returns:

  • (String)


62
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 62

required :first_name, String

#id ⇒ String

The unique identifier of the user.

Parameters:

  • value (String)

Returns:

  • (String)


44
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 44

required :id, String

#last_name ⇒ String

The last name of the user.

Parameters:

  • value (String)

Returns:

  • (String)


68
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 68

required :last_name, String

#level ⇒ Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Level

The current status of the user.

Parameters:

  • value (Straddle::Models::UserCreatedV1WebhookEvent::Data::level)

Returns:



74
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 74

required :level, enum: -> { Straddle::UserCreatedV1WebhookEvent::Data::Level }

#memberships ⇒ Array<Straddle::Models::UserCreatedV1WebhookEvent::Data::Membership>

Memberships that grant the user access to Straddle entities.

Parameters:

  • value (::Array[Straddle::UserCreatedV1WebhookEvent::Data::Membership])

Returns:



80
81
82
83
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 80

required :memberships,
-> do
  Straddle::Internal::Type::ArrayOf[Straddle::UserCreatedV1WebhookEvent::Data::Membership]
end

#organization_id ⇒ String?

The unique identifier of the organization this user belongs to.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


116
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 116

optional :organization_id, String, nil?: true

#platform_id ⇒ String?

The unique identifier of the organization this user belongs to.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


122
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 122

optional :platform_id, String, nil?: true

#roles ⇒ Array<Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Role>

The role assigned to the user, determining their permissions within the system.

Parameters:

  • value (::Array[Straddle::Models::UserCreatedV1WebhookEvent::Data::role])

Returns:



89
90
91
92
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 89

required :roles,
-> do
  Straddle::Internal::Type::ArrayOf[enum: Straddle::UserCreatedV1WebhookEvent::Data::Role]
end

#status ⇒ Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Status

The current status of the user.

Parameters:

  • value (Straddle::Models::UserCreatedV1WebhookEvent::Data::status)

Returns:



98
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 98

required :status, enum: -> { Straddle::UserCreatedV1WebhookEvent::Data::Status }

#updated_at ⇒ Time

Timestamp of the most recent update to the user.

Parameters:

  • value (Time)

Returns:

  • (Time)


104
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 104

required :updated_at, Time

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 163

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


94
# File 'sig/straddle/models/user_created_v1_webhook_event.rbs', line 94

def to_hash: -> {