Class: Straddle::Models::AccountChargeSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::AccountChargeSettings
- Defined in:
- lib/straddle/models/account_charge_settings.rb,
sig/straddle/models/account_charge_settings.rbs
Defined Under Namespace
Modules: FundingTime
Instance Attribute Summary collapse
-
#daily_amount ⇒ Integer
Daily charge amount limit in cents.
-
#funding_time ⇒ Symbol, Straddle::Models::AccountChargeSettings::FundingTime
Funding schedule for charges.
-
#linked_bank_account_id ⇒ String
ID of the linked bank account used for charge settlement.
-
#max_amount ⇒ Integer
Maximum amount in cents for one charge.
-
#monthly_amount ⇒ Integer
Monthly charge amount limit in cents.
-
#monthly_count ⇒ Integer
Maximum number of charges per calendar month.
Instance Method Summary collapse
-
#initialize(daily_amount:, funding_time:, linked_bank_account_id:, max_amount:, monthly_amount:, monthly_count:) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccountChargeSettings for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(daily_amount:, funding_time:, linked_bank_account_id:, max_amount:, monthly_amount:, monthly_count:) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::AccountChargeSettings for more details.
|
|
# File 'lib/straddle/models/account_charge_settings.rb', line 43
|
Instance Attribute Details
#daily_amount ⇒ Integer
Daily charge amount limit in cents.
10 |
# File 'lib/straddle/models/account_charge_settings.rb', line 10 required :daily_amount, Integer |
#funding_time ⇒ Symbol, Straddle::Models::AccountChargeSettings::FundingTime
Funding schedule for charges. Straddle sets this value.
16 |
# File 'lib/straddle/models/account_charge_settings.rb', line 16 required :funding_time, enum: -> { Straddle::AccountChargeSettings::FundingTime } |
#linked_bank_account_id ⇒ String
ID of the linked bank account used for charge settlement. Straddle sets this value.
23 |
# File 'lib/straddle/models/account_charge_settings.rb', line 23 required :linked_bank_account_id, String |
#max_amount ⇒ Integer
Maximum amount in cents for one charge.
29 |
# File 'lib/straddle/models/account_charge_settings.rb', line 29 required :max_amount, Integer |
#monthly_amount ⇒ Integer
Monthly charge amount limit in cents.
35 |
# File 'lib/straddle/models/account_charge_settings.rb', line 35 required :monthly_amount, Integer |
#monthly_count ⇒ Integer
Maximum number of charges per calendar month.
41 |
# File 'lib/straddle/models/account_charge_settings.rb', line 41 required :monthly_count, Integer |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/straddle/models/account_charge_settings.rbs', line 35
def to_hash: -> {
|