Class: Straddle::Models::CustomerDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::CustomerDetails
- Defined in:
- lib/straddle/models/customer_details.rb,
sig/straddle/models/customer_details.rbs
Instance Attribute Summary collapse
-
#customer_type ⇒ Symbol, Straddle::Models::CustomerType
Whether the customer is an individual or a business.
-
#email ⇒ String
Customer's email address.
-
#id ⇒ String
Unique identifier for the customer.
-
#name ⇒ String
Customer's full name or business name.
-
#phone ⇒ String
Customer's phone number in E.164 format.
Instance Method Summary collapse
-
#initialize(id:, customer_type:, email:, name:, phone:) ⇒ Object
constructor
Information about the customer associated with the charge or payout.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, customer_type:, email:, name:, phone:) ⇒ Object
Information about the customer associated with the charge or payout.
|
|
# File 'lib/straddle/models/customer_details.rb', line 36
|
Instance Attribute Details
#customer_type ⇒ Symbol, Straddle::Models::CustomerType
Whether the customer is an individual or a business.
16 |
# File 'lib/straddle/models/customer_details.rb', line 16 required :customer_type, enum: -> { Straddle::CustomerType } |
#email ⇒ String
Customer's email address.
22 |
# File 'lib/straddle/models/customer_details.rb', line 22 required :email, String |
#id ⇒ String
Unique identifier for the customer.
10 |
# File 'lib/straddle/models/customer_details.rb', line 10 required :id, String |
#name ⇒ String
Customer's full name or business name.
28 |
# File 'lib/straddle/models/customer_details.rb', line 28 required :name, String |
#phone ⇒ String
Customer's phone number in E.164 format.
34 |
# File 'lib/straddle/models/customer_details.rb', line 34 required :phone, String |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/straddle/models/customer_details.rbs', line 31
def to_hash: -> {
|