Class: Straddle::Models::Customers::IdentityVerificationWatchlistMatch
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::Customers::IdentityVerificationWatchlistMatch
- Defined in:
- lib/straddle/models/customers/identity_verification_watchlist_match.rb,
sig/straddle/models/customers/identity_verification_watchlist_match.rbs
Instance Attribute Summary collapse
- #correlation ⇒ Symbol, Straddle::Models::Customers::CorrelationBucket
-
#list_name ⇒ String
Name of the watchlist that contains the matching record.
-
#match_fields ⇒ Array<String>
Customer fields that match the watchlist record.
-
#urls ⇒ Array<String>
Source URLs associated with the match.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(correlation:, list_name:, match_fields:, urls:) ⇒ Object
|
|
# File 'lib/straddle/models/customers/identity_verification_watchlist_match.rb', line 30
|
Instance Attribute Details
#correlation ⇒ Symbol, Straddle::Models::Customers::CorrelationBucket
10 |
# File 'lib/straddle/models/customers/identity_verification_watchlist_match.rb', line 10 required :correlation, enum: -> { Straddle::Customers::CorrelationBucket } |
#list_name ⇒ String
Name of the watchlist that contains the matching record.
16 |
# File 'lib/straddle/models/customers/identity_verification_watchlist_match.rb', line 16 required :list_name, String |
#match_fields ⇒ Array<String>
Customer fields that match the watchlist record.
22 |
# File 'lib/straddle/models/customers/identity_verification_watchlist_match.rb', line 22 required :match_fields, Straddle::Internal::Type::ArrayOf[String] |
#urls ⇒ Array<String>
Source URLs associated with the match.
28 |
# File 'lib/straddle/models/customers/identity_verification_watchlist_match.rb', line 28 required :urls, Straddle::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
28 |
# File 'sig/straddle/models/customers/identity_verification_watchlist_match.rbs', line 28
def to_hash: -> {
|