Class: Straddle::Models::FundingEventSimulateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::FundingEventSimulateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/funding_event_simulate_params.rb,
sig/straddle/models/funding_event_simulate_params.rbs
Overview
Defined Under Namespace
Modules: FundingEventJobType
Instance Attribute Summary collapse
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#funding_event_job_type ⇒ Symbol, Straddle::Models::FundingEventSimulateParams::FundingEventJobType
Required.
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#sandbox_outcome ⇒ Symbol, ...
Optional.
-
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(funding_event_job_type:, sandbox_outcome: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see FundingEventSimulateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(funding_event_job_type:, sandbox_outcome: nil, correlation_id: nil, idempotency_key: nil, request_id: nil, straddle_account_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::FundingEventSimulateParams for more details.
|
|
# File 'lib/straddle/models/funding_event_simulate_params.rb', line 47
|
Instance Attribute Details
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
27 |
# File 'lib/straddle/models/funding_event_simulate_params.rb', line 27 optional :correlation_id, String |
#funding_event_job_type ⇒ Symbol, Straddle::Models::FundingEventSimulateParams::FundingEventJobType
Required. Selects charge or payout activity for the simulated funding event.
14 |
# File 'lib/straddle/models/funding_event_simulate_params.rb', line 14 required :funding_event_job_type, enum: -> { Straddle::FundingEventSimulateParams::FundingEventJobType } |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
33 |
# File 'lib/straddle/models/funding_event_simulate_params.rb', line 33 optional :idempotency_key, String |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
39 |
# File 'lib/straddle/models/funding_event_simulate_params.rb', line 39 optional :request_id, String |
#sandbox_outcome ⇒ Symbol, ...
Optional. Sets the processing outcome for the simulated funding event. Defaults
to standard.
21 |
# File 'lib/straddle/models/funding_event_simulate_params.rb', line 21 optional :sandbox_outcome, enum: -> { Straddle::SimulatedPaymentOutcome } |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
45 |
# File 'lib/straddle/models/funding_event_simulate_params.rb', line 45 optional :straddle_account_id, String |
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/straddle/models/funding_event_simulate_params.rbs', line 52
def to_hash: -> {
|