Class: Straddle::Models::FundingEventSummary
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::FundingEventSummary
- Defined in:
- lib/straddle/models/funding_event_summary.rb,
sig/straddle/models/funding_event_summary.rbs
Constant Summary collapse
- Straddle =
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Total funding event amount in the smallest currency unit.
-
#created_at ⇒ Time
Timestamp when this funding event was created.
-
#direction ⇒ Symbol, Straddle::Models::TransferDirection
Transfer direction relative to the linked bank account.
-
#event_type ⇒ Symbol, Straddle::Models::FundingEventType
Reason for the funding event.
-
#id ⇒ String
Unique identifier for this funding event.
-
#payment_count ⇒ Integer
Number of payments included in this funding event.
-
#status ⇒ Symbol, ...
Current status of this funding event.
-
#status_details ⇒ Straddle::Models::PaymentStatusDetails?
Reason, source, and message for the most recent status change.
-
#trace_ids ⇒ Hash{Symbol=>String}
Network-level trace identifiers assigned during processing.
-
#trace_number ⇒ String?
The trace number of the funding event.
-
#trace_numbers ⇒ Array<String>
Network trace numbers associated with payments in this funding event.
-
#transfer_date ⇒ Date
The date the funds transfer was initiated.
-
#updated_at ⇒ Time
Timestamp when this funding event was last updated.
Instance Method Summary collapse
-
#initialize(id:, amount:, created_at:, direction:, event_type:, payment_count:, trace_ids:, trace_numbers:, transfer_date:, updated_at:, status: nil, status_details: nil, trace_number: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see FundingEventSummary for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, created_at:, direction:, event_type:, payment_count:, trace_ids:, trace_numbers:, transfer_date:, updated_at:, status: nil, status_details: nil, trace_number: nil) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::FundingEventSummary for more details.
|
|
# File 'lib/straddle/models/funding_event_summary.rb', line 90
|
Instance Attribute Details
#amount ⇒ Integer
Total funding event amount in the smallest currency unit. For example, 1000 is
$10.00 USD.
17 |
# File 'lib/straddle/models/funding_event_summary.rb', line 17 required :amount, Integer |
#created_at ⇒ Time
Timestamp when this funding event was created.
23 |
# File 'lib/straddle/models/funding_event_summary.rb', line 23 required :created_at, Time |
#direction ⇒ Symbol, Straddle::Models::TransferDirection
Transfer direction relative to the linked bank account. deposit moves funds
into the account, and withdrawal moves funds out.
30 |
# File 'lib/straddle/models/funding_event_summary.rb', line 30 required :direction, enum: -> { Straddle::TransferDirection } |
#event_type ⇒ Symbol, Straddle::Models::FundingEventType
Reason for the funding event. charge_deposit settles collected charges to the
linked bank account. charge_reversal withdraws funds for reversed charges.
payout_withdrawal withdraws funds for payouts. payout_return deposits
returned payout funds.
39 |
# File 'lib/straddle/models/funding_event_summary.rb', line 39 required :event_type, enum: -> { Straddle::FundingEventType } |
#id ⇒ String
Unique identifier for this funding event.
10 |
# File 'lib/straddle/models/funding_event_summary.rb', line 10 required :id, String |
#payment_count ⇒ Integer
Number of payments included in this funding event.
45 |
# File 'lib/straddle/models/funding_event_summary.rb', line 45 required :payment_count, Integer |
#status ⇒ Symbol, ...
Current status of this funding event.
76 |
# File 'lib/straddle/models/funding_event_summary.rb', line 76 optional :status, enum: -> { Straddle::PaymentStatus } |
#status_details ⇒ Straddle::Models::PaymentStatusDetails?
Reason, source, and message for the most recent status change.
82 |
# File 'lib/straddle/models/funding_event_summary.rb', line 82 optional :status_details, -> { Straddle::PaymentStatusDetails } |
#trace_ids ⇒ Hash{Symbol=>String}
Network-level trace identifiers assigned during processing. Keys vary by payment rail.
52 |
# File 'lib/straddle/models/funding_event_summary.rb', line 52 required :trace_ids, Straddle::Internal::Type::HashOf[String] |
#trace_number ⇒ String?
The trace number of the funding event.
88 |
# File 'lib/straddle/models/funding_event_summary.rb', line 88 optional :trace_number, String, nil?: true |
#trace_numbers ⇒ Array<String>
Network trace numbers associated with payments in this funding event.
58 |
# File 'lib/straddle/models/funding_event_summary.rb', line 58 required :trace_numbers, Straddle::Internal::Type::ArrayOf[String] |
#transfer_date ⇒ Date
The date the funds transfer was initiated.
64 |
# File 'lib/straddle/models/funding_event_summary.rb', line 64 required :transfer_date, Date |
#updated_at ⇒ Time
Timestamp when this funding event was last updated.
70 |
# File 'lib/straddle/models/funding_event_summary.rb', line 70 required :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
71 |
# File 'sig/straddle/models/funding_event_summary.rbs', line 71
def to_hash: -> {
|