Class: Straddle::Models::LinkedBankAccountCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::LinkedBankAccountCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/linked_bank_account_create_params.rb,
sig/straddle/models/linked_bank_account_create_params.rbs
Overview
Defined Under Namespace
Modules: Purpose Classes: BankAccount
Instance Attribute Summary collapse
-
#account_id ⇒ String?
ID of the account that will own the linked bank account.
- #bank_account ⇒ Straddle::Models::LinkedBankAccountCreateParams::BankAccount
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#description ⇒ String?
Your description for the linked bank account.
-
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
Up to 20 user-defined key-value pairs.
-
#platform_id ⇒ String?
ID of the platform to associate with the linked bank account.
-
#purposes ⇒ Array<Symbol, Straddle::Models::LinkedBankAccountCreateParams::Purpose>?
Payment purposes for the linked bank account.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account_holder:, account_number:, routing_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BankAccount for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_holder:, account_number:, routing_number:) ⇒ Object
Some parameter documentations has been truncated, see BankAccount for more details.
|
|
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 113
|
Instance Attribute Details
#account_id ⇒ String?
ID of the account that will own the linked bank account. Omit this field to assign ownership to the platform in the authenticated request context.
20 |
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 20 optional :account_id, String, nil?: true |
#bank_account ⇒ Straddle::Models::LinkedBankAccountCreateParams::BankAccount
13 |
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 13 required :bank_account, -> { Straddle::LinkedBankAccountCreateParams::BankAccount } |
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
55 |
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 55 optional :correlation_id, String |
#description ⇒ String?
Your description for the linked bank account.
26 |
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 26 optional :description, String, nil?: true |
#idempotency_key ⇒ String?
Optional client-generated key for an idempotent request.
61 |
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 61 optional :idempotency_key, String |
#metadata ⇒ Hash{Symbol=>String, nil}?
Up to 20 user-defined key-value pairs.
32 |
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 32 optional :metadata, Straddle::Internal::Type::HashOf[String, nil?: true], nil?: true |
#platform_id ⇒ String?
ID of the platform to associate with the linked bank account.
38 |
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 38 optional :platform_id, String, nil?: true |
#purposes ⇒ Array<Symbol, Straddle::Models::LinkedBankAccountCreateParams::Purpose>?
Payment purposes for the linked bank account. Defaults to charges, payouts,
and billing.
45 46 47 48 49 |
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 45 optional :purposes, -> do Straddle::Internal::Type::ArrayOf[enum: Straddle::LinkedBankAccountCreateParams::Purpose] end, nil?: true |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
67 |
# File 'lib/straddle/models/linked_bank_account_create_params.rb', line 67 optional :request_id, String |
Instance Method Details
#to_hash ⇒ {
58 |
# File 'sig/straddle/models/linked_bank_account_create_params.rbs', line 58
def to_hash: -> {
|