Class: Straddle::Models::MaskedLinkedBankAccountDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::MaskedLinkedBankAccountDetails
- Defined in:
- lib/straddle/models/masked_linked_bank_account_details.rb,
sig/straddle/models/masked_linked_bank_account_details.rbs
Instance Attribute Summary collapse
-
#account_holder ⇒ String
Name of the account holder as it appears on the bank account.
-
#account_mask ⇒ String
Last four digits of the bank account number.
-
#institution_name ⇒ String
Name of the financial institution.
-
#routing_number ⇒ String
Nine-digit ABA routing number for the bank account.
Instance Method Summary collapse
- #initialize(account_holder:, account_mask:, institution_name:, routing_number:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_holder:, account_mask:, institution_name:, routing_number:) ⇒ Object
|
|
# File 'lib/straddle/models/masked_linked_bank_account_details.rb', line 30
|
Instance Attribute Details
#account_holder ⇒ String
Name of the account holder as it appears on the bank account.
10 |
# File 'lib/straddle/models/masked_linked_bank_account_details.rb', line 10 required :account_holder, String |
#account_mask ⇒ String
Last four digits of the bank account number.
16 |
# File 'lib/straddle/models/masked_linked_bank_account_details.rb', line 16 required :account_mask, String |
#institution_name ⇒ String
Name of the financial institution.
22 |
# File 'lib/straddle/models/masked_linked_bank_account_details.rb', line 22 required :institution_name, String |
#routing_number ⇒ String
Nine-digit ABA routing number for the bank account.
28 |
# File 'lib/straddle/models/masked_linked_bank_account_details.rb', line 28 required :routing_number, String |
Instance Method Details
#to_hash ⇒ {
27 |
# File 'sig/straddle/models/masked_linked_bank_account_details.rbs', line 27
def to_hash: -> {
|