Class: Straddle::Models::PaykeyDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::PaykeyDetails
- Defined in:
- lib/straddle/models/paykey_details.rb,
sig/straddle/models/paykey_details.rbs
Instance Attribute Summary collapse
-
#balance ⇒ Integer?
The most recent available balance in the smallest currency unit, if a balance check was performed.
-
#customer_id ⇒ String
Unique identifier for the customer associated with the paykey.
-
#id ⇒ String
Unique identifier for the paykey.
-
#label ⇒ String
Display label combining the bank name and masked account number.
Instance Method Summary collapse
-
#initialize(id:, customer_id:, label:, balance: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaykeyDetails for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, customer_id:, label:, balance: nil) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::PaykeyDetails for more details.
|
|
# File 'lib/straddle/models/paykey_details.rb', line 31
|
Instance Attribute Details
#balance ⇒ Integer?
The most recent available balance in the smallest currency unit, if a balance check was performed.
29 |
# File 'lib/straddle/models/paykey_details.rb', line 29 optional :balance, Integer, nil?: true |
#customer_id ⇒ String
Unique identifier for the customer associated with the paykey.
16 |
# File 'lib/straddle/models/paykey_details.rb', line 16 required :customer_id, String |
#id ⇒ String
Unique identifier for the paykey.
10 |
# File 'lib/straddle/models/paykey_details.rb', line 10 required :id, String |
#label ⇒ String
Display label combining the bank name and masked account number.
22 |
# File 'lib/straddle/models/paykey_details.rb', line 22 required :label, String |
Instance Method Details
#to_hash ⇒ {
22 |
# File 'sig/straddle/models/paykey_details.rbs', line 22
def to_hash: -> {
|