Class: Straddle::Models::Paykeys::AccountNameMatchDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::Paykeys::AccountNameMatchDetails
- Defined in:
- lib/straddle/models/paykeys/account_name_match_details.rb,
sig/straddle/models/paykeys/account_name_match_details.rbs
Instance Attribute Summary collapse
-
#codes ⇒ Array<String>
Result codes returned by the name-match check.
-
#correlation_score ⇒ Float?
Strength of the match between the customer name and account-holder names.
-
#customer_name ⇒ String?
Customer name evaluated during account verification.
- #decision ⇒ Symbol, Straddle::Models::Paykeys::PaykeyVerificationResult
-
#matched_name ⇒ String?
Account-holder name that matched the customer record.
-
#names_on_account ⇒ Array<String>?
Account-holder names returned by the financial institution.
-
#reason ⇒ String?
Reason for the name-match decision.
Instance Method Summary collapse
- #initialize(codes:, decision:, correlation_score: nil, customer_name: nil, matched_name: nil, names_on_account: nil, reason: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(codes:, decision:, correlation_score: nil, customer_name: nil, matched_name: nil, names_on_account: nil, reason: nil) ⇒ Object
|
|
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 48
|
Instance Attribute Details
#codes ⇒ Array<String>
Result codes returned by the name-match check.
11 |
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 11 required :codes, Straddle::Internal::Type::ArrayOf[String] |
#correlation_score ⇒ Float?
Strength of the match between the customer name and account-holder names.
22 |
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 22 optional :correlation_score, Float, nil?: true |
#customer_name ⇒ String?
Customer name evaluated during account verification.
28 |
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 28 optional :customer_name, String, nil?: true |
#decision ⇒ Symbol, Straddle::Models::Paykeys::PaykeyVerificationResult
16 |
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 16 required :decision, enum: -> { Straddle::Paykeys::PaykeyVerificationResult } |
#matched_name ⇒ String?
Account-holder name that matched the customer record.
34 |
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 34 optional :matched_name, String, nil?: true |
#names_on_account ⇒ Array<String>?
Account-holder names returned by the financial institution.
40 |
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 40 optional :names_on_account, Straddle::Internal::Type::ArrayOf[String], nil?: true |
#reason ⇒ String?
Reason for the name-match decision.
46 |
# File 'lib/straddle/models/paykeys/account_name_match_details.rb', line 46 optional :reason, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/straddle/models/paykeys/account_name_match_details.rbs', line 40
def to_hash: -> {
|