Class: Straddle::Models::PaymentListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::PaymentListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/straddle/models/payment_list_params.rb,
sig/straddle/models/payment_list_params.rbs
Overview
Defined Under Namespace
Modules: DefaultSort, SortBy
Instance Attribute Summary collapse
-
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
-
#customer_id ⇒ String?
Filter by the unique identifier of the customer.
-
#default_page_size ⇒ Integer?
Default number of results returned per page.
-
#default_sort ⇒ Symbol, ...
Default field used to sort the results.
-
#default_sort_order ⇒ Symbol, ...
Default order in which to sort the results.
-
#external_id ⇒ String?
Filter by your external identifier for the payment.
-
#funding_id ⇒ String?
Filter by the unique identifier of a funding event.
-
#has_refund ⇒ Boolean?
Filter charges by whether an associated payout has refunded them.
-
#has_resubmit ⇒ Boolean?
Filter payments by whether they have been resubmitted.
-
#include_metadata ⇒ Boolean?
Whether to include metadata in each returned payment.
-
#is_refund ⇒ Boolean?
Filter payouts by whether they refund an original charge.
-
#is_resubmit ⇒ Boolean?
Filter payments by whether they resubmit an original payment.
-
#max_amount ⇒ Integer?
Filter to payments with an amount in cents less than or equal to this value.
-
#max_created_at ⇒ Time?
Filter to payments created at or before this timestamp.
-
#max_effective_at ⇒ Time?
Filter to payments effective at or before this timestamp.
-
#max_payment_date ⇒ Date?
Filter to payments with a payment date on or before this date.
-
#max_updated_at ⇒ Time?
Filter to payments last updated on or before this timestamp.
-
#min_amount ⇒ Integer?
Filter to payments with an amount in cents greater than or equal to this value.
-
#min_created_at ⇒ Time?
Filter to payments created at or after this timestamp.
-
#min_effective_at ⇒ Time?
Filter to payments effective at or after this timestamp.
-
#min_payment_date ⇒ Date?
Filter to payments with a payment date on or after this date.
-
#min_updated_at ⇒ Time?
Filter to payments last updated on or after this timestamp.
-
#page_number ⇒ Integer?
Page number to return.
-
#page_size ⇒ Integer?
Number of results to return per page.
-
#paykey ⇒ String?
Filter by the paykey token.
-
#paykey_id ⇒ String?
Filter by the unique identifier of the paykey.
-
#payment_id ⇒ String?
Filter by the payment's unique identifier.
-
#payment_status ⇒ Array<Symbol, Straddle::Models::PaymentStatus>?
Filter by payment status.
-
#payment_type ⇒ Array<Symbol, Straddle::Models::PaymentType>?
Filter by payment type.
-
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
-
#search_text ⇒ String?
Free-text search across payment fields.
-
#sort_by ⇒ Symbol, ...
Field used to sort the results.
-
#sort_order ⇒ Symbol, ...
Order in which to sort the results.
-
#status_reason ⇒ Array<Symbol, Straddle::Models::PaymentStatusReason>?
Filter by the reason for the most recent payment status change.
-
#status_source ⇒ Array<Symbol, Straddle::Models::PaymentStatusSource>?
Filter by the source of the most recent payment status change.
-
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
208 |
# File 'sig/straddle/models/payment_list_params.rbs', line 208
def initialize: (
|
Instance Attribute Details
#correlation_id ⇒ String?
Optional client-generated identifier for tracing a series of related requests.
212 |
# File 'lib/straddle/models/payment_list_params.rb', line 212 optional :correlation_id, String |
#customer_id ⇒ String?
Filter by the unique identifier of the customer.
14 |
# File 'lib/straddle/models/payment_list_params.rb', line 14 optional :customer_id, String |
#default_page_size ⇒ Integer?
Default number of results returned per page.
20 |
# File 'lib/straddle/models/payment_list_params.rb', line 20 optional :default_page_size, Integer |
#default_sort ⇒ Symbol, ...
Default field used to sort the results.
26 |
# File 'lib/straddle/models/payment_list_params.rb', line 26 optional :default_sort, enum: -> { Straddle::PaymentListParams::DefaultSort } |
#default_sort_order ⇒ Symbol, ...
Default order in which to sort the results.
32 |
# File 'lib/straddle/models/payment_list_params.rb', line 32 optional :default_sort_order, enum: -> { Straddle::SortOrder } |
#external_id ⇒ String?
Filter by your external identifier for the payment.
38 |
# File 'lib/straddle/models/payment_list_params.rb', line 38 optional :external_id, String |
#funding_id ⇒ String?
Filter by the unique identifier of a funding event.
44 |
# File 'lib/straddle/models/payment_list_params.rb', line 44 optional :funding_id, String |
#has_refund ⇒ Boolean?
Filter charges by whether an associated payout has refunded them.
50 |
# File 'lib/straddle/models/payment_list_params.rb', line 50 optional :has_refund, Straddle::Internal::Type::Boolean |
#has_resubmit ⇒ Boolean?
Filter payments by whether they have been resubmitted.
56 |
# File 'lib/straddle/models/payment_list_params.rb', line 56 optional :has_resubmit, Straddle::Internal::Type::Boolean |
#include_metadata ⇒ Boolean?
Whether to include metadata in each returned payment. Defaults to false.
62 |
# File 'lib/straddle/models/payment_list_params.rb', line 62 optional :include_metadata, Straddle::Internal::Type::Boolean |
#is_refund ⇒ Boolean?
Filter payouts by whether they refund an original charge.
68 |
# File 'lib/straddle/models/payment_list_params.rb', line 68 optional :is_refund, Straddle::Internal::Type::Boolean |
#is_resubmit ⇒ Boolean?
Filter payments by whether they resubmit an original payment.
74 |
# File 'lib/straddle/models/payment_list_params.rb', line 74 optional :is_resubmit, Straddle::Internal::Type::Boolean |
#max_amount ⇒ Integer?
Filter to payments with an amount in cents less than or equal to this value.
80 |
# File 'lib/straddle/models/payment_list_params.rb', line 80 optional :max_amount, Integer |
#max_created_at ⇒ Time?
Filter to payments created at or before this timestamp.
86 |
# File 'lib/straddle/models/payment_list_params.rb', line 86 optional :max_created_at, Time |
#max_effective_at ⇒ Time?
Filter to payments effective at or before this timestamp.
92 |
# File 'lib/straddle/models/payment_list_params.rb', line 92 optional :max_effective_at, Time |
#max_payment_date ⇒ Date?
Filter to payments with a payment date on or before this date.
98 |
# File 'lib/straddle/models/payment_list_params.rb', line 98 optional :max_payment_date, Date |
#max_updated_at ⇒ Time?
Filter to payments last updated on or before this timestamp.
104 |
# File 'lib/straddle/models/payment_list_params.rb', line 104 optional :max_updated_at, Time |
#min_amount ⇒ Integer?
Filter to payments with an amount in cents greater than or equal to this value.
110 |
# File 'lib/straddle/models/payment_list_params.rb', line 110 optional :min_amount, Integer |
#min_created_at ⇒ Time?
Filter to payments created at or after this timestamp.
116 |
# File 'lib/straddle/models/payment_list_params.rb', line 116 optional :min_created_at, Time |
#min_effective_at ⇒ Time?
Filter to payments effective at or after this timestamp.
122 |
# File 'lib/straddle/models/payment_list_params.rb', line 122 optional :min_effective_at, Time |
#min_payment_date ⇒ Date?
Filter to payments with a payment date on or after this date.
128 |
# File 'lib/straddle/models/payment_list_params.rb', line 128 optional :min_payment_date, Date |
#min_updated_at ⇒ Time?
Filter to payments last updated on or after this timestamp.
134 |
# File 'lib/straddle/models/payment_list_params.rb', line 134 optional :min_updated_at, Time |
#page_number ⇒ Integer?
Page number to return.
140 |
# File 'lib/straddle/models/payment_list_params.rb', line 140 optional :page_number, Integer |
#page_size ⇒ Integer?
Number of results to return per page.
146 |
# File 'lib/straddle/models/payment_list_params.rb', line 146 optional :page_size, Integer |
#paykey ⇒ String?
Filter by the paykey token.
152 |
# File 'lib/straddle/models/payment_list_params.rb', line 152 optional :paykey, String |
#paykey_id ⇒ String?
Filter by the unique identifier of the paykey.
158 |
# File 'lib/straddle/models/payment_list_params.rb', line 158 optional :paykey_id, String |
#payment_id ⇒ String?
Filter by the payment's unique identifier.
164 |
# File 'lib/straddle/models/payment_list_params.rb', line 164 optional :payment_id, String |
#payment_status ⇒ Array<Symbol, Straddle::Models::PaymentStatus>?
Filter by payment status.
170 |
# File 'lib/straddle/models/payment_list_params.rb', line 170 optional :payment_status, -> { Straddle::Internal::Type::ArrayOf[enum: Straddle::PaymentStatus] } |
#payment_type ⇒ Array<Symbol, Straddle::Models::PaymentType>?
Filter by payment type.
176 |
# File 'lib/straddle/models/payment_list_params.rb', line 176 optional :payment_type, -> { Straddle::Internal::Type::ArrayOf[enum: Straddle::PaymentType] } |
#request_id ⇒ String?
Optional client-generated identifier for tracing one request.
218 |
# File 'lib/straddle/models/payment_list_params.rb', line 218 optional :request_id, String |
#search_text ⇒ String?
Free-text search across payment fields.
182 |
# File 'lib/straddle/models/payment_list_params.rb', line 182 optional :search_text, String |
#sort_by ⇒ Symbol, ...
Field used to sort the results.
188 |
# File 'lib/straddle/models/payment_list_params.rb', line 188 optional :sort_by, enum: -> { Straddle::PaymentListParams::SortBy } |
#sort_order ⇒ Symbol, ...
Order in which to sort the results.
194 |
# File 'lib/straddle/models/payment_list_params.rb', line 194 optional :sort_order, enum: -> { Straddle::SortOrder } |
#status_reason ⇒ Array<Symbol, Straddle::Models::PaymentStatusReason>?
Filter by the reason for the most recent payment status change.
200 |
# File 'lib/straddle/models/payment_list_params.rb', line 200 optional :status_reason, -> { Straddle::Internal::Type::ArrayOf[enum: Straddle::PaymentStatusReason] } |
#status_source ⇒ Array<Symbol, Straddle::Models::PaymentStatusSource>?
Filter by the source of the most recent payment status change.
206 |
# File 'lib/straddle/models/payment_list_params.rb', line 206 optional :status_source, -> { Straddle::Internal::Type::ArrayOf[enum: Straddle::PaymentStatusSource] } |
#straddle_account_id ⇒ String?
For platform requests, the embedded account UUID that sets the request scope.
224 |
# File 'lib/straddle/models/payment_list_params.rb', line 224 optional :straddle_account_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/straddle/models/payment_list_params.rb', line 311
|
Instance Method Details
#to_hash ⇒ {
248 |
# File 'sig/straddle/models/payment_list_params.rbs', line 248
def to_hash: -> {
|