Class: Straddle::Models::RepresentativeRelationship
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::RepresentativeRelationship
- Defined in:
- lib/straddle/models/representative_relationship.rb,
sig/straddle/models/representative_relationship.rbs
Instance Attribute Summary collapse
-
#control ⇒ Boolean
Whether the representative controls, manages, or directs the business.
-
#owner ⇒ Boolean
Whether the representative owns any equity in the business.
-
#percent_ownership ⇒ Float?
The representative's ownership percentage.
-
#primary ⇒ Boolean
Whether this person is the account's primary representative.
-
#title ⇒ String?
The representative's job title.
Instance Method Summary collapse
-
#initialize(control:, owner:, primary:, percent_ownership: nil, title: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RepresentativeRelationship for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(control:, owner:, primary:, percent_ownership: nil, title: nil) ⇒ Object
Some parameter documentations has been truncated, see Straddle::Models::RepresentativeRelationship for more details.
|
|
# File 'lib/straddle/models/representative_relationship.rb', line 39
|
Instance Attribute Details
#control ⇒ Boolean
Whether the representative controls, manages, or directs the business. Each
legal entity must have one representative with control set to true.
11 |
# File 'lib/straddle/models/representative_relationship.rb', line 11 required :control, Straddle::Internal::Type::Boolean |
#owner ⇒ Boolean
Whether the representative owns any equity in the business.
17 |
# File 'lib/straddle/models/representative_relationship.rb', line 17 required :owner, Straddle::Internal::Type::Boolean |
#percent_ownership ⇒ Float?
The representative's ownership percentage. Required when owner is true.
31 |
# File 'lib/straddle/models/representative_relationship.rb', line 31 optional :percent_ownership, Float, nil?: true |
#primary ⇒ Boolean
Whether this person is the account's primary representative. The primary representative provides personal and business information and accepts the services agreement. An account can have only one primary representative.
25 |
# File 'lib/straddle/models/representative_relationship.rb', line 25 required :primary, Straddle::Internal::Type::Boolean |
#title ⇒ String?
The representative's job title.
37 |
# File 'lib/straddle/models/representative_relationship.rb', line 37 optional :title, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/straddle/models/representative_relationship.rbs', line 31 def to_hash: -> { |