Class: Straddle::Models::UserCreatedV1WebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Straddle::Models::UserCreatedV1WebhookEvent::Data
- Defined in:
- lib/straddle/models/user_created_v1_webhook_event.rb,
sig/straddle/models/user_created_v1_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Level, Role, Status Classes: Membership
Instance Attribute Summary collapse
-
#authenticator_id ⇒ String?
The unique identifier used for authentication purposes.
-
#created_at ⇒ Time
Timestamp of when the user was created.
-
#email ⇒ String
The email address of the user.
-
#first_name ⇒ String
The first name of the user.
-
#id ⇒ String
The unique identifier of the user.
-
#last_name ⇒ String
The last name of the user.
-
#level ⇒ Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Level
The current status of the user.
-
#memberships ⇒ Array<Straddle::Models::UserCreatedV1WebhookEvent::Data::Membership>
Memberships that grant the user access to Straddle entities.
-
#organization_id ⇒ String?
The unique identifier of the organization this user belongs to.
-
#platform_id ⇒ String?
The unique identifier of the organization this user belongs to.
-
#roles ⇒ Array<Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Role>
The role assigned to the user, determining their permissions within the system.
-
#status ⇒ Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Status
The current status of the user.
-
#updated_at ⇒ Time
Timestamp of the most recent update to the user.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(id:, created_at:, email:, first_name:, last_name:, level:, memberships:, roles:, status:, updated_at:, authenticator_id: nil, organization_id: nil, platform_id: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, email:, first_name:, last_name:, level:, memberships:, roles:, status:, updated_at:, authenticator_id: nil, organization_id: nil, platform_id: nil) ⇒ Object
|
|
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 124
|
Instance Attribute Details
#authenticator_id ⇒ String?
The unique identifier used for authentication purposes.
110 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 110 optional :authenticator_id, String, nil?: true |
#created_at ⇒ Time
Timestamp of when the user was created.
50 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 50 required :created_at, Time |
#email ⇒ String
The email address of the user.
56 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 56 required :email, String |
#first_name ⇒ String
The first name of the user.
62 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 62 required :first_name, String |
#id ⇒ String
The unique identifier of the user.
44 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 44 required :id, String |
#last_name ⇒ String
The last name of the user.
68 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 68 required :last_name, String |
#level ⇒ Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Level
The current status of the user.
74 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 74 required :level, enum: -> { Straddle::UserCreatedV1WebhookEvent::Data::Level } |
#memberships ⇒ Array<Straddle::Models::UserCreatedV1WebhookEvent::Data::Membership>
Memberships that grant the user access to Straddle entities.
80 81 82 83 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 80 required :memberships, -> do Straddle::Internal::Type::ArrayOf[Straddle::UserCreatedV1WebhookEvent::Data::Membership] end |
#organization_id ⇒ String?
The unique identifier of the organization this user belongs to.
116 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 116 optional :organization_id, String, nil?: true |
#platform_id ⇒ String?
The unique identifier of the organization this user belongs to.
122 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 122 optional :platform_id, String, nil?: true |
#roles ⇒ Array<Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Role>
The role assigned to the user, determining their permissions within the system.
89 90 91 92 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 89 required :roles, -> do Straddle::Internal::Type::ArrayOf[enum: Straddle::UserCreatedV1WebhookEvent::Data::Role] end |
#status ⇒ Symbol, Straddle::Models::UserCreatedV1WebhookEvent::Data::Status
The current status of the user.
98 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 98 required :status, enum: -> { Straddle::UserCreatedV1WebhookEvent::Data::Status } |
#updated_at ⇒ Time
Timestamp of the most recent update to the user.
104 |
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 104 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/straddle/models/user_created_v1_webhook_event.rb', line 163
|
Instance Method Details
#to_hash ⇒ {
94 |
# File 'sig/straddle/models/user_created_v1_webhook_event.rbs', line 94
def to_hash: -> {
|