Class: Straddle::Resources::AccountSettings
- Inherits:
-
Object
- Object
- Straddle::Resources::AccountSettings
- Defined in:
- lib/straddle/resources/account_settings.rb,
sig/straddle/resources/account_settings.rbs
Overview
Account settings define payment limits, capabilities, statement details, and policy controls for an account.
Instance Method Summary collapse
-
#initialize(client:) ⇒ AccountSettings
constructor
private
A new instance of AccountSettings.
-
#retrieve(account_id, correlation_id: nil, request_id: nil, request_options: {}) ⇒ Straddle::Models::AccountSettingsResponse
Returns all effective settings for the account, including values inherited from its organization, platform, and system defaults.
Constructor Details
#initialize(client:) ⇒ AccountSettings
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of AccountSettings.
38 39 40 |
# File 'lib/straddle/resources/account_settings.rb', line 38 def initialize(client:) @client = client end |
Instance Method Details
#retrieve(account_id, correlation_id: nil, request_id: nil, request_options: {}) ⇒ Straddle::Models::AccountSettingsResponse
Returns all effective settings for the account, including values inherited from its organization, platform, and system defaults.
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/straddle/resources/account_settings.rb', line 24 def retrieve(account_id, params = {}) parsed, = Straddle::AccountSettingRetrieveParams.dump_request(params) @client.request( method: :get, path: ["v1/account_settings/%1$s", account_id], headers: parsed.transform_keys(correlation_id: "correlation-id", request_id: "request-id"), model: Straddle::AccountSettingsResponse, options: ) end |